@@ -25,8 +25,8 @@ if TYPE_CHECKING:
     )
 
 
-class BaseClient(Protocol):
-    """Base client interface for ACP - always required."""
+class Client(Protocol):
+    """Base client interface for ACP."""
 
     async def request_permission(
         self, params: RequestPermissionRequest
@@ -34,29 +34,15 @@ class BaseClient(Protocol):
 
     async def session_update(self, params: SessionNotification) -> None: ...
 
-
-class FsCapability(Protocol):
-    """Client capability for filesystem operations."""
-
     async def write_text_file(
         self, params: WriteTextFileRequest
     ) -> WriteTextFileResponse | None: ...
 
-    async def read_text_file(
-        self, params: ReadTextFileRequest
-    ) -> ReadTextFileResponse: ...
+    async def read_text_file(self, params: ReadTextFileRequest) -> ReadTextFileResponse: ...
 
+    async def create_terminal(self, params: CreateTerminalRequest) -> CreateTerminalResponse: ...
 
-class TerminalCapability(Protocol):
-    """Client capability for terminal operations."""
-
-    async def create_terminal(
-        self, params: CreateTerminalRequest
-    ) -> CreateTerminalResponse: ...
-
-    async def terminal_output(
-        self, params: TerminalOutputRequest
-    ) -> TerminalOutputResponse: ...
+    async def terminal_output(self, params: TerminalOutputRequest) -> TerminalOutputResponse: ...
 
     async def release_terminal(
         self, params: ReleaseTerminalRequest
@@ -70,18 +56,6 @@ class TerminalCapability(Protocol):
         self, params: KillTerminalCommandRequest
     ) -> KillTerminalCommandResponse | None: ...
 
-
-class ExtensibilityCapability(Protocol):
-    """Client capability for extension methods."""
-
     async def ext_method(self, method: str, params: dict[str, Any]) -> dict[str, Any]: ...
 
     async def ext_notification(self, method: str, params: dict[str, Any]) -> None: ...
-
-
-class Client(BaseClient, FsCapability, TerminalCapability, ExtensibilityCapability):
-    """High-level client interface for interacting with an ACP server.
-
-    Includes all client capabilities.
-    New implementations should inherit from specific capability protocols instead.
-    """
