@@ -3,7 +3,7 @@
 from __future__ import annotations
 
 from collections.abc import Sequence
-from typing import TYPE_CHECKING, Any
+from typing import TYPE_CHECKING, Any, assert_never
 
 from acp.schema import (
     AgentMessageChunk,
@@ -35,20 +35,22 @@ from llmling_agent.log import get_logger
 
 if TYPE_CHECKING:
     from collections.abc import Sequence
+    from datetime import datetime
 
     from pydantic_ai import ModelRequest, ModelResponse
 
-    from acp import Client
-    from acp.schema import (
-        Annotations,
+    from acp import (
         AvailableCommand,
+        Client,
         PlanEntry,
+        ToolCallContent,
         ToolCallKind,
         ToolCallStatus,
     )
-    from acp.schema.tool_call import ToolCallContent
+    from acp.schema import Audience
 
     ContentType = Sequence[ToolCallContent | str]
+
 logger = get_logger(__name__)
 
 
@@ -68,7 +70,8 @@ class ACPNotifications:
         """
         self.client = client
         self.id = session_id
-        self._tool_call_inputs: dict[str, dict] = {}
+        self.log = logger.bind(session_id=session_id)
+        self._tool_call_inputs: dict[str, dict[str, Any]] = {}
 
     async def tool_call(
         self,
@@ -104,8 +107,7 @@ class ACPNotifications:
             else:
                 # Fallback to string conversion
                 output_text = str(tool_output)
-                block = TextContentBlock(text=output_text)
-                content.append(ContentToolCallContent(content=block))
+                content.append(ContentToolCallContent.text(text=output_text))
 
         # Extract file locations if present
         locations = [
@@ -162,15 +164,13 @@ class ACPNotifications:
             kind=kind,
             locations=locations,
             content=[
-                ContentToolCallContent(content=TextContentBlock(text=i))
-                if isinstance(i, str)
-                else i
+                ContentToolCallContent.text(text=i) if isinstance(i, str) else i
                 for i in content or []
             ],
             raw_input=raw_input,
         )
         notification = SessionNotification(session_id=self.id, update=start)
-        await self.client.session_update(notification)
+        await self.client.session_update(notification)  # pyright: ignore[reportArgumentType]
 
     async def tool_call_progress(
         self,
@@ -206,7 +206,7 @@ class ACPNotifications:
             ],
         )
         notification = SessionNotification(session_id=self.id, update=progress)
-        await self.client.session_update(notification)
+        await self.client.session_update(notification)  # pyright: ignore[reportArgumentType]
 
     async def file_edit_progress(
         self,
@@ -273,7 +273,7 @@ class ACPNotifications:
             content=[terminal_content],
         )
 
-    async def update_plan(self, entries: list[PlanEntry]) -> None:
+    async def update_plan(self, entries: Sequence[PlanEntry]) -> None:
         """Send a plan notification.
 
         Args:
@@ -281,7 +281,7 @@ class ACPNotifications:
         """
         plan = AgentPlanUpdate(entries=entries)
         notification = SessionNotification(session_id=self.id, update=plan)
-        await self.client.session_update(notification)
+        await self.client.session_update(notification)  # pyright: ignore[reportArgumentType]
 
     async def update_commands(self, commands: list[AvailableCommand]) -> None:
         """Send a command update notification.
@@ -291,45 +291,92 @@ class ACPNotifications:
         """
         update = AvailableCommandsUpdate(available_commands=commands)
         notification = SessionNotification(session_id=self.id, update=update)
-        await self.client.session_update(notification)
+        await self.client.session_update(notification)  # pyright: ignore[reportArgumentType]
 
-    async def send_agent_text(self, message: str) -> None:
+    async def send_agent_text(
+        self,
+        message: str,
+        *,
+        audience: Audience | None = None,
+        last_modified: datetime | str | None = None,
+        priority: float | None = None,
+    ) -> None:
         """Send a text message notification.
 
         Args:
             message: Text message to send
+            audience: Audience to send the message to
+            last_modified: Last modified timestamp
+            priority: Priority of the message
         """
-        update = AgentMessageChunk(content=TextContentBlock(text=message))
+        update = AgentMessageChunk.text(
+            text=message,
+            audience=audience,
+            last_modified=last_modified,
+            priority=priority,
+        )
         notification = SessionNotification(session_id=self.id, update=update)
-        await self.client.session_update(notification)
+        await self.client.session_update(notification)  # pyright: ignore[reportArgumentType]
 
-    async def send_agent_thought(self, message: str) -> None:
+    async def send_agent_thought(
+        self,
+        message: str,
+        *,
+        audience: Audience | None = None,
+        last_modified: datetime | str | None = None,
+        priority: float | None = None,
+    ) -> None:
         """Send a text message notification.
 
         Args:
             message: Text message to send
+            audience: Audience to send the message to
+            last_modified: Last modified date of the message
+            priority: Priority of the message
         """
-        update = AgentThoughtChunk(content=TextContentBlock(text=message))
+        update = AgentThoughtChunk.text(
+            text=message,
+            audience=audience,
+            last_modified=last_modified,
+            priority=priority,
+        )
         notification = SessionNotification(session_id=self.id, update=update)
-        await self.client.session_update(notification)
+        await self.client.session_update(notification)  # pyright: ignore[reportArgumentType]
 
-    async def send_user_message(self, message: str) -> None:
+    async def send_user_message(
+        self,
+        message: str,
+        *,
+        audience: Audience | None = None,
+        last_modified: datetime | str | None = None,
+        priority: float | None = None,
+    ) -> None:
         """Send a user message notification.
 
         Args:
             message: Text message to send
+            audience: Audience to send the message to
+            last_modified: Last modified date of the message
+            priority: Priority of the message
         """
-        update = UserMessageChunk(content=TextContentBlock(text=message))
-        notification = SessionNotification[Any](session_id=self.id, update=update)
-        await self.client.session_update(notification)
+        update = UserMessageChunk.text(
+            text=message,
+            audience=audience,
+            last_modified=last_modified,
+            priority=priority,
+        )
+        notification = SessionNotification(session_id=self.id, update=update)
+        await self.client.session_update(notification)  # pyright: ignore[reportArgumentType]
 
     async def send_user_image(
         self,
-        data: str,
+        data: str | bytes,
         mime_type: str,
         *,
         uri: str | None = None,
-        annotations: Any | None = None,
+        audience: Audience | None = None,
+        last_modified: datetime | str | None = None,
+        priority: float | None = None,
     ) -> None:
         """Send a user image notification.
 
@@ -337,40 +384,49 @@ class ACPNotifications:
             data: Base64-encoded image data
             mime_type: MIME type of the image
             uri: Optional URI of the image
-            annotations: Optional annotations for the content block
+            audience: Optional audience for the content block
+            last_modified: Optional last modified timestamp for the content block
+            priority: Optional priority for the content block
         """
-        content = ImageContentBlock(
+        update = UserMessageChunk.image(
             data=data,
             mime_type=mime_type,
             uri=uri,
-            annotations=annotations,
+            audience=audience,
+            last_modified=last_modified,
+            priority=priority,
         )
-        update = UserMessageChunk(content=content)
-        notification = SessionNotification[Any](session_id=self.id, update=update)
-        await self.client.session_update(notification)
+        notification = SessionNotification(session_id=self.id, update=update)
+        await self.client.session_update(notification)  # pyright: ignore[reportArgumentType]
 
     async def send_user_audio(
         self,
-        data: str,
+        data: str | bytes,
         mime_type: str,
         *,
-        annotations: Any | None = None,
+        audience: Audience | None = None,
+        last_modified: datetime | str | None = None,
+        priority: float | None = None,
     ) -> None:
         """Send a user audio notification.
 
         Args:
             data: Base64-encoded audio data
             mime_type: MIME type of the audio
-            annotations: Optional annotations for the content block
+            uri: Optional URI for the audio
+            audience: Optional audience for the content block
+            last_modified: Optional last modified timestamp for the content block
+            priority: Optional priority for the content block
         """
-        content = AudioContentBlock(
+        update = UserMessageChunk.audio(
             data=data,
             mime_type=mime_type,
-            annotations=annotations,
+            audience=audience,
+            last_modified=last_modified,
+            priority=priority,
         )
-        update = UserMessageChunk(content=content)
-        notification = SessionNotification[Any](session_id=self.id, update=update)
-        await self.client.session_update(notification)
+        notification = SessionNotification(session_id=self.id, update=update)
+        await self.client.session_update(notification)  # pyright: ignore[reportArgumentType]
 
     async def send_user_resource(
         self,
@@ -381,7 +437,9 @@ class ACPNotifications:
         mime_type: str | None = None,
         size: int | None = None,
         title: str | None = None,
-        annotations: Any | None = None,
+        audience: Audience | None = None,
+        last_modified: datetime | str | None = None,
+        priority: float | None = None,
     ) -> None:
         """Send a user resource link notification.
 
@@ -392,20 +450,23 @@ class ACPNotifications:
             mime_type: Optional MIME type of the resource
             size: Optional size of the resource in bytes
             title: Optional title of the resource
-            annotations: Optional annotations for the content block
+            audience: Optional audience for the content block
+            last_modified: Optional last modified timestamp for the content block
+            priority: Optional priority for the content block
         """
-        content = ResourceContentBlock(
+        update = UserMessageChunk.resource(
             uri=uri,
             name=name,
             description=description,
             mime_type=mime_type,
             size=size,
             title=title,
-            annotations=annotations,
+            audience=audience,
+            last_modified=last_modified,
+            priority=priority,
         )
-        update = UserMessageChunk(content=content)
-        notification = SessionNotification[Any](session_id=self.id, update=update)
-        await self.client.session_update(notification)
+        notification = SessionNotification(session_id=self.id, update=update)
+        await self.client.session_update(notification)  # pyright: ignore[reportArgumentType]
 
     async def replay(self, messages: Sequence[ModelRequest | ModelResponse]) -> None:
         """Replay a sequence of model messages as notifications.
@@ -423,11 +484,10 @@ class ACPNotifications:
                     case ModelResponse():
                         await self._replay_response(message)
                     case _:
-                        logger.debug(
-                            "Unhandled message type", message_type=type(message).__name__
-                        )
+                        typ = type(message).__name__
+                        self.log.debug("Unhandled message type", message_type=typ)
             except Exception as e:
-                logger.exception("Failed to replay message", error=str(e))
+                self.log.exception("Failed to replay message", error=str(e))
 
     async def _replay_request(self, request: ModelRequest) -> None:
         """Replay a ModelRequest by converting it to appropriate ACP notifications."""
@@ -445,8 +505,6 @@ class ACPNotifications:
                         converted_content = to_acp_content_blocks(content)
                         # Send each content block as separate notifications
                         for block in converted_content:
-                            # Handle different content block types with proper
-                            # pattern matching
                             match block:
                                 case TextContentBlock(text=text):
                                     await self.send_user_message(text)
@@ -455,13 +513,29 @@ class ACPNotifications:
                                         data=img_block.data,
                                         mime_type=img_block.mime_type,
                                         uri=img_block.uri,
-                                        annotations=img_block.annotations,
+                                        audience=img_block.annotations.audience
+                                        if img_block.annotations
+                                        else None,
+                                        last_modified=img_block.annotations.last_modified
+                                        if img_block.annotations
+                                        else None,
+                                        priority=img_block.annotations.priority
+                                        if img_block.annotations
+                                        else None,
                                     )
                                 case AudioContentBlock() as audio_block:
                                     await self.send_user_audio(
                                         data=audio_block.data,
                                         mime_type=audio_block.mime_type,
-                                        annotations=audio_block.annotations,
+                                        audience=audio_block.annotations.audience
+                                        if audio_block.annotations
+                                        else None,
+                                        last_modified=audio_block.annotations.last_modified
+                                        if audio_block.annotations
+                                        else None,
+                                        priority=audio_block.annotations.priority
+                                        if audio_block.annotations
+                                        else None,
                                     )
                                 case ResourceContentBlock() as resource_block:
                                     await self.send_user_resource(
@@ -471,7 +545,15 @@ class ACPNotifications:
                                         mime_type=resource_block.mime_type,
                                         size=resource_block.size,
                                         title=resource_block.title,
-                                        annotations=resource_block.annotations,
+                                        audience=resource_block.annotations.audience
+                                        if resource_block.annotations
+                                        else None,
+                                        last_modified=resource_block.annotations.last_modified
+                                        if resource_block.annotations
+                                        else None,
+                                        priority=resource_block.annotations.priority
+                                        if resource_block.annotations
+                                        else None,
                                     )
                                 case EmbeddedResourceContentBlock() as embedded_block:
                                     # Handle embedded resources with proper
@@ -483,18 +565,12 @@ class ACPNotifications:
                                             blob_size = len(blob_resource.blob) * 3 // 4
                                             size_mb = blob_size / (1024 * 1024)
                                             mime = blob_resource.mime_type or "unknown"
-                                            msg = (
-                                                f"Embedded resource: {mime} "
-                                                f"({size_mb:.2f} MB)"
-                                            )
+                                            msg = f"Embedded resource: {mime} ({size_mb:.2f} MB)"
                                             await self.send_user_message(msg)
-                                        case _:
-                                            await self.send_user_message(
-                                                "Embedded resource"
-                                            )
-                                case _:
-                                    # Fallback for unknown types
-                                    await self.send_user_message(str(block))
+                                        case _ as unreachable:
+                                            assert_never(unreachable)
+                                case _ as unreachable:
+                                    assert_never(unreachable)
 
                 case ToolReturnPart(
                     content=content, tool_name=tool_name, tool_call_id=tool_call_id
@@ -512,9 +588,8 @@ class ACPNotifications:
                     self._tool_call_inputs.pop(tool_call_id, None)
 
                 case _:
-                    logger.debug(
-                        "Unhandled request part type", part_type=type(part).__name__
-                    )
+                    typ = type(part).__name__
+                    self.log.debug("Unhandled request part type", part_type=typ)
 
     async def _replay_response(self, response: ModelResponse) -> None:
         """Replay a ModelResponse by converting it to appropriate ACP notifications."""
@@ -536,17 +611,18 @@ class ACPNotifications:
                     # tool call state
 
                 case _:
-                    logger.debug(
-                        "Unhandled response part type", part_type=type(part).__name__
-                    )
+                    typ = type(part).__name__
+                    self.log.debug("Unhandled response part type", part_type=typ)
 
     async def send_agent_image(
         self,
-        data: str,
+        data: str | bytes,
         mime_type: str,
         *,
         uri: str | None = None,
-        annotations: Annotations | None = None,
+        audience: Audience | None = None,
+        last_modified: datetime | str | None = None,
+        priority: float | None = None,
     ) -> None:
         """Send an image message notification.
 
@@ -554,14 +630,20 @@ class ACPNotifications:
             data: Base64-encoded image data
             mime_type: MIME type of the image (e.g., 'image/png')
             uri: Optional URI reference for the image
-            annotations: Optional annotations for the image
+            audience: Optional audience for the image
+            last_modified: Optional last modified timestamp for the image
+            priority: Optional priority for the image
         """
-        content = ImageContentBlock(
-            data=data, mime_type=mime_type, uri=uri, annotations=annotations
+        update = AgentMessageChunk.image(
+            data=data,
+            mime_type=mime_type,
+            uri=uri,
+            audience=audience,
+            last_modified=last_modified,
+            priority=priority,
         )
-        update = AgentMessageChunk(content=content)
         notification = SessionNotification(session_id=self.id, update=update)
-        await self.client.session_update(notification)
+        await self.client.session_update(notification)  # pyright: ignore[reportArgumentType]
 
     async def update_session_mode(self, mode_id: str) -> None:
         """Send a session mode update notification.
@@ -571,7 +653,7 @@ class ACPNotifications:
         """
         update = CurrentModeUpdate(current_mode_id=mode_id)
         notification = SessionNotification(session_id=self.id, update=update)
-        await self.client.session_update(notification)
+        await self.client.session_update(notification)  # pyright: ignore[reportArgumentType]
 
     # async def update_session_model(self, model_id: str) -> None:
     #     """Send a session model update notification.
@@ -585,24 +667,31 @@ class ACPNotifications:
 
     async def send_agent_audio(
         self,
-        data: str,
+        data: str | bytes,
         mime_type: str,
         *,
-        annotations: Annotations | None = None,
+        audience: Audience | None = None,
+        last_modified: datetime | str | None = None,
+        priority: float | None = None,
     ) -> None:
         """Send an audio message notification.
 
         Args:
             data: Base64-encoded audio data
             mime_type: MIME type of the audio (e.g., 'audio/wav')
-            annotations: Optional annotations for the audio
+            audience: Optional audience for the audio
+            last_modified: Optional last modified timestamp for the audio
+            priority: Optional priority for the audio
         """
-        content = AudioContentBlock(
-            data=data, mime_type=mime_type, annotations=annotations
+        update = AgentMessageChunk.audio(
+            data=data,
+            mime_type=mime_type,
+            last_modified=last_modified,
+            priority=priority,
+            audience=audience,
         )
-        update = AgentMessageChunk(content=content)
         notification = SessionNotification(session_id=self.id, update=update)
-        await self.client.session_update(notification)
+        await self.client.session_update(notification)  # pyright: ignore[reportArgumentType]
 
     async def send_agent_resource(
         self,
@@ -613,7 +702,9 @@ class ACPNotifications:
         description: str | None = None,
         mime_type: str | None = None,
         size: int | None = None,
-        annotations: Annotations | None = None,
+        audience: Audience | None = None,
+        last_modified: datetime | str | None = None,
+        priority: float | None = None,
     ) -> None:
         """Send a resource reference message notification.
 
@@ -624,17 +715,20 @@ class ACPNotifications:
             description: Optional description of the resource
             mime_type: Optional MIME type of the resource
             size: Optional size of the resource in bytes
-            annotations: Optional annotations for the resource
+            audience: Optional audience for the resource
+            last_modified: Optional last modified timestamp for the resource
+            priority: Optional priority for the resource
         """
-        content = ResourceContentBlock(
+        update = AgentMessageChunk.resource(
             name=name,
             uri=uri,
             title=title,
             description=description,
             mime_type=mime_type,
             size=size,
-            annotations=annotations,
+            audience=audience,
+            last_modified=last_modified,
+            priority=priority,
         )
-        update = AgentMessageChunk(content=content)
         notification = SessionNotification(session_id=self.id, update=update)
-        await self.client.session_update(notification)
+        await self.client.session_update(notification)  # pyright: ignore[reportArgumentType]
