@@ -1,7 +1,7 @@
 from __future__ import annotations
 
 from collections.abc import Sequence  # noqa: TC003
-from typing import Any, Literal
+from typing import Any, Literal, Self
 
 from pydantic import Field
 
@@ -107,9 +107,7 @@ class InitializeResponse(Response):
     See protocol docs: [Initialization](https://agentclientprotocol.com/protocol/initialization)
     """
 
-    agent_capabilities: AgentCapabilities | None = Field(
-        default_factory=AgentCapabilities
-    )
+    agent_capabilities: AgentCapabilities | None = Field(default_factory=AgentCapabilities)
     """Capabilities supported by the agent."""
 
     agent_info: Implementation | None = None
@@ -142,7 +140,7 @@ class InitializeResponse(Response):
         embedded_context_prompts: bool = False,
         image_prompts: bool = False,
         auth_methods: Sequence[AuthMethod] | None = None,
-    ):
+    ) -> Self:
         """Create an instance of AgentCapabilities.
 
         Args:
