@@ -2,6 +2,8 @@
 
 from __future__ import annotations
 
+from typing import Self
+
 from pydantic import Field
 
 from acp.schema.base import AnnotatedObject
@@ -44,7 +46,7 @@ class ClientCapabilities(AnnotatedObject):
         read_text_file: bool | None = False,
         write_text_file: bool | None = False,
         terminal: bool | None = False,
-    ):
+    ) -> Self:
         """Create a new instance of ClientCapabilities.
 
         Args:
@@ -56,9 +58,7 @@ class ClientCapabilities(AnnotatedObject):
             A new instance of ClientCapabilities.
         """
         return cls(
-            fs=FileSystemCapability(
-                read_text_file=read_text_file, write_text_file=write_text_file
-            ),
+            fs=FileSystemCapability(read_text_file=read_text_file, write_text_file=write_text_file),
             terminal=terminal,
         )
 
@@ -117,9 +117,7 @@ class AgentCapabilities(AnnotatedObject):
     mcp_capabilities: McpCapabilities | None = Field(default_factory=McpCapabilities)
     """MCP capabilities supported by the agent."""
 
-    prompt_capabilities: PromptCapabilities | None = Field(
-        default_factory=PromptCapabilities
-    )
+    prompt_capabilities: PromptCapabilities | None = Field(default_factory=PromptCapabilities)
     """Prompt capabilities supported by the agent."""
 
     @classmethod
@@ -131,7 +129,7 @@ class AgentCapabilities(AnnotatedObject):
         audio_prompts: bool = False,
         embedded_context_prompts: bool = False,
         image_prompts: bool = False,
-    ):
+    ) -> Self:
         """Create an instance of AgentCapabilities.
 
         Args:
