@@ -7,9 +7,11 @@ from __future__ import annotations
 
 from importlib.metadata import version
 
-from llmling_agent.config import Capabilities
 from llmling_agent.models import AgentsManifest, AgentConfig
-from llmling_agent.agent import Agent, StructuredAgent, AnyAgent, AgentContext
+
+# Builtin toolsets imports removed to avoid circular dependency
+# Import them directly from llmling_agent_toolsets.builtin when needed
+from llmling_agent.agent import Agent, AgentContext
 from llmling_agent.delegation import AgentPool, Team, TeamRun, BaseTeam
 from dotenv import load_dotenv
 from llmling_agent.messaging.messages import ChatMessage
@@ -41,18 +43,15 @@ __all__ = [
     "AgentContext",
     "AgentPool",
     "AgentsManifest",
-    "AnyAgent",
     "AudioBase64Content",
     "AudioURLContent",
     "BaseTeam",
-    "Capabilities",
     "ChatMessage",
     "ImageBase64Content",
     "ImageURLContent",
     "MessageNode",
     "PDFBase64Content",
     "PDFURLContent",
-    "StructuredAgent",
     "Team",
     "TeamRun",
     "Tool",
