@@ -4,7 +4,7 @@ from __future__ import annotations
 
 from llmling_agent.agent.agent import Agent
 from llmling_agent.agent.context import AgentContext
-from llmling_agent.agent.conversation import ConversationManager
+from llmling_agent.agent.conversation import MessageHistory
 from llmling_agent.agent.interactions import Interactions
 from llmling_agent.agent.slashed_agent import SlashedAgent
 from llmling_agent.agent.sys_prompts import SystemPrompts
@@ -13,8 +13,8 @@ from llmling_agent.agent.sys_prompts import SystemPrompts
 __all__ = [
     "Agent",
     "AgentContext",
-    "ConversationManager",
     "Interactions",
+    "MessageHistory",
     "SlashedAgent",
     "SystemPrompts",
 ]
