@@ -5,15 +5,13 @@ from __future__ import annotations
 from collections import deque
 from contextlib import asynccontextmanager
 from dataclasses import dataclass, field
-from typing import TYPE_CHECKING, Any, Self, overload
+from typing import TYPE_CHECKING, Any, Self, assert_never
 from uuid import UUID, uuid4
 
-from llmling import BasePrompt
 from psygnal import Signal
-from upathtools import read_path
+from upathtools import read_path, to_upath
 
 from llmling_agent.log import get_logger
-from llmling_agent.messaging import ChatMessage, ChatMessageContainer
 from llmling_agent.utils.count_tokens import count_tokens
 from llmling_agent.utils.now import get_now
 from llmling_agent_config.session import SessionQuery
@@ -24,19 +22,21 @@ if TYPE_CHECKING:
     from datetime import datetime
     from types import TracebackType
 
-    from llmling.config.models import Resource
-    from llmling.prompts import PromptType
     from toprompt import AnyPromptType
     from upath.types import JoinablePathLike
 
     from llmling_agent.agent.agent import Agent
     from llmling_agent.common_types import MessageRole, SessionIdType
+    from llmling_agent.messaging import ChatMessage
+    from llmling_agent.prompts.conversion_manager import ConversionManager
+    from llmling_agent.prompts.prompts import PromptType
+    from llmling_agent.storage import StorageManager
     from llmling_agent_config.session import MemoryConfig
 
 logger = get_logger(__name__)
 
 
-class ConversationManager:
+class MessageHistory:
     """Manages conversation state and system prompts."""
 
     @dataclass(frozen=True)
@@ -50,36 +50,44 @@ class ConversationManager:
 
     def __init__(
         self,
-        agent: Agent[Any, Any],
+        storage: StorageManager,
+        converter: ConversionManager,
         session_config: MemoryConfig | None = None,
         *,
-        resources: Sequence[Resource | PromptType | str] = (),
-    ):
+        resources: Sequence[PromptType | str] = (),
+    ) -> None:
         """Initialize conversation manager.
 
         Args:
-            agent: instance to manage
+            storage: Storage manager for persistence
+            converter: Content converter for file processing
             session_config: Optional MemoryConfig
             resources: Optional paths to load as context
         """
-        self._agent = agent
+        from llmling_agent.messaging import ChatMessageContainer
+
+        self._storage = storage
+        self._converter = converter
         self.chat_messages = ChatMessageContainer()
-        self._last_messages: list[ChatMessage] = []
-        self._pending_messages: deque[ChatMessage] = deque()
+        self._last_messages: list[ChatMessage[Any]] = []
+        self._pending_messages: deque[ChatMessage[Any]] = deque()
         self._config = session_config
         self._resources = list(resources)  # Store for async loading
         # Generate new ID if none provided
         self.id = str(uuid4())
 
-        if session_config is not None and session_config.session is not None:
-            storage = self._agent.context.storage
-            self._current_history = storage.filter_messages.sync(session_config.session)
+        if session_config and session_config.session:
+            self._current_history = self.storage.filter_messages.sync(session_config.session)
             if session_config.session.name:
                 self.id = session_config.session.name
 
         # Note: max_messages and max_tokens will be handled in add_message/get_history
         # to maintain the rolling window during conversation
 
+    @property
+    def storage(self) -> StorageManager:
+        return self._storage
+
     def get_initialization_tasks(self) -> list[Coroutine[Any, Any, Any]]:
         """Get all initialization coroutines."""
         self._resources = []  # Clear so we dont load again on async init
@@ -96,7 +104,7 @@ class ConversationManager:
         exc_type: type[BaseException] | None,
         exc_val: BaseException | None,
         exc_tb: TracebackType | None,
-    ):
+    ) -> None:
         """Clean up any pending messages."""
         self._pending_messages.clear()
 
@@ -104,7 +112,7 @@ class ConversationManager:
         return bool(self._pending_messages) or bool(self.chat_messages)
 
     def __repr__(self) -> str:
-        return f"ConversationManager(id={self.id!r})"
+        return f"MessageHistory(id={self.id!r})"
 
     def __prompt__(self) -> str:
         if not self.chat_messages:
@@ -115,35 +123,6 @@ class ConversationManager:
         parts.extend(msg.format() for msg in last_msgs)
         return "\n".join(parts)
 
-    @overload
-    def __getitem__(self, key: int) -> ChatMessage[Any]: ...
-
-    @overload
-    def __getitem__(self, key: slice | str) -> list[ChatMessage[Any]]: ...
-
-    def __getitem__(
-        self, key: int | slice | str
-    ) -> ChatMessage[Any] | list[ChatMessage[Any]]:
-        """Access conversation history.
-
-        Args:
-            key: Either:
-                - Integer index for single message
-                - Slice for message range
-                - Agent name for conversation history with that agent
-        """
-        match key:
-            case int():
-                return self.chat_messages[key]
-            case slice():
-                return list(self.chat_messages[key])
-            case str():
-                query = SessionQuery(name=key)
-                return self._agent.context.storage.filter_messages.sync(query=query)
-            case _:
-                msg = f"Invalid key type: {type(key)}"
-                raise TypeError(msg)
-
     def __contains__(self, item: Any) -> bool:
         """Check if item is in history."""
         return item in self.chat_messages
@@ -152,10 +131,10 @@ class ConversationManager:
         """Get length of history."""
         return len(self.chat_messages)
 
-    def get_message_tokens(self, message: ChatMessage) -> int:
+    def get_message_tokens(self, message: ChatMessage[Any]) -> int:
         """Get token count for a single message."""
         content = "\n".join(message.format())
-        return count_tokens(content, self._agent.model_name)
+        return count_tokens(content, message.model_name)
 
     async def format_history(
         self,
@@ -186,9 +165,6 @@ class ConversationManager:
             history = list(reversed(history))  # Start from newest when token limited
 
         for msg in history:
-            # Check role directly from ChatMessage
-            if not include_system and msg.role == "system":
-                continue
             name = msg.name or msg.role.title()
             formatted = template.format(agent=name, content=str(msg.content))
 
@@ -210,8 +186,10 @@ class ConversationManager:
 
         return "\n".join(messages)
 
-    async def load_context_source(self, source: Resource | PromptType | str):
+    async def load_context_source(self, source: PromptType | str) -> None:
         """Load context from a single source."""
+        from llmling_agent.prompts.prompts import BasePrompt
+
         try:
             match source:
                 case str():
@@ -232,7 +210,7 @@ class ConversationManager:
         until: datetime | None = None,
         roles: set[MessageRole] | None = None,
         limit: int | None = None,
-    ):
+    ) -> None:
         """Load conversation history from database.
 
         Args:
@@ -242,7 +220,6 @@ class ConversationManager:
             roles: Only include messages with these roles (override)
             limit: Maximum number of messages to return (override)
         """
-        storage = self._agent.context.storage
         match session:
             case SessionQuery() as query:
                 # Override query params if provided
@@ -274,17 +251,16 @@ class ConversationManager:
                     roles=roles,
                     limit=limit,
                 )
-            case _:
-                msg = f"Invalid type for session: {type(session)}"
-                raise ValueError(msg)
+            case _ as unreachable:
+                assert_never(unreachable)
         self.chat_messages.clear()
-        self.chat_messages.extend(storage.filter_messages.sync(query))
+        self.chat_messages.extend(self.storage.filter_messages.sync(query))
 
     def get_history(
         self,
         include_pending: bool = True,
         do_filter: bool = True,
-    ) -> list[ChatMessage]:
+    ) -> list[ChatMessage[Any]]:
         """Get conversation history.
 
         Args:
@@ -322,21 +298,23 @@ class ConversationManager:
 
         return list(history)
 
-    def get_pending_messages(self) -> list[ChatMessage]:
+    def get_pending_messages(self) -> list[ChatMessage[Any]]:
         """Get messages that will be included in next interaction."""
         return list(self._pending_messages)
 
-    def clear_pending(self):
+    def clear_pending(self) -> None:
         """Clear pending messages without adding them to history."""
         self._pending_messages.clear()
 
-    def set_history(self, history: list[ChatMessage]):
+    def set_history(self, history: list[ChatMessage[Any]]) -> None:
         """Update conversation history after run."""
         self.chat_messages.clear()
         self.chat_messages.extend(history)
 
-    def clear(self):
+    def clear(self) -> None:
         """Clear conversation history and prompts."""
+        from llmling_agent.messaging import ChatMessageContainer
+
         self.chat_messages = ChatMessageContainer()
         self._last_messages = []
         event = self.HistoryCleared(session_id=str(self.id))
@@ -361,11 +339,13 @@ class ConversationManager:
 
         old_history = self.chat_messages.copy()
 
+        from llmling_agent.messaging import ChatMessage, ChatMessageContainer
+
         try:
             messages: Sequence[ChatMessage[Any]] = ChatMessageContainer()
             if history is not None:
                 if isinstance(history, SessionQuery):
-                    messages = await self._agent.context.storage.filter_messages(history)
+                    messages = await self.storage.filter_messages(history)
                 else:
                     messages = [
                         ChatMessage.user_prompt(message=prompt)
@@ -383,13 +363,13 @@ class ConversationManager:
         finally:
             self.chat_messages = old_history
 
-    def add_chat_messages(self, messages: Sequence[ChatMessage]):
+    def add_chat_messages(self, messages: Sequence[ChatMessage[Any]]) -> None:
         """Add new messages to history and update last_messages."""
         self._last_messages = list(messages)
         self.chat_messages.extend(messages)
 
     @property
-    def last_run_messages(self) -> list[ChatMessage]:
+    def last_run_messages(self) -> list[ChatMessage[Any]]:
         """Get messages from the last run converted to our format."""
         return self._last_messages
 
@@ -398,7 +378,7 @@ class ConversationManager:
         content: str,
         source: str | None = None,
         **metadata: Any,
-    ):
+    ) -> None:
         """Add a context message.
 
         Args:
@@ -406,6 +386,8 @@ class ConversationManager:
             source: Description of content source
             **metadata: Additional metadata to include with the message
         """
+        from llmling_agent.messaging import ChatMessage
+
         meta_str = ""
         if metadata:
             meta_str = "\n".join(f"{k}: {v}" for k, v in metadata.items())
@@ -422,8 +404,6 @@ class ConversationManager:
             conversation_id="context",  # TODO: should probably allow DB field to be NULL
         )
         self._pending_messages.append(chat_message)
-        # Emit as user message - will trigger logging through existing flow
-        self._agent.message_received.emit(chat_message)
 
     async def add_context_from_path(
         self,
@@ -431,7 +411,7 @@ class ConversationManager:
         *,
         convert_to_md: bool = False,
         **metadata: Any,
-    ):
+    ) -> None:
         """Add file or URL content as context message.
 
         Args:
@@ -442,11 +422,9 @@ class ConversationManager:
         Raises:
             ValueError: If content cannot be loaded or converted
         """
-        from upathtools import to_upath
-
         path_obj = to_upath(path)
         if convert_to_md:
-            content = await self._agent.context.converter.convert_file(path)
+            content = await self._converter.convert_file(path)
             source = f"markdown:{path_obj.name}"
         else:
             content = await read_path(path)
@@ -458,7 +436,7 @@ class ConversationManager:
         prompt: PromptType,
         metadata: dict[str, Any] | None = None,
         **kwargs: Any,
-    ):
+    ) -> None:
         """Add rendered prompt content as context message.
 
         Args:
@@ -485,18 +463,13 @@ class ConversationManager:
     def get_history_tokens(self) -> int:
         """Get token count for current history."""
         # Use cost_info if available
-        return self.chat_messages.get_history_tokens(self._agent.model_name)
-
-    def get_pending_tokens(self) -> int:
-        """Get token count for pending messages."""
-        text = "\n".join(msg.format() for msg in self._pending_messages)
-        return count_tokens(text, self._agent.model_name)
+        return self.chat_messages.get_history_tokens()
 
 
 if __name__ == "__main__":
     from llmling_agent import Agent
 
-    async def main():
+    async def main() -> None:
         async with Agent() as agent:
             await agent.conversation.add_context_from_path("E:/mcp_zed.yml")
             print(agent.conversation.get_history())
