@@ -87,7 +87,7 @@ def get_label(item: Any) -> str:
 class Interactions[TDeps, TResult]:
     """Manages agent communication patterns."""
 
-    def __init__(self, agent: Agent[TDeps, TResult]):
+    def __init__(self, agent: Agent[TDeps, TResult]) -> None:
         self.agent = agent
 
     async def conversation(
@@ -96,8 +96,7 @@ class Interactions[TDeps, TResult]:
         initial_message: AnyPromptType,
         *,
         max_rounds: int | None = None,
-        end_condition: Callable[[list[ChatMessage[Any]], ChatMessage[Any]], bool]
-        | None = None,
+        end_condition: Callable[[list[ChatMessage[Any]], ChatMessage[Any]], bool] | None = None,
         store_history: bool = True,
     ) -> AsyncIterator[ChatMessage[Any]]:
         """Maintain conversation between two agents.
@@ -122,9 +121,7 @@ class Interactions[TDeps, TResult]:
                 logger.debug("Conversation ended", max_rounds=max_rounds)
                 return
 
-            response = await current_node.run(
-                current_message, store_history=store_history
-            )
+            response = await current_node.run(current_message, store_history=store_history)
             messages.append(response)
             yield response
 
@@ -137,30 +134,6 @@ class Interactions[TDeps, TResult]:
             current_message = response.content
             rounds += 1
 
-    @overload
-    async def pick[T: AnyPromptType](
-        self,
-        selections: Sequence[T],
-        task: str,
-        prompt: AnyPromptType | None = None,
-    ) -> Pick[T]: ...
-
-    @overload
-    async def pick[T: AnyPromptType](
-        self,
-        selections: Sequence[T],
-        task: str,
-        prompt: AnyPromptType | None = None,
-    ) -> Pick[T]: ...
-
-    @overload
-    async def pick[T: AnyPromptType](
-        self,
-        selections: Mapping[str, T],
-        task: str,
-        prompt: AnyPromptType | None = None,
-    ) -> Pick[T]: ...
-
     @overload
     async def pick(
         self,
@@ -177,6 +150,14 @@ class Interactions[TDeps, TResult]:
         prompt: AnyPromptType | None = None,
     ) -> Pick[MessageNode[TDeps, Any]]: ...
 
+    @overload
+    async def pick[T: AnyPromptType](
+        self,
+        selections: Sequence[T] | Mapping[str, T],
+        task: str,
+        prompt: AnyPromptType | None = None,
+    ) -> Pick[T]: ...
+
     async def pick[T](
         self,
         selections: Sequence[T] | Mapping[str, T] | AgentPool | BaseTeam[TDeps, Any],
@@ -250,28 +231,6 @@ Select ONE option by its exact label."""
         selected = cast(T, label_map[result.content.selection])
         return Pick(selection=selected, reason=result.content.reason)
 
-    @overload
-    async def pick_multiple[T: AnyPromptType](
-        self,
-        selections: Sequence[T],
-        task: str,
-        *,
-        min_picks: int = 1,
-        max_picks: int | None = None,
-        prompt: AnyPromptType | None = None,
-    ) -> MultiPick[T]: ...
-
-    @overload
-    async def pick_multiple[T: AnyPromptType](
-        self,
-        selections: Mapping[str, T],
-        task: str,
-        *,
-        min_picks: int = 1,
-        max_picks: int | None = None,
-        prompt: AnyPromptType | None = None,
-    ) -> MultiPick[T]: ...
-
     @overload
     async def pick_multiple(
         self,
@@ -294,6 +253,17 @@ Select ONE option by its exact label."""
         prompt: AnyPromptType | None = None,
     ) -> MultiPick[Agent[Any, Any]]: ...
 
+    @overload
+    async def pick_multiple[T: AnyPromptType](
+        self,
+        selections: Sequence[T] | Mapping[str, T],
+        task: str,
+        *,
+        min_picks: int = 1,
+        max_picks: int | None = None,
+        prompt: AnyPromptType | None = None,
+    ) -> MultiPick[T]: ...
+
     async def pick_multiple[T](
         self,
         selections: Sequence[T] | Mapping[str, T] | AgentPool | BaseTeam[TDeps, Any],
@@ -429,7 +399,7 @@ List your selections, one per line, followed by your reasoning."""
             description_override=schema["description"],
             # schema_override=schema,
         )
-        with self.agent.tools.temporary_tools(tool, exclusive=not include_tools):
+        async with self.agent.tools.temporary_tools(tool, exclusive=not include_tools):
             result = await self.agent.run(final_prompt, output_type=item_model)  # type: ignore
         return result.content  # type: ignore
 
