@@ -12,7 +12,7 @@ if TYPE_CHECKING:
     from toprompt import AnyPromptType
 
     from llmling_agent.agent import Agent
-    from llmling_agent.agent.context import AgentContext
+    from llmling_agent.prompts.manager import PromptManager
 
 
 ToolInjectionMode = Literal["off", "all"]
@@ -33,7 +33,7 @@ You MUST use these tools to complete your tasks:
 You have access to these tools:
 {%- endif %}
 {% for tool in tools %}
-- {{ tool.name }}{% if tool.description %}: {{ tool.description }}{% endif %}{% if tool.requires_capability %} (requires {{ tool.requires_capability }}){% endif %}
+- {{ tool.name }}{% if tool.description %}: {{ tool.description }}{% endif %}
 {%- endfor %}
 
 {%- if tool_usage_style == "strict" %}
@@ -60,11 +60,11 @@ class SystemPrompts:
         prompts: AnyPromptType | list[AnyPromptType] | None = None,
         template: str | None = None,
         dynamic: bool = True,
-        context: AgentContext | None = None,
+        prompt_manager: PromptManager | None = None,
         inject_agent_info: bool = True,
         inject_tools: ToolInjectionMode = "off",
         tool_usage_style: ToolUsageStyle = "suggestive",
-    ):
+    ) -> None:
         """Initialize prompt manager."""
         from jinjarope import Environment
         from toprompt import to_prompt
@@ -76,7 +76,7 @@ class SystemPrompts:
                 self.prompts = []
             case _:
                 self.prompts = [prompts]
-        self.context = context
+        self.prompt_manager = prompt_manager
         self.template = template
         self.dynamic = dynamic
         self.inject_agent_info = inject_agent_info
@@ -99,7 +99,7 @@ class SystemPrompts:
     def __getitem__(self, idx: int | slice) -> AnyPromptType | list[AnyPromptType]:
         return self.prompts[idx]
 
-    async def add_by_reference(self, reference: str):
+    async def add_by_reference(self, reference: str) -> None:
         """Add a system prompt using reference syntax.
 
         Args:
@@ -109,12 +109,12 @@ class SystemPrompts:
             await sys_prompts.add_by_reference("code_review?language=python")
             await sys_prompts.add_by_reference("langfuse:expert@v2")
         """
-        if not self.context:
-            msg = "No context available to resolve prompts"
+        if not self.prompt_manager:
+            msg = "No prompt_manager available to resolve prompts"
             raise RuntimeError(msg)
 
         try:
-            content = await self.context.prompt_manager.get(reference)
+            content = await self.prompt_manager.get(reference)
             self.prompts.append(content)
         except Exception as e:
             msg = f"Failed to add prompt {reference!r}"
@@ -127,8 +127,8 @@ class SystemPrompts:
         provider: str | None = None,
         version: str | None = None,
         variables: dict[str, Any] | None = None,
-    ):
-        """Add a system prompt using explicit parameters.
+    ) -> None:
+        """Add a system prompt.
 
         Args:
             identifier: Prompt identifier/name
@@ -140,12 +140,12 @@ class SystemPrompts:
             await sys_prompts.add("code_review", variables={"language": "python"})
             await sys_prompts.add("expert", provider="langfuse", version="v2")
         """
-        if not self.context:
-            msg = "No context available to resolve prompts"
+        if not self.prompt_manager:
+            msg = "No prompt_manager available to resolve prompts"
             raise RuntimeError(msg)
 
         try:
-            content = await self.context.prompt_manager.get_from(
+            content = await self.prompt_manager.get_from(
                 identifier,
                 provider=provider,
                 version=version,
@@ -157,11 +157,11 @@ class SystemPrompts:
             msg = f"Failed to add prompt {ref!r}"
             raise RuntimeError(msg) from e
 
-    def clear(self):
+    def clear(self) -> None:
         """Clear all system prompts."""
         self.prompts = []
 
-    async def refresh_cache(self):
+    async def refresh_cache(self) -> None:
         """Force re-evaluation of prompts."""
         from toprompt import to_prompt
 
