@@ -6,7 +6,7 @@ from abc import abstractmethod
 import asyncio
 from contextlib import AsyncExitStack, asynccontextmanager
 from dataclasses import dataclass
-from typing import TYPE_CHECKING, Any, Literal, Self, overload
+from typing import TYPE_CHECKING, Any, Self, overload
 
 from psygnal.containers import EventedList
 
@@ -42,7 +42,7 @@ logger = get_logger(__name__)
 
 
 @dataclass(kw_only=True)
-class TeamContext[TDeps](NodeContext[TDeps]):
+class TeamContext[TDeps = object](NodeContext[TDeps]):
     """Context for team nodes."""
 
     config: TeamConfig
@@ -51,26 +51,6 @@ class TeamContext[TDeps](NodeContext[TDeps]):
     pool: AgentPool | None = None
     """Pool the team is part of."""
 
-    @classmethod
-    def create_default(
-        cls,
-        name: str,
-        mode: Literal["sequential", "parallel"] = "sequential",
-        pool: AgentPool | None = None,
-    ) -> TeamContext:
-        """Create a default agent context with minimal privileges.
-
-        Args:
-            name: Name of the agent
-            mode: Execution mode (sequential or parallel)
-            pool:(optional): Optional pool the agent is part of
-        """
-        from llmling_agent_config import TeamConfig
-
-        cfg = TeamConfig(name=name, mode=mode, members=[])
-        defn = AgentsManifest()
-        return cls(node_name=name, config=cfg, pool=pool, definition=defn)
-
 
 class BaseTeam[TDeps, TResult](MessageNode[TDeps, TResult]):
     """Base class for Team and TeamRun."""
@@ -86,25 +66,28 @@ class BaseTeam[TDeps, TResult](MessageNode[TDeps, TResult]):
         picker: Agent[Any, Any] | None = None,
         num_picks: int | None = None,
         pick_prompt: str | None = None,
-    ):
+    ) -> None:
         """Common variables only for typing."""
         from llmling_agent.delegation.teamrun import ExtendedTeamTalk
 
         self._name = name or " & ".join([i.name for i in agents])
-        self.agents = EventedList[MessageNode]()
+        self.agents = EventedList[MessageNode[Any, Any]]()
         self.agents.events.inserted.connect(self._on_node_added)
         self.agents.events.removed.connect(self._on_node_removed)
         self.agents.events.changed.connect(self._on_node_changed)
+        mcp_servers = list(mcp_servers) if mcp_servers else []
+        if self.context and (cfg := self.context.config) and cfg.mcp_servers:
+            mcp_servers.extend(cfg.get_mcp_servers())
         super().__init__(
             name=self._name,
-            context=self.context,
+            input_provider=self.context.get_input_provider(),
             mcp_servers=mcp_servers,
             description=description,
         )
         self.agents.extend(list(agents))
         self._team_talk = ExtendedTeamTalk()
         self.shared_prompt = shared_prompt
-        self._main_task: asyncio.Task[Any] | None = None
+        self._main_task: asyncio.Task[ChatMessage[Any] | None] | None = None
         self._infinite = False
         self.picker = picker
         self.num_picks = num_picks
@@ -152,24 +135,30 @@ class BaseTeam[TDeps, TResult](MessageNode[TDeps, TResult]):
             return multi_result.selections
         return list(self.agents)
 
-    def _on_node_changed(self, index: int, old: MessageNode, new: MessageNode):
+    def _on_node_changed(
+        self, index: int, old: MessageNode[Any, Any], new: MessageNode[Any, Any]
+    ) -> None:
         """Handle node replacement in the agents list."""
         self._on_node_removed(index, old)
         self._on_node_added(index, new)
 
-    def _on_node_added(self, index: int, node: MessageNode[Any, Any]):
-        """Handler for adding nodes to the team."""
+    def _on_node_added(self, index: int, node: MessageNode[Any, Any]) -> None:
+        """Handler for adding new nodes to the team."""
         from llmling_agent.agent import Agent
 
         if isinstance(node, Agent):
-            node.tools.add_provider(self.mcp)
+            # Add MCP aggregating provider from manager
+            aggregating_provider = self.mcp.get_aggregating_provider()
+            node.tools.add_provider(aggregating_provider)
 
-    def _on_node_removed(self, index: int, node: MessageNode[Any, Any]):
+    def _on_node_removed(self, index: int, node: MessageNode[Any, Any]) -> None:
         """Handler for removing nodes from the team."""
         from llmling_agent.agent import Agent
 
         if isinstance(node, Agent):
-            node.tools.remove_provider(self.mcp)
+            # Remove MCP aggregating provider
+            aggregating_provider = self.mcp.get_aggregating_provider()
+            node.tools.remove_provider(aggregating_provider.name)
 
     def __repr__(self) -> str:
         """Create readable representation."""
@@ -229,9 +218,7 @@ class BaseTeam[TDeps, TResult](MessageNode[TDeps, TResult]):
     @overload
     def __and__(self, other: Agent[Any, Any]) -> Team[Any]: ...
 
-    def __and__(
-        self, other: Team[Any] | Agent[Any, Any] | ProcessorCallback[Any]
-    ) -> Team[Any]:
+    def __and__(self, other: Team[Any] | Agent[Any, Any] | ProcessorCallback[Any]) -> Team[Any]:
         """Combine teams, preserving type safety for same types."""
         from llmling_agent.agent import Agent
         from llmling_agent.delegation.team import Team
@@ -262,7 +249,7 @@ class BaseTeam[TDeps, TResult](MessageNode[TDeps, TResult]):
         """Check if team is processing any tasks."""
         return bool(self.task_manager._pending_tasks or self._main_task)
 
-    async def stop(self):
+    async def stop(self) -> None:
         """Stop background execution if running."""
         if self._main_task and not self._main_task.done():
             self._main_task.cancel()
@@ -319,9 +306,7 @@ class BaseTeam[TDeps, TResult](MessageNode[TDeps, TResult]):
                     break
             return last_message
 
-        self._main_task = self.task_manager.create_task(
-            _continuous(), name="main_execution"
-        )
+        self._main_task = self.task_manager.create_task(_continuous(), name="main_execution")
         return self._team_talk
 
     @property
@@ -339,7 +324,7 @@ class BaseTeam[TDeps, TResult](MessageNode[TDeps, TResult]):
         """Get events for the team."""
         return self.agents.events
 
-    async def cancel(self):
+    async def cancel(self) -> None:
         """Cancel execution and cleanup."""
         if self._main_task:
             self._main_task.cancel()
@@ -349,7 +334,7 @@ class BaseTeam[TDeps, TResult](MessageNode[TDeps, TResult]):
         """Generate mermaid flowchart of node hierarchy."""
         lines = ["flowchart TD"]
 
-        def add_node(node: MessageNode[Any, Any], parent: str | None = None):
+        def add_node(node: MessageNode[Any, Any], parent: str | None = None) -> None:
             """Recursively add node and its members to diagram."""
             node_id = f"node_{id(node)}"
             lines.append(f"    {node_id}[{node.name}]")
@@ -397,7 +382,7 @@ class BaseTeam[TDeps, TResult](MessageNode[TDeps, TResult]):
         team_config: TeamConfig | None = None
 
         for agent in self.iter_agents():
-            if agent.context and agent.context.pool:
+            if agent.context.pool:
                 pool_id = id(agent.context.pool)
                 if pool_id not in pool_ids:
                     pool_ids.add(pool_id)
@@ -427,7 +412,7 @@ class BaseTeam[TDeps, TResult](MessageNode[TDeps, TResult]):
         )
 
     @context.setter
-    def context(self, value: NodeContext):
+    def context(self, value: NodeContext) -> None:
         msg = "Cannot set context on BaseTeam"
         raise RuntimeError(msg)
 
@@ -438,7 +423,7 @@ class BaseTeam[TDeps, TResult](MessageNode[TDeps, TResult]):
         tools: list[str] | None = None,
         resources: list[str] | None = None,
         metadata: dict[str, Any] | None = None,
-    ):
+    ) -> None:
         """Distribute content and capabilities to all team members."""
         for agent in self.iter_agents():
             # Add context message
@@ -519,7 +504,7 @@ class BaseTeam[TDeps, TResult](MessageNode[TDeps, TResult]):
 
 if __name__ == "__main__":
 
-    async def main():
+    async def main() -> None:
         from llmling_agent import Agent, Team
 
         agent = Agent("My Agent")
