@@ -6,9 +6,9 @@ import asyncio
 from asyncio import Lock
 from contextlib import AsyncExitStack, asynccontextmanager, suppress
 import os
-from typing import TYPE_CHECKING, Any, Self, Unpack, cast, overload
+from typing import TYPE_CHECKING, Any, Self, Unpack, overload
 
-from anyenv import MultiEventHandler
+from anyenv import ProcessManager
 from upath import UPath
 
 from llmling_agent.agent import Agent
@@ -17,9 +17,8 @@ from llmling_agent.delegation.message_flow_tracker import MessageFlowTracker
 from llmling_agent.delegation.team import Team
 from llmling_agent.delegation.teamrun import TeamRun
 from llmling_agent.log import get_logger
-from llmling_agent.messaging import MessageEmitter
-from llmling_agent.messaging.context import ProgressCallback
-from llmling_agent.talk import Talk, TeamTalk
+from llmling_agent.messaging import MessageNode
+from llmling_agent.talk import TeamTalk
 from llmling_agent.talk.registry import ConnectionRegistry
 from llmling_agent.tasks import TaskRegistry
 from llmling_agent.utils.baseregistry import BaseRegistry
@@ -38,24 +37,22 @@ if TYPE_CHECKING:
 
     from psygnal.containers._evented_dict import DictEvents
     from pydantic_ai.output import OutputSpec
+    from tokonomics import ModelName
     from upath.types import JoinablePathLike
 
     from llmling_agent.agent.agent import AgentKwargs
-    from llmling_agent.common_types import AgentName, SessionIdType
+    from llmling_agent.common_types import AgentName, IndividualEventHandler, SessionIdType
     from llmling_agent.delegation.base_team import BaseTeam
-    from llmling_agent.messaging.eventnode import EventNode
-    from llmling_agent.messaging.messagenode import MessageNode
     from llmling_agent.models.manifest import AgentsManifest
-    from llmling_agent_config.output_types import StructuredResponseConfig
+    from llmling_agent.ui.base import InputProvider
     from llmling_agent_config.session import SessionQuery
     from llmling_agent_config.task import Job
-    from llmling_agent_input.base import InputProvider
 
 
 logger = get_logger(__name__)
 
 
-class AgentPool[TPoolDeps = None](BaseRegistry[NodeName, MessageEmitter[Any, Any]]):
+class AgentPool[TPoolDeps = None](BaseRegistry[NodeName, MessageNode[Any, Any]]):
     """Pool managing message processing nodes (agents and teams).
 
     Acts as a unified registry for all nodes, providing:
@@ -74,21 +71,21 @@ class AgentPool[TPoolDeps = None](BaseRegistry[NodeName, MessageEmitter[Any, Any
         self,
         manifest: JoinablePathLike | AgentsManifest | None = None,
         *,
-        shared_deps: TPoolDeps | None = None,
+        shared_deps_type: type[TPoolDeps] | None = None,
         connect_nodes: bool = True,
         input_provider: InputProvider | None = None,
         parallel_load: bool = True,
-        progress_handlers: list[ProgressCallback] | None = None,
+        event_handlers: list[IndividualEventHandler] | None = None,
     ):
         """Initialize agent pool with immediate agent creation.
 
         Args:
             manifest: Agent configuration manifest
-            shared_deps: Dependencies to share across all nodes
+            shared_deps_type: Dependencies to share across all nodes
             connect_nodes: Whether to set up forwarding connections
             input_provider: Input provider for tool / step confirmations / HumanAgents
             parallel_load: Whether to load nodes in parallel (async)
-            progress_handlers: List of progress handlers to notify about progress
+            event_handlers: Event handlers to pass through to all agents
 
         Raises:
             ValueError: If manifest contains invalid node configurations
@@ -97,6 +94,8 @@ class AgentPool[TPoolDeps = None](BaseRegistry[NodeName, MessageEmitter[Any, Any
         super().__init__()
         from llmling_agent.mcp_server.manager import MCPManager
         from llmling_agent.models.manifest import AgentsManifest
+        from llmling_agent.observability import registry
+        from llmling_agent.skills.manager import SkillsManager
         from llmling_agent.storage import StorageManager
 
         match manifest:
@@ -109,42 +108,42 @@ class AgentPool[TPoolDeps = None](BaseRegistry[NodeName, MessageEmitter[Any, Any
             case _:
                 msg = f"Invalid config path: {manifest}"
                 raise ValueError(msg)
-        self.shared_deps = shared_deps
+
+        registry.configure_observability(self.manifest.observability)
+        self.shared_deps_type = shared_deps_type
         self._input_provider = input_provider
         self.exit_stack = AsyncExitStack()
         self.parallel_load = parallel_load
         self.storage = StorageManager(self.manifest.storage)
-        self.progress_handlers = MultiEventHandler[ProgressCallback](progress_handlers)
+        self.event_handlers = event_handlers or []
         self.connection_registry = ConnectionRegistry()
         servers = self.manifest.get_mcp_servers()
         self.mcp = MCPManager(name="pool_mcp", servers=servers, owner="pool")
+        self.skills = SkillsManager(name="pool_skills", owner="pool")
         self._tasks = TaskRegistry()
         # Register tasks from manifest
         for name, task in self.manifest.jobs.items():
             self._tasks.register(name, task)
-
-        # Initialize process manager for background processes
-        from anyenv import ProcessManager
-
         self.process_manager = ProcessManager()
         self.pool_talk = TeamTalk[Any].from_nodes(list(self.nodes.values()))
-        # MCP server is now managed externally
-        self.server = None
         # Create requested agents immediately
         for name in self.manifest.agents:
-            agent = self.manifest.get_agent(name, deps=shared_deps)
+            agent = self.manifest.get_agent(
+                name,
+                deps_type=shared_deps_type,
+                input_provider=self._input_provider,
+                pool=self,
+                event_handlers=self.event_handlers,
+            )
             self.register(name, agent)
 
-        # Then set up worker relationships
         for agent in self.agents.values():
             self.setup_agent_workers(agent)
         self._create_teams()
-        # Set up forwarding connections
         if connect_nodes:
             self._connect_nodes()
 
-        # Initialize async safety fields
-        self._enter_lock = Lock()
+        self._enter_lock = Lock()  # Initialize async safety fields
         self._running_count = 0
 
     async def __aenter__(self) -> Self:
@@ -152,15 +151,20 @@ class AgentPool[TPoolDeps = None](BaseRegistry[NodeName, MessageEmitter[Any, Any
         async with self._enter_lock:
             if self._running_count == 0:
                 try:
-                    # Add MCP tool provider to all agents
+                    # Initialize MCP manager first, then add aggregating provider
+                    await self.exit_stack.enter_async_context(self.mcp)
+                    await self.exit_stack.enter_async_context(self.skills)
+                    aggregating_provider = self.mcp.get_aggregating_provider()
+                    skills_provider = self.skills.get_skills_provider()
+
                     agents = list(self.agents.values())
                     teams = list(self.teams.values())
                     for agent in agents:
-                        agent.tools.add_provider(self.mcp)
+                        agent.tools.add_provider(aggregating_provider)
+                        agent.tools.add_provider(skills_provider)
 
-                    # Collect all components to initialize
+                    # Collect remaining components to initialize (MCP already initialized)
                     components: list[AbstractAsyncContextManager[Any]] = [
-                        self.mcp,
                         self.storage,
                         *agents,
                         *teams,
@@ -189,7 +193,7 @@ class AgentPool[TPoolDeps = None](BaseRegistry[NodeName, MessageEmitter[Any, Any
         exc_type: type[BaseException] | None,
         exc_val: BaseException | None,
         exc_tb: TracebackType | None,
-    ):
+    ) -> None:
         """Exit async context."""
         if self._running_count == 0:
             msg = "AgentPool.__aexit__ called more times than __aenter__"
@@ -197,10 +201,12 @@ class AgentPool[TPoolDeps = None](BaseRegistry[NodeName, MessageEmitter[Any, Any
         async with self._enter_lock:
             self._running_count -= 1
             if self._running_count == 0:
-                # Remove MCP tool provider from all agents
+                # Remove MCP aggregating provider from all agents
+                aggregating_provider = self.mcp.get_aggregating_provider()
+                skills_provider = self.skills.get_skills_provider()
                 for agent in self.agents.values():
-                    if self.mcp in agent.tools.providers:
-                        agent.tools.remove_provider(self.mcp)
+                    agent.tools.remove_provider(aggregating_provider.name)
+                    agent.tools.remove_provider(skills_provider.name)
                 await self.cleanup()
 
     @property
@@ -208,7 +214,7 @@ class AgentPool[TPoolDeps = None](BaseRegistry[NodeName, MessageEmitter[Any, Any
         """Check if the agent pool is running."""
         return bool(self._running_count)
 
-    async def cleanup(self):
+    async def cleanup(self) -> None:
         """Clean up all agents."""
         # Clean up background processes first
         await self.process_manager.cleanup()
@@ -386,7 +392,7 @@ class AgentPool[TPoolDeps = None](BaseRegistry[NodeName, MessageEmitter[Any, Any
         finally:
             self.connection_registry.message_flow.disconnect(tracker.track)
 
-    async def run_event_loop(self):
+    async def run_event_loop(self) -> None:
         """Run pool in event-watching mode until interrupted."""
         print("Starting event watch mode...")
         print("Active nodes: ", ", ".join(self.list_nodes()))
@@ -415,21 +421,12 @@ class AgentPool[TPoolDeps = None](BaseRegistry[NodeName, MessageEmitter[Any, Any
 
         return {i.name: i for i in self._items.values() if isinstance(i, MessageNode)}
 
-    @property
-    def event_nodes(self) -> dict[str, EventNode[Any]]:
-        """Get agents dict (backward compatibility)."""
-        from llmling_agent.messaging.eventnode import EventNode
-
-        return {i.name: i for i in self._items.values() if isinstance(i, EventNode)}
-
     @property
     def node_events(self) -> DictEvents:
         """Get node events."""
         return self._items.events
 
-    def _validate_item(
-        self, item: MessageEmitter[Any, Any] | Any
-    ) -> MessageEmitter[Any, Any]:
+    def _validate_item(self, item: MessageNode[Any, Any] | Any) -> MessageNode[Any, Any]:
         """Validate and convert items before registration.
 
         Args:
@@ -441,26 +438,22 @@ class AgentPool[TPoolDeps = None](BaseRegistry[NodeName, MessageEmitter[Any, Any
         Raises:
             LLMlingError: If item is not a valid node
         """
-        if not isinstance(item, MessageEmitter):
+        if not isinstance(item, MessageNode):
             msg = f"Item must be Agent or Team, got {type(item)}"
             raise self._error_class(msg)
         item.context.pool = self
         return item
 
-    def _create_teams(self):
+    def _create_teams(self) -> None:
         """Create all teams in two phases to allow nesting."""
         # Phase 1: Create empty teams
 
         empty_teams: dict[str, BaseTeam[Any, Any]] = {}
         for name, config in self.manifest.teams.items():
             if config.mode == "parallel":
-                empty_teams[name] = Team(
-                    [], name=name, shared_prompt=config.shared_prompt
-                )
+                empty_teams[name] = Team([], name=name, shared_prompt=config.shared_prompt)
             else:
-                empty_teams[name] = TeamRun(
-                    [], name=name, shared_prompt=config.shared_prompt
-                )
+                empty_teams[name] = TeamRun([], name=name, shared_prompt=config.shared_prompt)
 
         # Phase 2: Resolve members
         for name, config in self.manifest.teams.items():
@@ -477,7 +470,7 @@ class AgentPool[TPoolDeps = None](BaseRegistry[NodeName, MessageEmitter[Any, Any
             team.agents.extend(members)
             self[name] = team
 
-    def _connect_nodes(self):
+    def _connect_nodes(self) -> None:
         """Set up connections defined in manifest."""
         # Merge agent and team configs into one dict of nodes with connections
         for name, config in self.manifest.nodes.items():
@@ -499,7 +492,7 @@ class AgentPool[TPoolDeps = None](BaseRegistry[NodeName, MessageEmitter[Any, Any
                         raise ValueError(msg)
 
                 source.connect_to(
-                    target_node,  # type: ignore  # recognized as "Any | BaseTeam[Any, Any]" by mypy?
+                    target_node,
                     connection_type=target.connection_type,
                     name=name,
                     priority=target.priority,
@@ -510,170 +503,15 @@ class AgentPool[TPoolDeps = None](BaseRegistry[NodeName, MessageEmitter[Any, Any
                     filter_condition=target.filter_condition.check
                     if target.filter_condition
                     else None,
-                    stop_condition=target.stop_condition.check
-                    if target.stop_condition
-                    else None,
-                    exit_condition=target.exit_condition.check
-                    if target.exit_condition
-                    else None,
+                    stop_condition=target.stop_condition.check if target.stop_condition else None,
+                    exit_condition=target.exit_condition.check if target.exit_condition else None,
                 )
                 source.connections.set_wait_state(
                     target_node,
                     wait=target.wait_for_completion,
                 )
 
-    # async def clone_agent[TDeps, TAgentResult](
-    #     self,
-    #     agent: AgentName | Agent[TDeps, TAgentResult],
-    #     new_name: AgentName | None = None,
-    #     *,
-    #     system_prompts: list[str] | None = None,
-    #     template_context: dict[str, Any] | None = None,
-    # ) -> Agent[TDeps, TAgentResult]:
-    #     """Create a copy of an agent.
-
-    #     Args:
-    #         agent: Agent instance or name to clone
-    #         new_name: Optional name for the clone
-    #         system_prompts: Optional different prompts
-    #         template_context: Variables for template rendering
-
-    #     Returns:
-    #         The new agent instance
-    #     """
-    #     from llmling_agent.agent import Agent
-
-    #     # Get original config
-    #     if isinstance(agent, str):
-    #         if agent not in self.manifest.agents:
-    #             msg = f"Agent {agent} not found"
-    #             raise KeyError(msg)
-    #         config = self.manifest.agents[agent]
-    #         original_agent: Agent[Any, Any] = self.get_agent(agent)
-    #     else:
-    #         config = agent.context.config  # type: ignore
-    #         original_agent = agent
-
-    #     # Create new config
-    #     new_cfg = config.model_copy(deep=True)
-
-    #     # Apply overrides
-    #     if system_prompts:
-    #         new_cfg.system_prompts = system_prompts
-
-    #     # Handle template rendering
-    #     if template_context:
-    #         new_cfg.system_prompts = new_cfg.render_system_prompts(template_context)
-
-    #     # Create new agent with same runtime
-    #     new_agent = Agent[TDeps](
-    #         runtime=original_agent.runtime,
-    #         context=original_agent.context,
-    #         output_type=original_agent._output_type,
-    #         # output_type=original_agent.actual_type,
-    #         provider=new_cfg.get_provider(),
-    #         system_prompt=new_cfg.system_prompts,
-    #         name=new_name or f"{config.name}_copy_{len(self.agents)}",
-    #     )
-    #     # Register in pool
-    #     agent_name = new_agent.name
-    #     self.manifest.agents[agent_name] = new_cfg
-    #     self.register(agent_name, new_agent)
-    #     return await self.exit_stack.enter_async_context(new_agent)
-
-    @overload
-    async def create_agent(
-        self,
-        name: AgentName,
-        *,
-        session: SessionIdType | SessionQuery = None,
-        name_override: str | None = None,
-    ) -> Agent[TPoolDeps]: ...
-
-    @overload
-    async def create_agent[TCustomDeps](
-        self,
-        name: AgentName,
-        *,
-        deps: TCustomDeps,
-        session: SessionIdType | SessionQuery = None,
-        name_override: str | None = None,
-    ) -> Agent[TCustomDeps]: ...
-
-    @overload
-    async def create_agent[TResult](
-        self,
-        name: AgentName,
-        *,
-        return_type: type[TResult],
-        session: SessionIdType | SessionQuery = None,
-        name_override: str | None = None,
-    ) -> Agent[TPoolDeps, TResult]: ...
-
-    @overload
-    async def create_agent[TCustomDeps, TResult](
-        self,
-        name: AgentName,
-        *,
-        deps: TCustomDeps,
-        return_type: type[TResult],
-        session: SessionIdType | SessionQuery = None,
-        name_override: str | None = None,
-    ) -> Agent[TCustomDeps, TResult]: ...
-
-    async def create_agent(
-        self,
-        name: AgentName,
-        *,
-        deps: Any | None = None,
-        return_type: Any | None = None,
-        session: SessionIdType | SessionQuery = None,
-        name_override: str | None = None,
-    ) -> Agent[Any, Any]:
-        """Create a new agent instance from configuration.
-
-        Args:
-            name: Name of the agent configuration to use
-            deps: Optional custom dependencies (overrides pool deps)
-            return_type: Optional type for structured responses
-            session: Optional session ID or query to recover conversation
-            name_override: Optional different name for this instance
-
-        Returns:
-            New agent instance with the specified configuration
-
-        Raises:
-            KeyError: If agent configuration not found
-            ValueError: If configuration is invalid
-        """
-        if name not in self.manifest.agents:
-            msg = f"Agent configuration {name!r} not found"
-            raise KeyError(msg)
-
-        # Use Manifest.get_agent for proper initialization
-        final_deps = deps if deps is not None else self.shared_deps
-        agent = self.manifest.get_agent(name, deps=final_deps)
-        # Override name if requested
-        if name_override:
-            agent._name = name_override
-
-        # Set pool reference
-        agent.context.pool = self
-
-        # Handle session if provided
-        if session:
-            agent.conversation.load_history_from_database(session=session)
-
-        # Initialize agent through exit stack
-        agent = await self.exit_stack.enter_async_context(agent)
-
-        # Override structured configuration if provided
-        if return_type not in {None, str}:
-            agent.set_output_type(return_type)
-
-        return agent
-
-    def setup_agent_workers(self, agent: Agent[Any, Any]):
+    def setup_agent_workers(self, agent: Agent[Any, Any]) -> None:
         """Set up workers for an agent from configuration."""
         for worker_config in agent.context.config.workers:
             try:
@@ -697,7 +535,7 @@ class AgentPool[TPoolDeps = None](BaseRegistry[NodeName, MessageEmitter[Any, Any
         agent: AgentName | Agent[Any, str],
         *,
         return_type: type[TResult] = str,  # type: ignore
-        model_override: str | None = None,
+        model_override: ModelName | str | None = None,
         session: SessionIdType | SessionQuery = None,
     ) -> Agent[TPoolDeps, TResult]: ...
 
@@ -708,7 +546,7 @@ class AgentPool[TPoolDeps = None](BaseRegistry[NodeName, MessageEmitter[Any, Any
         *,
         deps_type: type[TCustomDeps],
         return_type: type[TResult] = str,  # type: ignore
-        model_override: str | None = None,
+        model_override: ModelName | str | None = None,
         session: SessionIdType | SessionQuery = None,
     ) -> Agent[TCustomDeps, TResult]: ...
 
@@ -718,7 +556,7 @@ class AgentPool[TPoolDeps = None](BaseRegistry[NodeName, MessageEmitter[Any, Any
         *,
         deps_type: Any | None = None,
         return_type: Any = str,
-        model_override: str | None = None,
+        model_override: ModelName | str | None = None,
         session: SessionIdType | SessionQuery = None,
     ) -> Agent[Any, Any]:
         """Get or configure an agent from the pool.
@@ -744,30 +582,18 @@ class AgentPool[TPoolDeps = None](BaseRegistry[NodeName, MessageEmitter[Any, Any
             ValueError: If configuration is invalid
         """
         from llmling_agent.agent import Agent
-        from llmling_agent.agent.context import AgentContext
 
-        # Get base agent
         base = agent if isinstance(agent, Agent) else self.agents[agent]
-
-        # Setup context and dependencies
-        if base.context is None:
-            base.context = AgentContext[Any].create_default(base.name)
-
         # Use custom deps if provided, otherwise use shared deps
         # base.context.data = deps if deps is not None else self.shared_deps
         base.deps_type = deps_type
         base.context.pool = self
-
-        # Apply overrides
         if model_override:
             base.set_model(model_override)
-
         if session:
             base.conversation.load_history_from_database(session=session)
-
-        # Convert to structured if needed
         if return_type not in {str, None}:
-            base.set_output_type(return_type)
+            base.to_structured(return_type)
 
         return base
 
@@ -778,14 +604,14 @@ class AgentPool[TPoolDeps = None](BaseRegistry[NodeName, MessageEmitter[Any, Any
     def get_job(self, name: str) -> Job[Any, Any]:
         return self._tasks[name]
 
-    def register_task(self, name: str, task: Job[Any, Any]):
+    def register_task(self, name: str, task: Job[Any, Any]) -> None:
         self._tasks.register(name, task)
 
     async def add_agent[TResult = str](
         self,
         name: AgentName,
         *,
-        output_type: OutputSpec[TResult] | str | StructuredResponseConfig = str,  # type: ignore[assignment]
+        output_type: OutputSpec[TResult] = str,  # type: ignore[assignment]
         **kwargs: Unpack[AgentKwargs],
     ) -> Agent[Any, TResult]:
         """Add a new permanent agent to the pool.
@@ -793,10 +619,6 @@ class AgentPool[TPoolDeps = None](BaseRegistry[NodeName, MessageEmitter[Any, Any
         Args:
             name: Name for the new agent
             output_type: Optional type for structured responses:
-                - None: Regular unstructured agent
-                - type: Python type for validation
-                - str: Name of response definition
-                - StructuredResponseConfig: Complete response definition
             **kwargs: Additional agent configuration
 
         Returns:
@@ -804,8 +626,17 @@ class AgentPool[TPoolDeps = None](BaseRegistry[NodeName, MessageEmitter[Any, Any
         """
         from llmling_agent.agent import Agent
 
-        agent: Agent[Any, TResult] = Agent(name=name, **kwargs, output_type=output_type)
-        agent.tools.add_provider(self.mcp)
+        if not kwargs.get("event_handlers"):
+            kwargs["event_handlers"] = self.event_handlers
+        agent: Agent[Any, TResult] = Agent(
+            name=name,
+            **kwargs,
+            output_type=output_type,
+            agent_pool=self,
+        )
+        # Add MCP aggregating provider from manager
+        agent.tools.add_provider(self.mcp.get_aggregating_provider())
+        agent.tools.add_provider(self.skills.get_skills_provider())
         agent = await self.exit_stack.enter_async_context(agent)
         self.register(name, agent)
         return agent
@@ -826,7 +657,6 @@ class AgentPool[TPoolDeps = None](BaseRegistry[NodeName, MessageEmitter[Any, Any
         for agent in self.agents.values():
             connections = agent.connections.get_connections()
             for talk in connections:
-                talk = cast(Talk[Any], talk)  # help mypy understand it's a Talk
                 source = talk.source.name
                 for target in talk.targets:
                     if include_details:
@@ -834,11 +664,11 @@ class AgentPool[TPoolDeps = None](BaseRegistry[NodeName, MessageEmitter[Any, Any
                         details.append(talk.connection_type)
                         if talk.queued:
                             details.append(f"queued({talk.queue_strategy})")
-                        if fn := talk.filter_condition:  # type: ignore
+                        if fn := talk.filter_condition:
                             details.append(f"filter:{fn.__name__}")
-                        if fn := talk.stop_condition:  # type: ignore
+                        if fn := talk.stop_condition:
                             details.append(f"stop:{fn.__name__}")
-                        if fn := talk.exit_condition:  # type: ignore
+                        if fn := talk.exit_condition:
                             details.append(f"exit:{fn.__name__}")
 
                         label = f"|{' '.join(details)}|" if details else ""
@@ -851,7 +681,7 @@ class AgentPool[TPoolDeps = None](BaseRegistry[NodeName, MessageEmitter[Any, Any
 
 if __name__ == "__main__":
 
-    async def main():
+    async def main() -> None:
         path = "src/llmling_agent/config_resources/agents.yml"
         async with AgentPool(path) as pool:
             agent = pool.get_agent("overseer")
