@@ -4,7 +4,7 @@ from __future__ import annotations
 
 import functools
 import inspect
-from typing import TYPE_CHECKING, Any, overload
+from typing import TYPE_CHECKING, Any
 
 from llmling_agent.functional.structure import get_structured
 
@@ -12,30 +12,7 @@ from llmling_agent.functional.structure import get_structured
 if TYPE_CHECKING:
     from collections.abc import Callable, Coroutine
 
-    from pydantic_ai.agent import models
-
-    from llmling_agent.common_types import AnyCallable
-
-
-# We need separate overloads for async and sync functions
-@overload
-def auto_callable[R, **P](
-    model: str | models.Model | models.KnownModelName,
-    *,
-    system_prompt: str | None = None,
-    retries: int = 3,
-) -> Callable[
-    [Callable[P, Coroutine[Any, Any, R]]], Callable[P, Coroutine[Any, Any, R]]
-]: ...
-
-
-@overload
-def auto_callable[R, **P](
-    model: str | models.Model | models.KnownModelName,
-    *,
-    system_prompt: str | None = None,
-    retries: int = 3,
-) -> Callable[[Callable[P, R]], Callable[P, Coroutine[Any, Any, R]]]: ...
+    from pydantic_ai import models
 
 
 def auto_callable[R, **P](
@@ -43,7 +20,10 @@ def auto_callable[R, **P](
     *,
     system_prompt: str | None = None,
     retries: int = 3,
-) -> AnyCallable:
+) -> (
+    Callable[[Callable[P, R]], Callable[P, Coroutine[Any, Any, R]]]
+    | Callable[[Callable[P, Coroutine[Any, Any, R]]], Callable[P, Coroutine[Any, Any, R]]]
+):
     """Use function signature as schema for LLM responses.
 
     This decorator uses the function's:
@@ -88,11 +68,11 @@ def auto_callable[R, **P](
             # Use get_structured to get typed response
             return_type = sig.return_annotation
             if return_type is inspect.Parameter.empty:
-                return_type = str  # type: ignore[assignment]
+                return_type = str
 
             return await get_structured(
                 prompt=prompt,
-                response_type=return_type,  # type: ignore[arg-type]
+                response_type=return_type,
                 model=model,
                 system_prompt=system_prompt,
                 max_retries=retries,
