@@ -11,7 +11,7 @@ import structlog
 
 
 if TYPE_CHECKING:
-    from collections.abc import Sequence
+    from collections.abc import Iterator, Sequence
 
     from slashed import OutputWriter
 
@@ -45,18 +45,28 @@ def configure_logging(
     if isinstance(level, str):
         level = getattr(logging, level.upper())
 
+    # Determine output format first
+    colors = sys.stderr.isatty() and not json_logs if use_colors is not None else False
+    use_console_renderer = not (json_logs or (not colors and not sys.stderr.isatty()))
+
     # Configure standard logging as backend
-    logging.basicConfig(
-        level=level,
-        handlers=[logging.StreamHandler(sys.stderr)],
-        force=True,
-        format="%(message)s",  # structlog handles formatting
-    )
+    if use_console_renderer:
+        # For console output, don't show level in stdlib logging (structlog handles it)
+        handler = logging.StreamHandler(sys.stderr)
+        handler.setFormatter(logging.Formatter("%(message)s"))
+        logging.basicConfig(level=level, handlers=[handler], force=True)
+    else:
+        # For structured output, use minimal formatting
+        logging.basicConfig(
+            level=level,
+            handlers=[logging.StreamHandler(sys.stderr)],
+            force=True,
+            format="%(message)s",
+        )
 
     # Configure structlog processors
     processors: list[Any] = [
         structlog.stdlib.filter_by_level,
-        structlog.stdlib.add_logger_name,
         structlog.stdlib.add_log_level,
         structlog.stdlib.PositionalArgumentsFormatter(),
         structlog.processors.TimeStamper(fmt="iso"),
@@ -64,12 +74,9 @@ def configure_logging(
         structlog.processors.UnicodeDecoder(),
     ]
 
-    # Determine output format
-    colors = sys.stderr.isatty() and not json_logs if use_colors is not None else False
-    use_console_renderer = not (json_logs or (not colors and not sys.stderr.isatty()))
-
-    # Add format_exc_info only for non-console renderers
+    # Add logger name only for non-console renderers (avoid duplication with stdlib)
     if not use_console_renderer:
+        processors.insert(1, structlog.stdlib.add_logger_name)
         processors.append(structlog.processors.format_exc_info)
 
     # Add final renderer
@@ -89,9 +96,7 @@ def configure_logging(
     _LOGGING_CONFIGURED = True
 
 
-def get_logger(
-    name: str, log_level: LogLevel | None = None
-) -> structlog.stdlib.BoundLogger:
+def get_logger(name: str, log_level: LogLevel | None = None) -> structlog.stdlib.BoundLogger:
     """Get a structlog logger for the given name.
 
     Args:
@@ -107,7 +112,6 @@ def get_logger(
         structlog.configure(
             processors=[
                 structlog.stdlib.filter_by_level,
-                structlog.stdlib.add_logger_name,
                 structlog.stdlib.add_log_level,
                 structlog.processors.StackInfoRenderer(),
                 structlog.dev.ConsoleRenderer(colors=False),
@@ -125,7 +129,7 @@ def get_logger(
         # Set level on underlying stdlib logger
         stdlib_logger = logging.getLogger(f"llmling_agent.{name}")
         stdlib_logger.setLevel(log_level)
-    return logger
+    return logger  # type: ignore[no-any-return]
 
 
 @contextmanager
@@ -134,7 +138,7 @@ def set_handler_level(
     logger_names: Sequence[str],
     *,
     session_handler: OutputWriter | None = None,
-):
+) -> Iterator[None]:
     """Temporarily set logging level and optionally add session handler.
 
     Args:
