@@ -2,13 +2,15 @@
 
 from __future__ import annotations
 
-import asyncio
+from dataclasses import dataclass
 from typing import TYPE_CHECKING
 
 from llmling_agent.log import get_logger
 
 
 if TYPE_CHECKING:
+    from collections.abc import Awaitable, Callable
+
     from mcp.shared.session import RequestResponder
     import mcp.types
 
@@ -17,11 +19,18 @@ if TYPE_CHECKING:
 logger = get_logger(__name__)
 
 
+@dataclass
 class MCPMessageHandler:
     """Custom message handler that bridges FastMCP to llmling-agent notifications."""
 
-    def __init__(self, client: MCPClient) -> None:
-        self.client = client
+    client: MCPClient
+    """The MCP client instance."""
+    tool_change_callback: Callable[[], Awaitable[None]] | None = None
+    """Tool change callback."""
+    prompt_change_callback: Callable[[], Awaitable[None]] | None = None
+    """Prompt change callback."""
+    resource_change_callback: Callable[[], Awaitable[None]] | None = None
+    """Resource change callback."""
 
     async def __call__(
         self,
@@ -47,10 +56,8 @@ class MCPMessageHandler:
                     case mcp.types.CreateMessageRequest():
                         await self.on_create_message(message.request.root)
 
-            # notifications
             case mcp.types.ServerNotification():
                 await self.on_notification(message)
-                # Handle specific notifications
                 match message.root:
                     case mcp.types.CancelledNotification():
                         await self.on_cancelled(message.root)
@@ -86,27 +93,23 @@ class MCPMessageHandler:
     async def on_notification(self, message: mcp.types.ServerNotification) -> None:
         """Handle server notifications."""
 
-    async def on_tool_list_changed(
-        self, message: mcp.types.ToolListChangedNotification
-    ) -> None:
-        """Handle tool list changes by refreshing tools."""
+    async def on_tool_list_changed(self, message: mcp.types.ToolListChangedNotification) -> None:
+        """Handle tool list changes."""
         logger.info("MCP tool list changed", message=message)
-        # Schedule async refresh - use create_task to avoid blocking
-        task = asyncio.create_task(self.client._refresh_tools())
-        # Store reference to avoid warning about unawaited task
-        task.add_done_callback(
-            lambda t: t.exception() if t.done() and t.exception() else None
-        )
+        # Call the tool change callback if provided
+        if self.tool_change_callback:
+            await self.tool_change_callback()
 
     async def on_resource_list_changed(
         self, message: mcp.types.ResourceListChangedNotification
     ) -> None:
         """Handle resource list changes."""
         logger.info("MCP resource list changed", message=message)
+        # Call the resource change callback if provided
+        if self.resource_change_callback:
+            await self.resource_change_callback()
 
-    async def on_resource_updated(
-        self, message: mcp.types.ResourceUpdatedNotification
-    ) -> None:
+    async def on_resource_updated(self, message: mcp.types.ResourceUpdatedNotification) -> None:
         """Handle resource updates."""
         # ResourceUpdatedNotification has uri directly, not in params
         logger.info("MCP resource updated", uri=getattr(message, "uri", "unknown"))
@@ -121,14 +124,15 @@ class MCPMessageHandler:
     ) -> None:
         """Handle prompt list changes."""
         logger.info("MCP prompt list changed", message=message)
+        # Call the prompt change callback if provided
+        if self.prompt_change_callback:
+            await self.prompt_change_callback()
 
     async def on_cancelled(self, message: mcp.types.CancelledNotification) -> None:
         """Handle cancelled operations."""
         logger.info("MCP operation cancelled", message=message)
 
-    async def on_logging_message(
-        self, message: mcp.types.LoggingMessageNotification
-    ) -> None:
+    async def on_logging_message(self, message: mcp.types.LoggingMessageNotification) -> None:
         """Handle server log messages."""
         # This is handled by _log_handler, but keep for completeness
 
