@@ -1,14 +1,9 @@
 """Core messsaging classes for LLMling agent."""
 
-from llmling_agent.messaging.messages import (
-    ChatMessage,
-    TokenCost,
-    AgentResponse,
-    TeamResponse,
-)
+from llmling_agent.messaging.messages import ChatMessage, TokenCost, AgentResponse, TeamResponse
 from llmling_agent.messaging.message_container import ChatMessageContainer
 from llmling_agent.messaging.event_manager import EventManager
-from llmling_agent.messaging.messageemitter import MessageEmitter
+
 from llmling_agent.messaging.messagenode import MessageNode
 
 __all__ = [
@@ -16,7 +11,6 @@ __all__ = [
     "ChatMessage",
     "ChatMessageContainer",
     "EventManager",
-    "MessageEmitter",
     "MessageNode",
     "TeamResponse",
     "TokenCost",
