@@ -4,7 +4,7 @@ from __future__ import annotations
 
 from collections.abc import Sequence
 from contextlib import asynccontextmanager
-from typing import TYPE_CHECKING, Any
+from typing import TYPE_CHECKING, Any, Self
 
 from psygnal import Signal
 from psygnal.containers import EventedList
@@ -14,15 +14,11 @@ from llmling_agent.talk import AggregatedTalkStats, Talk, TeamTalk
 
 
 if TYPE_CHECKING:
+    from collections.abc import AsyncIterator
     from datetime import timedelta
 
-    from llmling_agent.common_types import (
-        AgentName,
-        AnyTransformFn,
-        AsyncFilterFn,
-        QueueStrategy,
-    )
-    from llmling_agent.messaging import ChatMessage, MessageEmitter, MessageNode
+    from llmling_agent.common_types import AgentName, AnyTransformFn, AsyncFilterFn, QueueStrategy
+    from llmling_agent.messaging import ChatMessage, MessageNode
     from llmling_agent_config.forward_targets import ConnectionType
 
 logger = get_logger(__name__)
@@ -36,40 +32,44 @@ class ConnectionManager:
     node_connected = Signal(object)  # Node
     connection_added = Signal(Talk)  # Agent
 
-    def __init__(self, owner: MessageEmitter):
+    def __init__(self, owner: MessageNode[Any, Any]) -> None:
         self.owner = owner
         # helper class for the user
         self._connections = EventedList[Talk]()
         self._wait_states: dict[AgentName, bool] = {}
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         return f"ConnectionManager({self.owner})"
 
-    def _on_talk_added(self, index: int, talk: Talk):
+    def _on_talk_added(self, index: int, talk: Talk) -> None:
         """Connect to new talk's signal."""
         talk.connection_processed.connect(self._handle_message_flow)
 
-    def _on_talk_removed(self, index: int, talk: Talk):
+    def _on_talk_removed(self, index: int, talk: Talk) -> None:
         """Disconnect from removed talk's signal."""
         talk.connection_processed.disconnect(self._handle_message_flow)
 
-    def _on_talk_changed(self, index: int, old: Talk, new: Talk):
+    def _on_talk_changed(self, index: int, old: Talk, new: Talk) -> None:
         """Update signal connections on talk change."""
         old.connection_processed.disconnect(self._handle_message_flow)
         new.connection_processed.connect(self._handle_message_flow)
 
-    def _handle_message_flow(self, event: Talk.ConnectionProcessed):
+    def _handle_message_flow(self, event: Talk.ConnectionProcessed) -> None:
         """Forward message flow to our aggregated signal."""
         self.connection_processed.emit(event)
 
-    def set_wait_state(self, target: MessageEmitter | AgentName, wait: bool = True):
+    def set_wait_state(
+        self,
+        target: MessageNode[Any, Any] | AgentName,
+        wait: bool = True,
+    ) -> None:
         """Set waiting behavior for target."""
         target_name = target if isinstance(target, str) else target.name
         self._wait_states[target_name] = wait
 
-    async def wait_for_connections(self, _seen: set[AgentName] | None = None):
+    async def wait_for_connections(self, _seen: set[AgentName] | None = None) -> None:
         """Wait for this agent and all connected agents to complete their tasks."""
-        seen: set[AgentName] = _seen or {self.owner.name}  # type: ignore
+        seen: set[AgentName] = _seen or {self.owner.name}
 
         # Wait for our own tasks
         await self.owner.task_manager.complete_tasks()
@@ -82,7 +82,7 @@ class ConnectionManager:
 
     def get_targets(
         self, recursive: bool = False, _seen: set[AgentName] | None = None
-    ) -> set[MessageNode]:
+    ) -> set[MessageNode[Any, Any]]:
         """Get all currently connected target agents.
 
         Args:
@@ -95,7 +95,7 @@ class ConnectionManager:
             return targets
 
         # Track seen agents to prevent cycles
-        seen = _seen or {self.owner.name}  # type: ignore
+        seen = _seen or {self.owner.name}
         all_targets = set()
 
         for target in targets:
@@ -107,21 +107,21 @@ class ConnectionManager:
 
         return all_targets
 
-    def has_connection_to(self, target: MessageNode) -> bool:
+    def has_connection_to(self, target: MessageNode[Any, Any]) -> bool:
         """Check if target is connected."""
         return any(target in conn.targets for conn in self._connections if conn.active)
 
     def create_connection(
         self,
-        source: MessageEmitter,
-        target: MessageNode | Sequence[MessageNode],
+        source: MessageNode[Any, Any],
+        target: MessageNode[Any, Any] | Sequence[MessageNode[Any, Any]],
         *,
         connection_type: ConnectionType = "run",
         priority: int = 0,
         delay: timedelta | None = None,
         queued: bool = False,
         queue_strategy: QueueStrategy = "latest",
-        transform: AnyTransformFn | None = None,
+        transform: AnyTransformFn[Any] | None = None,
         filter_condition: AsyncFilterFn | None = None,
         stop_condition: AsyncFilterFn | None = None,
         exit_condition: AsyncFilterFn | None = None,
@@ -191,9 +191,7 @@ class ConnectionManager:
             else:
                 pool.connection_registry.register_auto(talk)
         else:
-            logger.debug(
-                "Could not register connection. no pool available", connection=name
-            )
+            logger.debug("Could not register connection. no pool available", connection=name)
         return talk
 
     async def trigger_all(self) -> dict[AgentName, list[ChatMessage[Any]]]:
@@ -215,27 +213,25 @@ class ConnectionManager:
                 results.extend(await talk.trigger())
         return results
 
-    def disconnect_all(self):
+    def disconnect_all(self) -> None:
         """Disconnect all managed connections."""
         for conn in self._connections:
             conn.disconnect()
         self._connections.clear()
 
-    def disconnect(self, node: MessageNode):
+    def disconnect(self, node: MessageNode[Any, Any]) -> None:
         """Disconnect a specific node."""
         for talk in self._connections:
             if node in talk.targets or node == talk.source:
                 talk.active = False
                 self._connections.remove(talk)
 
-    async def route_message(self, message: ChatMessage[Any], wait: bool | None = None):
+    async def route_message(self, message: ChatMessage[Any], wait: bool | None = None) -> None:
         """Route message to all connections."""
         if wait is not None:
             should_wait = wait
         else:
-            should_wait = any(
-                self._wait_states.get(t.name, False) for t in self.get_targets()
-            )
+            should_wait = any(self._wait_states.get(t.name, False) for t in self.get_targets())
         msg = "ConnectionManager routing message"
         logger.debug(msg, sender=message.name, num_connections=len(self._connections))
         for talk in self._connections:
@@ -245,7 +241,7 @@ class ConnectionManager:
             await self.wait_for_connections()
 
     @asynccontextmanager
-    async def paused_routing(self):
+    async def paused_routing(self) -> AsyncIterator[Self]:
         """Temporarily pause message routing to connections."""
         active_talks = [talk for talk in self._connections if talk.active]
         for talk in active_talks:
@@ -327,5 +323,5 @@ if __name__ == "__main__":
     _conn_1 = agent >> agent_2
     _conn_2 = agent >> agent_3
     _conn_3 = agent_2 >> agent_4
-    print(agent.connections.get_connections(recursive=True))
-    print(agent.connections.get_mermaid_diagram())
+    # print(agent.connections.get_connections(recursive=True))
+    # print(agent.connections.get_mermaid_diagram())
