@@ -8,14 +8,9 @@ from collections.abc import Awaitable, Callable
 from dataclasses import dataclass
 from functools import wraps
 import inspect
-from typing import TYPE_CHECKING, Any, Self, overload
+from typing import TYPE_CHECKING, Any, Self
 
-from evented.configs import (
-    EmailConfig,
-    FileWatchConfig,
-    TimeEventConfig,
-    WebhookConfig,
-)
+from evented.configs import EmailConfig, FileWatchConfig, TimeEventConfig, WebhookConfig
 from evented.event_data import EventData, FunctionResultEventData
 from psygnal import Signal
 from pydantic import SecretStr
@@ -34,7 +29,7 @@ if TYPE_CHECKING:
     from evented.configs import EventConfig
     from evented.timed_watcher import TimeEventSource
 
-    from llmling_agent.messaging import MessageEmitter
+    from llmling_agent.messaging import MessageNode
 
 
 logger = get_logger(__name__)
@@ -50,10 +45,10 @@ class EventManager:
 
     def __init__(
         self,
-        node: MessageEmitter[Any, Any],
+        node: MessageNode[Any, Any],
         enable_events: bool = True,
         auto_run: bool = True,
-    ):
+    ) -> None:
         """Initialize event manager.
 
         Args:
@@ -68,20 +63,20 @@ class EventManager:
         self.auto_run = auto_run
         self._observers = defaultdict[str, list[EventObserver]](list)
 
-    async def _default_handler(self, event: EventData):
+    async def _default_handler(self, event: EventData) -> None:
         """Default event handler that converts events to node runs."""
         if prompt := event.to_prompt():  # Only run if event provides a prompt
             await self.node.run(prompt)
 
-    def add_callback(self, callback: EventCallback):
+    def add_callback(self, callback: EventCallback) -> None:
         """Register an event callback."""
         self._callbacks.append(callback)
 
-    def remove_callback(self, callback: EventCallback):
+    def remove_callback(self, callback: EventCallback) -> None:
         """Remove a previously registered callback."""
         self._callbacks.remove(callback)
 
-    async def emit_event(self, event: EventData):
+    async def emit_event(self, event: EventData) -> None:
         """Emit event to all callbacks and optionally handle via node."""
         if not self.enabled:
             return
@@ -260,7 +255,7 @@ class EventManager:
         else:
             return source
 
-    async def remove_source(self, name: str):
+    async def remove_source(self, name: str) -> None:
         """Stop and remove an event source.
 
         Args:
@@ -270,7 +265,7 @@ class EventManager:
             await source.__aexit__(None, None, None)
             logger.debug("Removed event source", name=name)
 
-    async def _process_events(self, source: EventSource):
+    async def _process_events(self, source: EventSource) -> None:
         """Process events from a source.
 
         Args:
@@ -291,7 +286,7 @@ class EventManager:
         except Exception:
             logger.exception("Error processing events")
 
-    async def cleanup(self):
+    async def cleanup(self) -> None:
         """Clean up all event sources and tasks."""
         self.enabled = False
 
@@ -304,11 +299,7 @@ class EventManager:
             return self
 
         # Set up triggers from config
-        if (
-            self.node.context
-            and self.node.context.config
-            and self.node.context.config.triggers
-        ):
+        if self.node.context and self.node.context.config and self.node.context.config.triggers:
             for trigger in self.node.context.config.triggers:
                 await self.add_source(trigger)
 
@@ -323,27 +314,14 @@ class EventManager:
         """Clean up when exiting context."""
         await self.cleanup()
 
-    @overload
     def track[T](
         self,
         event_name: str | None = None,
         **event_metadata: Any,
-    ) -> Callable[[Callable[..., T]], Callable[..., T]]: ...
-
-    @overload
-    def track[T](
-        self,
-        event_name: str | None = None,
-        **event_metadata: Any,
-    ) -> Callable[
-        [Callable[..., Coroutine[Any, Any, T]]], Callable[..., Coroutine[Any, Any, T]]
-    ]: ...
-
-    def track(
-        self,
-        event_name: str | None = None,
-        **event_metadata: Any,
-    ) -> Callable[[Callable[..., Any]], Callable[..., Any]]:
+    ) -> (
+        Callable[[Callable[..., Coroutine[Any, Any, T]]], Callable[..., Coroutine[Any, Any, T]]]
+        | Callable[[Callable[..., T]], Callable[..., T]]
+    ):
         """Track function calls as events.
 
         Args:
@@ -404,27 +382,14 @@ class EventManager:
 
         return decorator
 
-    @overload
     def poll[T](
         self,
         event_type: str,
         interval: timedelta | None = None,
-    ) -> Callable[[Callable[..., T]], Callable[..., T]]: ...
-
-    @overload
-    def poll[T](
-        self,
-        event_type: str,
-        interval: timedelta | None = None,
-    ) -> Callable[
-        [Callable[..., Coroutine[Any, Any, T]]], Callable[..., Coroutine[Any, Any, T]]
-    ]: ...
-
-    def poll(
-        self,
-        event_type: str,
-        interval: timedelta | None = None,
-    ) -> Callable[[Callable[..., Any]], Callable[..., Any]]:
+    ) -> (
+        Callable[[Callable[..., Coroutine[Any, Any, T]]], Callable[..., Coroutine[Any, Any, T]]]
+        | Callable[[Callable[..., T]], Callable[..., T]]
+    ):
         """Decorator to register an event observer.
 
         Args:
@@ -448,9 +413,7 @@ class EventManager:
                 if self.enabled:
                     typ = type(result).__name__
                     meta = {"type": "function_result", "output_type": typ}
-                    event = FunctionResultEventData(
-                        result=result, source=event_type, metadata=meta
-                    )
+                    event = FunctionResultEventData(result=result, source=event_type, metadata=meta)
                     await self.emit_event(event)
                 return result
 
@@ -467,7 +430,7 @@ class EventObserver:
     interval: timedelta | None = None
     last_run: datetime | None = None
 
-    async def __call__(self, event: EventData):
+    async def __call__(self, event: EventData) -> None:
         """Handle an event."""
         try:
             await execute(self.callback, event)
