@@ -15,7 +15,7 @@ from llmling_agent.utils.count_tokens import batch_count_tokens, count_tokens
 if TYPE_CHECKING:
     from datetime import datetime
 
-    from bigtree import DAGNode
+    from bigtree import DAGNode  # type: ignore[attr-defined]
 
     from llmling_agent.common_types import MessageRole
     from llmling_agent.messaging.messages import FormatStyle
@@ -61,15 +61,12 @@ class ChatMessageContainer(EventedList[ChatMessage[Any]]):
         """
         # Use cost_info if available
         total = sum(m.cost_info.token_usage.total_tokens for m in self if m.cost_info)
-
         # For messages without cost_info, estimate using tiktoken
         if msgs := [msg for msg in self if not msg.cost_info]:
             if fallback_model:
                 model_name = fallback_model
             else:
-                model_name = next(
-                    (m.model_name for m in self if m.model_name), DEFAULT_TOKEN_MODEL
-                )
+                model_name = next((m.model_name for m in self if m.model_name), DEFAULT_TOKEN_MODEL)
             contents = [str(msg.content) for msg in msgs]
             total += sum(batch_count_tokens(contents, model_name))
 
@@ -118,9 +115,7 @@ class ChatMessageContainer(EventedList[ChatMessage[Any]]):
             List of messages with matching role
         """
         messages = [msg for msg in self if msg.role == role]
-        if max_messages:
-            messages = messages[-max_messages:]
-        return messages
+        return messages[-max_messages:] if max_messages else messages
 
     def get_between(
         self,
@@ -153,7 +148,7 @@ class ChatMessageContainer(EventedList[ChatMessage[Any]]):
         Returns:
             Root DAGNode of the graph
         """
-        from bigtree import DAGNode
+        from bigtree import DAGNode  # type: ignore[attr-defined]
 
         # Get messages from this conversation
         conv_messages = [m for m in self if m.conversation_id == message.conversation_id]
@@ -191,7 +186,7 @@ class ChatMessageContainer(EventedList[ChatMessage[Any]]):
         rankdir: Literal["TB", "BT", "LR", "RL"] = "LR",
     ) -> str:
         """Convert message flow to mermaid graph."""
-        from bigtree import dag_to_list
+        from bigtree import dag_to_list  # type: ignore[attr-defined]
 
         dag = self._build_flow_dag(message)
         if not dag:
