@@ -5,7 +5,7 @@ from __future__ import annotations
 from collections.abc import Sequence
 from dataclasses import dataclass, field, replace
 from decimal import Decimal
-from typing import TYPE_CHECKING, Any, Literal, Self, TypeVar
+from typing import TYPE_CHECKING, Any, Literal, Self, TypeVar, assert_never
 import uuid
 from uuid import uuid4
 
@@ -31,6 +31,7 @@ import tokonomics
 
 from llmling_agent.common_types import MessageRole, SimpleJsonType  # noqa: TC001
 from llmling_agent.log import get_logger
+from llmling_agent.utils.inspection import dataclasses_no_defaults_repr
 from llmling_agent.utils.now import get_now
 
 
@@ -226,20 +227,23 @@ class ChatMessage[TContent]:
 
     Normalized to OpenTelemetry values."""
 
+    __repr__ = dataclasses_no_defaults_repr
+
     @property
-    def last_message(self) -> ModelMessage:
+    def last_message(self) -> ModelMessage | None:
         """Return the last message from the message history."""
         # The response may not be the very last item if it contained an output tool call.
         # See `CallToolsNode._handle_final_result`.
         for message in reversed(self.messages):
             if isinstance(message, ModelRequest | ModelResponse):
                 return message
-        msg = "No last message found in the message history"
-        raise ValueError(msg)  # pragma: no cover
+        return None
 
     @property
     def parts(self) -> Sequence[ModelRequestPart] | Sequence[ModelResponsePart]:
         """The parts of the last model message."""
+        if not self.last_message:
+            return []
         return self.last_message.parts
 
     @property
@@ -257,7 +261,13 @@ class ChatMessage[TContent]:
             return self.messages
         match self.kind:
             case "request":
-                return [ModelRequest(parts=self.parts, instructions=None)]  # type: ignore
+                return [
+                    ModelRequest(
+                        parts=self.parts,  # type: ignore
+                        instructions=None,
+                        run_id=self.message_id,
+                    )
+                ]
             case "response":
                 return [
                     ModelResponse(
@@ -269,6 +279,7 @@ class ChatMessage[TContent]:
                         provider_details=self.provider_details,
                         finish_reason=self.finish_reason,
                         provider_response_id=self.provider_response_id,
+                        run_id=self.message_id,
                     )
                 ]
 
@@ -296,17 +307,16 @@ class ChatMessage[TContent]:
         message: ModelMessage,
         conversation_id: str | None = None,
         name: str | None = None,
-        message_id: str | None = None,
         forwarded_from: list[str] | None = None,
     ) -> ChatMessage[TContentType]:
         """Convert a Pydantic model to a ChatMessage."""
         match message:
-            case ModelRequest(instructions=_instructions):
+            case ModelRequest(instructions=_instructions, run_id=run_id):
                 return ChatMessage(
                     messages=[message],
                     content=content,
-                    role="user" if message.kind == "request" else "assistant",
-                    message_id=message_id or str(uuid.uuid4()),
+                    role="user",
+                    message_id=run_id or str(uuid.uuid4()),
                     # instructions=instructions,
                     forwarded_from=forwarded_from or [],
                     name=name,
@@ -319,13 +329,14 @@ class ChatMessage[TContent]:
                 provider_details=provider_details,
                 finish_reason=finish_reason,
                 provider_response_id=provider_response_id,
+                run_id=run_id,
             ):
                 return ChatMessage(
-                    role="user" if message.kind == "request" else "assistant",
+                    role="assistant",
                     content=content,
                     messages=[message],
                     usage=usage,
-                    message_id=message_id or str(uuid.uuid4()),
+                    message_id=run_id or str(uuid.uuid4()),
                     conversation_id=conversation_id,
                     model_name=model_name,
                     timestamp=timestamp,
@@ -336,9 +347,8 @@ class ChatMessage[TContent]:
                     name=name,
                     forwarded_from=forwarded_from or [],
                 )
-            case _:
-                msg = f"Unknown message kind: {message.kind}"
-                raise ValueError(msg)
+            case _ as unreachable:
+                assert_never(unreachable)
 
     @classmethod
     async def from_run_result[OutputDataT](
@@ -516,9 +526,7 @@ class ChatMessage[TContent]:
                     result=part.content,
                     tool_call_id=call_part.tool_call_id or str(uuid4()),
                     timestamp=part.timestamp,
-                    agent_tool_name=(
-                        t.agent_name if (t := tools.get(part.tool_name)) else None
-                    ),
+                    agent_tool_name=(t.agent_name if (t := tools.get(part.tool_name)) else None),
                 )
                 tool_calls.append(tool_info)
 
@@ -577,7 +585,7 @@ class ChatMessage[TContent]:
 
 
 @dataclass
-class AgentResponse[TResult]:
+class AgentResponse[TResult = Any]:
     """Result from an agent's execution."""
 
     agent_name: str
@@ -603,7 +611,7 @@ class AgentResponse[TResult]:
         return self.message.content if self.message else None
 
 
-class TeamResponse[TMessageContent](list[AgentResponse[Any]]):
+class TeamResponse[TMessageContent = Any](list[AgentResponse[Any]]):
     """Results from a team execution."""
 
     def __init__(
@@ -611,7 +619,7 @@ class TeamResponse[TMessageContent](list[AgentResponse[Any]]):
         responses: list[AgentResponse[TMessageContent]],
         start_time: datetime | None = None,
         errors: dict[str, Exception] | None = None,
-    ):
+    ) -> None:
         super().__init__(responses)
         self.start_time = start_time or get_now()
         self.end_time = get_now()
