@@ -7,43 +7,32 @@ from pathlib import Path
 from typing import TYPE_CHECKING, Any, Self
 
 from pydantic import ConfigDict, Field, model_validator
-from schemez.schema import Schema
+from schemez import Schema
 
 from llmling_agent import log
-from llmling_agent.models.agents import AgentConfig  # noqa: TC001
-from llmling_agent.resource_registry import ResourceRegistry
-from llmling_agent_config.commands import (  # noqa: TC001
-    CommandConfig,
-    StaticCommandConfig,
-)
+from llmling_agent.models.agents import AgentConfig
+from llmling_agent.vfs_registry import VFSRegistry
+from llmling_agent_config.commands import CommandConfig, StaticCommandConfig
 from llmling_agent_config.converters import ConversionConfig
-from llmling_agent_config.mcp_server import (
-    BaseMCPServerConfig,
-    MCPServerConfig,  # noqa: TC001
-)
+from llmling_agent_config.mcp_server import BaseMCPServerConfig, MCPServerConfig
 from llmling_agent_config.observability import ObservabilityConfig
-from llmling_agent_config.output_types import StructuredResponseConfig  # noqa: TC001
+from llmling_agent_config.output_types import StructuredResponseConfig
 from llmling_agent_config.pool_server import MCPPoolServerConfig
-from llmling_agent_config.resources import (  # noqa: TC001
-    ResourceConfig,
-    SourceResourceConfig,
-)
+from llmling_agent_config.resources import ResourceConfig, SourceResourceConfig
 from llmling_agent_config.storage import StorageConfig
 from llmling_agent_config.system_prompts import PromptLibraryConfig
-from llmling_agent_config.task import Job  # noqa: TC001
-from llmling_agent_config.teams import TeamConfig  # noqa: TC001
-from llmling_agent_config.workers import (
-    AgentWorkerConfig,
-    BaseWorkerConfig,
-    TeamWorkerConfig,
-)
+from llmling_agent_config.task import Job
+from llmling_agent_config.teams import TeamConfig
+from llmling_agent_config.workers import AgentWorkerConfig, BaseWorkerConfig, TeamWorkerConfig
 
 
 if TYPE_CHECKING:
     from upath.types import JoinablePathLike
 
     from llmling_agent import Agent, AgentPool
+    from llmling_agent.common_types import IndividualEventHandler
     from llmling_agent.prompts.manager import PromptManager
+    from llmling_agent.ui.base import InputProvider
 
 
 logger = log.get_logger(__name__)
@@ -65,7 +54,19 @@ class AgentsManifest(Schema):
     INHERIT: str | list[str] | None = None
     """Inheritance references."""
 
-    resources: dict[str, ResourceConfig | str] = Field(default_factory=dict)
+    resources: dict[str, ResourceConfig | str] = Field(
+        default_factory=dict,
+        examples=[
+            {"docs": "file://./docs", "data": "s3://bucket/data"},
+            {
+                "api": {
+                    "type": "source",
+                    "uri": "https://api.example.com",
+                    "cached": True,
+                }
+            },
+        ],
+    )
     """Resource configurations defining available filesystems.
 
     Supports both full config and URI shorthand:
@@ -77,14 +78,38 @@ class AgentsManifest(Schema):
             cached: true
     """
 
-    agents: dict[str, AgentConfig] = Field(default_factory=dict)
-    """Mapping of agent IDs to their configurations"""
+    agents: dict[str, AgentConfig] = Field(
+        default_factory=dict,
+        json_schema_extra={
+            "documentation_url": "https://phil65.github.io/llmling-agent/YAML%20Configuration/agent_configuration/"
+        },
+    )
+    """Mapping of agent IDs to their configurations.
 
-    teams: dict[str, TeamConfig] = Field(default_factory=dict)
-    """Mapping of team IDs to their configurations"""
+    Docs: https://phil65.github.io/llmling-agent/YAML%20Configuration/agent_configuration/
+    """
 
-    storage: StorageConfig = Field(default_factory=StorageConfig)
-    """Storage provider configuration."""
+    teams: dict[str, TeamConfig] = Field(
+        default_factory=dict,
+        json_schema_extra={
+            "documentation_url": "https://phil65.github.io/llmling-agent/YAML%20Configuration/team_configuration/"
+        },
+    )
+    """Mapping of team IDs to their configurations.
+
+    Docs: https://phil65.github.io/llmling-agent/YAML%20Configuration/team_configuration/
+    """
+
+    storage: StorageConfig = Field(
+        default_factory=StorageConfig,
+        json_schema_extra={
+            "documentation_url": "https://phil65.github.io/llmling-agent/YAML%20Configuration/storage_configuration/"
+        },
+    )
+    """Storage provider configuration.
+
+    Docs: https://phil65.github.io/llmling-agent/YAML%20Configuration/storage_configuration/
+    """
 
     observability: ObservabilityConfig = Field(default_factory=ObservabilityConfig)
     """Observability provider configuration."""
@@ -92,16 +117,35 @@ class AgentsManifest(Schema):
     conversion: ConversionConfig = Field(default_factory=ConversionConfig)
     """Document conversion configuration."""
 
-    responses: dict[str, StructuredResponseConfig] = Field(default_factory=dict)
-    """Mapping of response names to their definitions"""
+    responses: dict[str, StructuredResponseConfig] = Field(
+        default_factory=dict,
+        json_schema_extra={
+            "documentation_url": "https://phil65.github.io/llmling-agent/YAML%20Configuration/response_configuration/"
+        },
+    )
+    """Mapping of response names to their definitions.
 
-    jobs: dict[str, Job] = Field(default_factory=dict)
+    Docs: https://phil65.github.io/llmling-agent/YAML%20Configuration/response_configuration/
+    """
+
+    jobs: dict[str, Job[Any]] = Field(default_factory=dict)
     """Pre-defined jobs, ready to be used by nodes."""
 
-    mcp_servers: list[str | MCPServerConfig] = Field(default_factory=list)
+    mcp_servers: list[str | MCPServerConfig] = Field(
+        default_factory=list,
+        examples=[
+            ["uvx some-server"],
+            [{"type": "streamable-http", "url": "http://mcp.example.com"}],
+        ],
+        json_schema_extra={
+            "documentation_url": "https://phil65.github.io/llmling-agent/YAML%20Configuration/mcp_configuration/"
+        },
+    )
     """List of MCP server configurations:
 
     These MCP servers are used to provide tools and other resources to the nodes.
+
+    Docs: https://phil65.github.io/llmling-agent/YAML%20Configuration/mcp_configuration/
     """
     pool_server: MCPPoolServerConfig = Field(default_factory=MCPPoolServerConfig)
     """Pool server configuration.
@@ -109,9 +153,31 @@ class AgentsManifest(Schema):
     This MCP server configuration is used for the pool MCP server,
     which exposes pool functionality to other applications / clients."""
 
-    prompts: PromptLibraryConfig = Field(default_factory=PromptLibraryConfig)
+    prompts: PromptLibraryConfig = Field(
+        default_factory=PromptLibraryConfig,
+        json_schema_extra={
+            "documentation_url": "https://phil65.github.io/llmling-agent/YAML%20Configuration/prompt_configuration/"
+        },
+    )
+    """Prompt library configuration.
 
-    commands: dict[str, CommandConfig | str] = Field(default_factory=dict)
+    This configuration defines the prompt library, which is used to provide prompts to the nodes.
+
+    Docs: https://phil65.github.io/llmling-agent/YAML%20Configuration/prompt_configuration/
+    """
+
+    commands: dict[str, CommandConfig | str] = Field(
+        default_factory=dict,
+        examples=[
+            {"check_disk": "df -h", "analyze": "Analyze the current situation"},
+            {
+                "status": {
+                    "type": "static",
+                    "content": "Show system status",
+                }
+            },
+        ],
+    )
     """Global command shortcuts for prompt injection.
 
     Supports both shorthand string syntax and full command configurations:
@@ -122,7 +188,11 @@ class AgentsManifest(Schema):
             path: "./prompts/analysis.md"
     """
 
-    model_config = ConfigDict(use_attribute_docstrings=True, extra="forbid")
+    model_config = ConfigDict(
+        json_schema_extra={
+            "documentation_url": "https://phil65.github.io/llmling-agent/YAML%20Configuration/manifest_configuration/"
+        },
+    )
 
     @model_validator(mode="before")
     @classmethod
@@ -192,9 +262,9 @@ class AgentsManifest(Schema):
         return data
 
     @cached_property
-    def resource_registry(self) -> ResourceRegistry:
-        """Get registry with all configured resources."""
-        registry = ResourceRegistry()
+    def vfs_registry(self) -> VFSRegistry:
+        """Get registry with all configured VFS resources."""
+        registry = VFSRegistry()
         for name, config in self.resources.items():
             if isinstance(config, str):
                 # Convert URI shorthand to SourceResourceConfig
@@ -234,10 +304,7 @@ class AgentsManifest(Schema):
             msg = f"Agent {actual_name} already exists"
             raise ValueError(msg)
 
-        # Deep copy the configuration
         config = self.agents[name].model_copy(deep=True)
-
-        # Apply overrides
         for key, value in overrides.items():
             if not hasattr(config, key):
                 msg = f"Invalid override: {key}"
@@ -246,23 +313,22 @@ class AgentsManifest(Schema):
 
         # Handle template rendering if context provided
         if template_context and "name" in template_context and "name" not in overrides:
-            config.name = template_context["name"]
+            config.model_copy(update={"name": template_context["name"]})
 
         # Note: system_prompts will be rendered during agent creation, not here
         # config.system_prompts remains as PromptConfig objects
-
         self.agents[actual_name] = config
         return actual_name
 
     @model_validator(mode="before")
     @classmethod
-    def resolve_inheritance(cls, data: dict) -> dict:
+    def resolve_inheritance(cls, data: dict[str, Any]) -> dict[str, Any]:
         """Resolve agent inheritance chains."""
         nodes = data.get("agents", {})
-        resolved: dict[str, dict] = {}
+        resolved: dict[str, dict[str, Any]] = {}
         seen: set[str] = set()
 
-        def resolve_node(name: str) -> dict:
+        def resolve_node(name: str) -> dict[str, Any]:
             if name in resolved:
                 return resolved[name]
 
@@ -276,9 +342,7 @@ class AgentsManifest(Schema):
                 if hasattr(nodes[name], "model_copy")
                 else nodes[name].copy()
             )
-            inherit = (
-                config.get("inherits") if isinstance(config, dict) else config.inherits
-            )
+            inherit = config.get("inherits") if isinstance(config, dict) else config.inherits
             if inherit:
                 if inherit not in nodes:
                     msg = f"Parent agent {inherit} not found"
@@ -293,7 +357,7 @@ class AgentsManifest(Schema):
 
             seen.remove(name)
             resolved[name] = config
-            return config
+            return config  # type: ignore[no-any-return]
 
         # Resolve all nodes
         for name in nodes:
@@ -371,21 +435,22 @@ class AgentsManifest(Schema):
     #     return self
 
     def get_agent[TAgentDeps](
-        self, name: str, deps: TAgentDeps | None = None
+        self,
+        name: str,
+        deps_type: type[TAgentDeps] | None = None,
+        input_provider: InputProvider | None = None,
+        pool: AgentPool[Any] | None = None,
+        event_handlers: list[IndividualEventHandler] | None = None,
     ) -> Agent[TAgentDeps, Any]:
-        # TODO: Make this method async to support async function prompts
-
         from llmling_agent import Agent, AgentContext
 
         config = self.agents[name]
-        # Create context with config path and capabilities
         context = AgentContext[TAgentDeps](
             node_name=name,
-            data=deps,
             definition=self,
             config=config,
-            # pool=self,
-            # confirmation_callback=confirmation_callback,
+            input_provider=input_provider,
+            pool=pool,
         )
 
         # Resolve system prompts with new PromptConfig types
@@ -420,15 +485,25 @@ class AgentsManifest(Schema):
                         content = self.prompt_manager.get.sync(reference)
                         sys_prompts.append(content)
                     except Exception as e:
-                        msg = (
-                            f"Failed to load library prompt {reference!r} "
-                            f"for agent {name}"
-                        )
+                        msg = f"Failed to load library prompt {reference!r} for agent {name}"
                         logger.exception(msg)
                         raise ValueError(msg) from e
                 case FunctionPromptConfig(function=function, arguments=arguments):
                     content = function(**arguments)  # Call function to get prompt content
                     sys_prompts.append(content)
+        # Prepare toolsets list with config's tool provider
+        toolsets_list = []
+        if config_tool_provider := config.get_tool_provider():
+            toolsets_list.append(config_tool_provider)
+
+        # Resolve output type using the same two-step process as before
+        from llmling_agent.utils.result_utils import to_type
+
+        # Step 1: Get agent-specific output type (same as before)
+        agent_output_type = self.get_output_type(name) or str
+        # Step 2: Resolve it fully with to_type (same as before)
+        resolved_output_type = to_type(agent_output_type, self.responses)
+
         # Create agent with runtime and context
         return Agent(
             context=context,
@@ -437,14 +512,20 @@ class AgentsManifest(Schema):
             else config.model.get_model(),
             system_prompt=sys_prompts,
             name=name,
+            deps_type=deps_type,
             description=config.description,
             retries=config.retries,
             session=config.get_session_config(),
             output_retries=config.output_retries,
             end_strategy=config.end_strategy,
             debug=config.debug,
-            output_type=self.get_output_type(name) or str,
-            # name=config.name or name,
+            input_provider=input_provider,
+            output_type=resolved_output_type,
+            event_handlers=event_handlers,
+            agent_pool=pool,
+            tool_mode=config.tool_mode,
+            knowledge=config.knowledge,
+            toolsets=toolsets_list,
         )
 
     @classmethod
@@ -497,12 +578,12 @@ class AgentsManifest(Schema):
         logger.debug("Building response model", type=agent_config.output_type)
         if isinstance(agent_config.output_type, str):
             response_def = self.responses[agent_config.output_type]
-            return response_def.response_schema.get_schema()  # type: ignore
-        return agent_config.output_type.response_schema.get_schema()  # type: ignore
+            return response_def.response_schema.get_schema()
+        return agent_config.output_type.response_schema.get_schema()
 
 
 if __name__ == "__main__":
     model = {"type": "input"}
-    agent_cfg = dict(name="test_agent", model=model)  # type: ignore
-    manifest = AgentsManifest(agents=dict(test_agent=agent_cfg))  # type: ignore
-    print(manifest.agents["test_agent"].model)
+    agent_cfg = dict(name="test_agent", model=model)
+    manifest = AgentsManifest(agents=dict(test_agent=agent_cfg))  # pyright: ignore[reportArgumentType]
+    print(AgentsManifest.generate_test_data(mode="maximal").model_dump_yaml())
