@@ -70,7 +70,7 @@ class PromptManager:
     - Access to prompts from different sources
     """
 
-    def __init__(self, config: PromptLibraryConfig):
+    def __init__(self, config: PromptLibraryConfig) -> None:
         """Initialize prompt manager.
 
         Args:
@@ -103,7 +103,9 @@ class PromptManager:
                     self.providers["braintrust"] = BraintrustPromptHub(provider_config)
 
                 case PromptLayerConfig():
-                    from llmling_agent_prompts.promptlayer import PromptLayerProvider
+                    from llmling_agent_prompts.promptlayer_provider import (
+                        PromptLayerProvider,
+                    )
 
                     self.providers["promptlayer"] = PromptLayerProvider(provider_config)
 
@@ -190,7 +192,7 @@ class PromptManager:
             result[name] = prompts
         return result
 
-    def cleanup(self):
+    def cleanup(self) -> None:
         """Clean up providers."""
         self.providers.clear()
 
