@@ -8,11 +8,9 @@ from llmling_agent.resource_providers import ResourceProvider
 
 
 if TYPE_CHECKING:
-    from collections.abc import Sequence
-
-    from llmling import BasePrompt
     from pydantic_ai import ModelRequestPart
 
+    from llmling_agent.prompts.prompts import BasePrompt
     from llmling_agent.tools.base import Tool
     from llmling_agent_config.resources import ResourceInfo
 
@@ -20,36 +18,28 @@ if TYPE_CHECKING:
 class AggregatingResourceProvider(ResourceProvider):
     """Provider that combines resources from multiple providers."""
 
-    def __init__(self, providers: Sequence[ResourceProvider], name: str = "aggregating"):
+    def __init__(self, providers: list[ResourceProvider], name: str = "aggregating") -> None:
         """Initialize provider with list of providers to aggregate.
 
         Args:
-            providers: Resource providers to aggregate
+            providers: Resource providers to aggregate (stores reference to list)
             name: Name for this provider
         """
         super().__init__(name=name)
-        self.providers = list(providers)
+        # Store reference to the providers list for dynamic updates
+        self.providers = providers
 
     async def get_tools(self) -> list[Tool]:
         """Get tools from all providers."""
-        tools: list[Tool] = []
-        for provider in self.providers:
-            tools.extend(await provider.get_tools())
-        return tools
+        return [t for provider in self.providers for t in await provider.get_tools()]
 
     async def get_prompts(self) -> list[BasePrompt]:
         """Get prompts from all providers."""
-        prompts: list[BasePrompt] = []
-        for provider in self.providers:
-            prompts.extend(await provider.get_prompts())
-        return prompts
+        return [p for provider in self.providers for p in await provider.get_prompts()]
 
     async def get_resources(self) -> list[ResourceInfo]:
         """Get resources from all providers."""
-        resources: list[ResourceInfo] = []
-        for provider in self.providers:
-            resources.extend(await provider.get_resources())
-        return resources
+        return [r for provider in self.providers for r in await provider.get_resources()]
 
     async def get_request_parts(
         self, name: str, arguments: dict[str, str] | None = None
