@@ -2,22 +2,22 @@
 
 from __future__ import annotations
 
-from typing import TYPE_CHECKING, Self
-
-from llmling.core.typedefs import MessageContent
-from pydantic_ai import BinaryContent, SystemPromptPart, UserPromptPart
-from pydantic_ai.messages import ImageUrl
+from typing import TYPE_CHECKING, Any, Self
 
 from llmling_agent.log import get_logger
+from llmling_agent.tools.base import Tool
+from llmling_agent_config.tools import ToolHints
 
 
 if TYPE_CHECKING:
+    from collections.abc import Callable
     from types import TracebackType
 
-    from llmling import BasePrompt
     from pydantic_ai import ModelRequestPart
 
-    from llmling_agent.tools.base import Tool
+    from llmling_agent.prompts.prompts import BasePrompt
+    from llmling_agent.skills.skill import Skill
+    from llmling_agent.tools.base import ToolKind
     from llmling_agent_config.resources import ResourceInfo
 
 
@@ -31,7 +31,7 @@ class ResourceProvider:
     Default implementations return empty lists - override as needed.
     """
 
-    def __init__(self, name: str, owner: str | None = None):
+    def __init__(self, name: str, owner: str | None = None) -> None:
         """Initialize the resource provider."""
         self.name = name
         self.owner = owner
@@ -46,7 +46,7 @@ class ResourceProvider:
         exc_type: type[BaseException] | None,
         exc_val: BaseException | None,
         exc_tb: TracebackType | None,
-    ):
+    ) -> None:
         """Async context cleanup if required."""
 
     def __repr__(self) -> str:
@@ -56,6 +56,15 @@ class ResourceProvider:
         """Get available tools. Override to provide tools."""
         return []
 
+    async def get_tool(self, tool_name: str) -> Tool:
+        """Get specific tool."""
+        tools = await self.get_tools()
+        for tool in tools:
+            if tool.name == tool_name:
+                return tool
+        msg = f"Tool {tool_name!r} not found"
+        raise ValueError(msg)
+
     async def get_prompts(self) -> list[BasePrompt]:
         """Get available prompts. Override to provide prompts."""
         return []
@@ -64,6 +73,25 @@ class ResourceProvider:
         """Get available resources. Override to provide resources."""
         return []
 
+    async def get_skills(self) -> list[Skill]:
+        """Get available skills. Override to provide skills."""
+        return []
+
+    async def get_skill_instructions(self, skill_name: str) -> str:
+        """Get full instructions for a specific skill.
+
+        Args:
+            skill_name: Name of the skill to get instructions for
+
+        Returns:
+            The full skill instructions for execution
+
+        Raises:
+            KeyError: If skill not found
+        """
+        msg = f"Skill {skill_name!r} not found"
+        raise KeyError(msg)
+
     async def get_request_parts(
         self, name: str, arguments: dict[str, str] | None = None
     ) -> list[ModelRequestPart]:
@@ -91,32 +119,44 @@ class ResourceProvider:
             msg = f"Prompt {name!r} produced no messages"
             raise ValueError(msg)
 
-        parts: list[ModelRequestPart] = []
-        for prompt_msg in messages:
-            match prompt_msg.role:
-                case "system":
-                    parts.append(SystemPromptPart(str(prompt_msg.content)))
-                case "user":
-                    match prompt_msg.content:
-                        case str():
-                            parts.append(UserPromptPart(prompt_msg.content))
-                        case MessageContent():
-                            parts.append(to_pydantic(prompt_msg.content))
-                        case list():
-                            items = [to_pydantic(i) for i in prompt_msg.content]
-                            parts.extend(items)
-        return parts
+        return [p for prompt_msg in messages for p in prompt_msg.to_pydantic_parts()]
 
+    def create_tool(
+        self,
+        fn: Callable[..., Any],
+        read_only: bool | None = None,
+        destructive: bool | None = None,
+        idempotent: bool | None = None,
+        open_world: bool | None = None,
+        requires_confirmation: bool = False,
+        metadata: dict[str, Any] | None = None,
+        category: ToolKind | None = None,
+    ) -> Tool:
+        """Create a tool from a function.
 
-def to_pydantic(content: MessageContent) -> UserPromptPart:
-    """Convert MessageContent to Pydantic model."""
-    if content.type == "text":
-        return UserPromptPart(content.content)
-    if content.type == "image_url":
-        return UserPromptPart([ImageUrl(content.content)])
-    if content.type == "image_base64":
-        return UserPromptPart([
-            BinaryContent(content.content.encode(), media_type="image/jpeg")
-        ])
-    msg = "Unsupported content type"
-    raise ValueError(msg)
+        Args:
+            fn: Function to create a tool from
+            read_only: Whether the tool is read-only
+            destructive: Whether the tool is destructive
+            idempotent: Whether the tool is idempotent
+            open_world: Whether the tool is open-world
+            requires_confirmation: Whether the tool requires confirmation
+            metadata: Metadata for the tool
+            category: Category of the tool
+
+        Returns:
+            Tool created from the function
+        """
+        return Tool.from_callable(
+            fn=fn,
+            category=category,
+            source=self.name,
+            requires_confirmation=requires_confirmation,
+            metadata=metadata,
+            hints=ToolHints(
+                read_only=read_only,
+                destructive=destructive,
+                idempotent=idempotent,
+                open_world=open_world,
+            ),
+        )
