@@ -10,8 +10,7 @@ from llmling_agent.resource_providers import ResourceProvider
 if TYPE_CHECKING:
     from collections.abc import Callable, Sequence
 
-    from llmling import BasePrompt
-
+    from llmling_agent.prompts.prompts import BasePrompt
     from llmling_agent.tools.base import Tool
     from llmling_agent_config.resources import ResourceInfo
 
@@ -30,7 +29,7 @@ class StaticResourceProvider(ResourceProvider):
         tools: Sequence[Tool] | None = None,
         prompts: Sequence[BasePrompt] | None = None,
         resources: Sequence[ResourceInfo] | None = None,
-    ):
+    ) -> None:
         """Initialize provider with static resources.
 
         Args:
@@ -136,9 +135,6 @@ class StaticResourceProvider(ResourceProvider):
         description: str | None = None,
         enabled: bool = True,
         requires_confirmation: bool = False,
-        requires_capability: str | None = None,
-        priority: int = 100,
-        cache_enabled: bool = False,
         metadata: dict[str, str] | None = None,
         **kwargs: Any,
     ) -> Callable[[Callable[..., Any]], Callable[..., Any]]: ...
@@ -151,9 +147,6 @@ class StaticResourceProvider(ResourceProvider):
         description: str | None = None,
         enabled: bool = True,
         requires_confirmation: bool = False,
-        requires_capability: str | None = None,
-        priority: int = 100,
-        cache_enabled: bool = False,
         metadata: dict[str, str] | None = None,
         **kwargs: Any,
     ) -> Callable[..., Any] | Callable[[Callable[..., Any]], Callable[..., Any]]:
@@ -179,9 +172,6 @@ class StaticResourceProvider(ResourceProvider):
             description: Override for tool description
             enabled: Whether tool is initially enabled
             requires_confirmation: Whether execution needs confirmation
-            requires_capability: Optional capability requirement
-            priority: Execution priority (lower = higher priority)
-            cache_enabled: Whether to enable result caching
             metadata: Additional tool metadata
             **kwargs: Additional arguments passed to Tool.from_callable
         """
@@ -194,9 +184,6 @@ class StaticResourceProvider(ResourceProvider):
                 description_override=description,
                 enabled=enabled,
                 requires_confirmation=requires_confirmation,
-                requires_capability=requires_capability,
-                priority=priority,
-                cache_enabled=cache_enabled,
                 metadata=metadata or {},
                 **kwargs,
             )
