@@ -37,7 +37,7 @@ class NodeFunction:
     name: str = field(init=False)
     """Function name (from function.__name__)."""
 
-    def __post_init__(self):
+    def __post_init__(self) -> None:
         """Set name and validate dependencies."""
         self.name = self.func.__name__
         # Extract default inputs from function signature
@@ -52,11 +52,11 @@ class NodeFunction:
 
 
 def node_function(
-    func: Callable | None = None,
+    func: Callable[..., Any] | None = None,
     *,
     deps: Any | None = None,
-    depends_on: str | Sequence[str | Callable] | Callable | None = None,
-) -> Callable:
+    depends_on: str | Sequence[str | Callable[..., Any]] | Callable[..., Any] | None = None,
+) -> Callable[..., Any]:
     """Mark a function for automatic node execution.
 
     Can be used as simple decorator or with arguments:
@@ -76,13 +76,13 @@ def node_function(
         Decorated function
     """
 
-    def decorator(func: Callable) -> Callable:
+    def decorator(func: Callable[..., Any]) -> Callable[..., Any]:
         match depends_on:
             case None:
                 depends_on_ = []
             case str():
                 depends_on_ = [depends_on]
-            case Callable():
+            case Callable():  # type: ignore[misc]
                 depends_on_ = [depends_on.__name__]
 
             case [*items]:
