@@ -89,7 +89,7 @@ def _sort_functions(functions: list[NodeFunction]) -> list[NodeFunction]:
     seen = set()
     in_progress = set()
 
-    def add_function(func: NodeFunction):
+    def add_function(func: NodeFunction) -> None:
         if func.name in seen:
             return
         if func.name in in_progress:
@@ -205,7 +205,7 @@ async def execute_single(
         return func.name, result
 
 
-def _validate_dependency_types(functions: list[NodeFunction]):
+def _validate_dependency_types(functions: list[NodeFunction]) -> None:
     """Validate that dependency types match return types."""
     # Get return types for all functions
     return_types = {}
@@ -231,9 +231,7 @@ def _validate_dependency_types(functions: list[NodeFunction]):
                     raise TypeError(msg)
 
 
-def _validate_value_type(
-    value: Any, expected_type: type, func_name: str, param_name: str
-):
+def _validate_value_type(value: Any, expected_type: type, func_name: str, param_name: str) -> None:
     """Validate that a value matches its expected type."""
     if not isinstance(value, expected_type):
         msg = (
