@@ -18,7 +18,7 @@ from llmling_agent.utils.now import get_now
 
 
 if TYPE_CHECKING:
-    from collections.abc import Awaitable, Iterator
+    from collections.abc import AsyncIterator, Awaitable, Iterator
     from datetime import datetime, timedelta
 
     from evented.event_data import EventData
@@ -30,7 +30,7 @@ if TYPE_CHECKING:
         PromptCompatible,
         QueueStrategy,
     )
-    from llmling_agent.messaging import MessageEmitter, MessageNode
+    from llmling_agent.messaging import MessageNode
     from llmling_agent.messaging.events import ConnectionEventData
     from llmling_agent_config.events import ConnectionEventType
     from llmling_agent_config.forward_targets import ConnectionType
@@ -38,16 +38,16 @@ if TYPE_CHECKING:
 logger = get_logger(__name__)
 
 
-class Talk[TTransmittedData]:
+class Talk[TTransmittedData = Any]:
     """Manages message flow between agents/groups."""
 
     @dataclass(frozen=True)
     class ConnectionProcessed:
         """Event emitted when a message flows through a connection."""
 
-        message: ChatMessage
-        source: MessageEmitter
-        targets: list[MessageNode]
+        message: ChatMessage[Any]
+        source: MessageNode[Any, Any]
+        targets: list[MessageNode[Any, Any]]
         queued: bool
         connection_type: ConnectionType
         timestamp: datetime = field(default_factory=get_now)
@@ -61,8 +61,8 @@ class Talk[TTransmittedData]:
 
     def __init__(
         self,
-        source: MessageEmitter,
-        targets: Sequence[MessageNode],
+        source: MessageNode[Any, Any],
+        targets: Sequence[MessageNode[Any, Any]],
         group: TeamTalk | None = None,
         *,
         name: str | None = None,
@@ -76,7 +76,7 @@ class Talk[TTransmittedData]:
         filter_condition: AnyFilterFn | None = None,
         stop_condition: AnyFilterFn | None = None,
         exit_condition: AnyFilterFn | None = None,
-    ):
+    ) -> None:
         """Initialize talk connection.
 
         Args:
@@ -113,9 +113,7 @@ class Talk[TTransmittedData]:
         self.wait_for_connections = wait_for_connections
         self.queued = queued
         self.queue_strategy = queue_strategy
-        self._pending_messages = defaultdict[str, list[ChatMessage[TTransmittedData]]](
-            list
-        )
+        self._pending_messages = defaultdict[str, list[ChatMessage[TTransmittedData]]](list)
         names = {t.name for t in targets}
         self._stats = TalkStats(source_name=source.name, target_names=names)
         self.transform_fn = transform
@@ -123,7 +121,7 @@ class Talk[TTransmittedData]:
         self.stop_condition = stop_condition
         self.exit_condition = exit_condition
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         targets = [t.name for t in self.targets]
         return f"<Talk({self.connection_type}) {self.source.name} -> {targets}>"
 
@@ -159,7 +157,7 @@ class Talk[TTransmittedData]:
         from llmling_agent.talk import TeamTalk
 
         match other:
-            case Callable():
+            case Callable():  # type: ignore[misc]
                 other = Agent.from_callback(other)
                 if pool := self.source.context.pool:
                     pool.register(other.name, other)
@@ -178,7 +176,7 @@ class Talk[TTransmittedData]:
         self,
         condition: Callable[..., bool | Awaitable[bool]] | None,
         message: ChatMessage[Any],
-        target: MessageNode,
+        target: MessageNode[Any, Any],
         *,
         default_return: bool = False,
     ) -> bool:
@@ -204,14 +202,12 @@ class Talk[TTransmittedData]:
     def on_event(
         self,
         event_type: ConnectionEventType,
-        callback: Callable[
-            [ConnectionEventData[TTransmittedData]], None | Awaitable[None]
-        ],
+        callback: Callable[[ConnectionEventData[TTransmittedData]], None | Awaitable[None]],
     ) -> Self:
         """Register callback for connection events."""
         from llmling_agent.messaging.events import ConnectionEventData
 
-        async def wrapped_callback(event: EventData):
+        async def wrapped_callback(event: EventData) -> None:
             if isinstance(event, ConnectionEventData) and event.event_type == event_type:
                 await execute(callback, event)
 
@@ -222,7 +218,7 @@ class Talk[TTransmittedData]:
         self,
         event_type: ConnectionEventType,
         message: ChatMessage[TTransmittedData] | None,
-    ):
+    ) -> None:
         from llmling_agent.messaging.events import ConnectionEventData
 
         event = ConnectionEventData[Any](
@@ -266,7 +262,7 @@ class Talk[TTransmittedData]:
         if self.transform_fn:
             processed_message = await execute(self.transform_fn, message)
         # 6. First pass: Determine target list
-        target_list: list[MessageNode] = [
+        target_list: list[MessageNode[Any, Any]] = [
             target
             for target in self.targets
             if await self._evaluate_condition(
@@ -298,9 +294,7 @@ class Talk[TTransmittedData]:
             if self.queued:
                 self._pending_messages[target.name].append(processed_message)
                 continue
-            if response := await self._process_for_target(
-                processed_message, target, prompt
-            ):
+            if response := await self._process_for_target(processed_message, target, prompt):
                 responses.append(response)
 
         return responses
@@ -308,7 +302,7 @@ class Talk[TTransmittedData]:
     async def _process_for_target(
         self,
         message: ChatMessage[Any],
-        target: MessageNode,
+        target: MessageNode[Any, Any],
         prompt: PromptCompatible | None = None,
     ) -> ChatMessage[Any] | None:
         """Process message for a single target."""
@@ -332,7 +326,7 @@ class Talk[TTransmittedData]:
                     "prompt": prompt,
                 }
 
-                async def add_context():
+                async def add_context() -> None:
                     match target:
                         case BaseTeam():
                             # Use distribute for teams
@@ -357,7 +351,7 @@ class Talk[TTransmittedData]:
             case "forward":
                 if self.delay is not None or self.priority != 0:
 
-                    async def delayed_emit():
+                    async def delayed_emit() -> None:
                         await target.connections.route_message(message)
 
                     coro = delayed_emit()
@@ -460,7 +454,7 @@ class Talk[TTransmittedData]:
         new_talk = Talk[TNewData](
             source=self.source,
             targets=self.targets,
-            connection_type=self.connection_type,  # type: ignore
+            connection_type=self.connection_type,
         )
 
         if self.transform_fn is not None:
@@ -479,7 +473,7 @@ class Talk[TTransmittedData]:
         return new_talk
 
     @asynccontextmanager
-    async def paused(self):
+    async def paused(self) -> AsyncIterator[Self]:
         """Temporarily set inactive."""
         previous = self.active
         self.active = False
@@ -488,7 +482,7 @@ class Talk[TTransmittedData]:
         finally:
             self.active = previous
 
-    def disconnect(self):
+    def disconnect(self) -> None:
         """Permanently disconnect the connection."""
         self.active = False
 
@@ -498,17 +492,17 @@ class Talk[TTransmittedData]:
         return self._stats
 
 
-class TeamTalk[TTransmittedData](list["Talk | TeamTalk"]):
+class TeamTalk[TTransmittedData = Any](list["Talk | TeamTalk"]):
     """Group of connections with aggregate operations."""
 
     def __init__(
         self, talks: Sequence[Talk[TTransmittedData] | TeamTalk[TTransmittedData]]
-    ):
+    ) -> None:
         super().__init__(talks)
         self.filter_condition: AnyFilterFn | None = None
         self.active = True
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         return f"TeamTalk({list(self)})"
 
     def __rshift__(
@@ -527,7 +521,7 @@ class TeamTalk[TTransmittedData](list["Talk | TeamTalk"]):
         from llmling_agent.talk import TeamTalk
 
         match other:
-            case Callable():
+            case Callable():  # type: ignore[misc]
                 other = Agent.from_callback(other)
                 for talk_ in self.iter_talks():
                     if pool := talk_.source.context.pool:
@@ -545,7 +539,7 @@ class TeamTalk[TTransmittedData](list["Talk | TeamTalk"]):
                 raise TypeError(msg)
 
     @property
-    def targets(self) -> list[MessageNode]:
+    def targets(self) -> list[MessageNode[Any, Any]]:
         """Get all targets from all connections."""
         return [t for talk in self for t in talk.targets]
 
@@ -558,11 +552,11 @@ class TeamTalk[TTransmittedData](list["Talk | TeamTalk"]):
                 case TeamTalk():
                     yield from t.iter_talks()
 
-    async def _handle_message(self, message: ChatMessage[Any], prompt: str | None = None):
+    async def _handle_message(self, message: ChatMessage[Any], prompt: str | None = None) -> None:
         for talk in self:
             await talk._handle_message(message, prompt)
 
-    async def trigger(self, prompt: PromptCompatible | None = None) -> list[ChatMessage]:
+    async def trigger(self, prompt: PromptCompatible | None = None) -> list[ChatMessage[Any]]:
         messages = []
         for talk in self:
             messages.extend(await talk.trigger(prompt))
@@ -571,14 +565,14 @@ class TeamTalk[TTransmittedData](list["Talk | TeamTalk"]):
     @classmethod
     def from_nodes(
         cls,
-        agents: Sequence[MessageNode],
-        targets: list[MessageNode] | None = None,
+        agents: Sequence[MessageNode[Any, Any]],
+        targets: list[MessageNode[Any, Any]] | None = None,
     ) -> Self:
         """Create TeamTalk from a collection of agents."""
         return cls([Talk(agent, targets or []) for agent in agents])
 
     @asynccontextmanager
-    async def paused(self):
+    async def paused(self) -> AsyncIterator[Self]:
         """Temporarily set inactive."""
         previous = self.active
         self.active = False
@@ -606,7 +600,7 @@ class TeamTalk[TTransmittedData](list["Talk | TeamTalk"]):
             talk.when(condition)
         return self
 
-    def disconnect(self):
+    def disconnect(self) -> None:
         """Disconnect all connections in group."""
         for talk in self:
             talk.disconnect()
