@@ -17,12 +17,14 @@ class TaskRegistry(BaseRegistry[str, Job[Any, Any]]):
         return JobRegistrationError
 
     def _validate_item(self, item: Any) -> Job[Any, Any]:
+        from llmling_agent_config.task import Job
+
         if not isinstance(item, Job):
             msg = f"Expected Job, got {type(item)}"
             raise self._error_class(msg)
         return item
 
-    def register(self, name: str, task: Job[Any, Any], replace: bool = False):
+    def register(self, name: str, task: Job[Any, Any], replace: bool = False) -> None:
         """Register a task with name.
 
         Creates a copy of the task with the name set.
