@@ -2,16 +2,15 @@
 
 from __future__ import annotations
 
-from llmling_agent.tools.base import ToolContext, Tool
+from llmling_agent.tools.base import Tool
 from llmling_agent.tools.manager import ToolManager, ToolError
 from llmling_agent.tools.tool_call_info import ToolCallInfo
-from llmling_agent.tools.skills import SkillsRegistry
+from llmling_agent.skills.registry import SkillsRegistry
 
 __all__ = [
     "SkillsRegistry",
     "Tool",
     "ToolCallInfo",
-    "ToolContext",
     "ToolError",
     "ToolManager",
 ]
