@@ -4,23 +4,23 @@ from __future__ import annotations
 
 from dataclasses import dataclass, field
 import inspect
-from typing import TYPE_CHECKING, Any, Literal, Self
+from typing import TYPE_CHECKING, Any, Literal
 
 import logfire
+from pydantic_ai.tools import Tool as PydanticAiTool
 import schemez
 
 from llmling_agent.log import get_logger
-from llmling_agent.utils.inspection import execute
+from llmling_agent.utils.inspection import dataclasses_no_defaults_repr, execute
 from llmling_agent_config.tools import ToolHints  # noqa: TC001
 
 
 if TYPE_CHECKING:
-    from collections.abc import Callable
+    from collections.abc import Awaitable, Callable
 
     from mcp.types import Tool as MCPTool
-    from schemez.typedefs import Property, ToolParameters
+    from schemez import FunctionSchema, Property
 
-    from llmling_agent.agent import AgentContext
     from llmling_agent.common_types import ToolSource
     from llmling_agent.tools.manager import ToolState
 
@@ -40,57 +40,27 @@ ToolKind = Literal[
 ]
 
 
-@dataclass(frozen=True)
-class ToolContext:
-    """Context for tool execution confirmation."""
-
-    name: str
-    """Name of the tool being executed"""
-
-    args: dict[str, Any]
-    """Arguments being passed to the tool"""
-
-    schema: schemez.OpenAIFunctionTool
-    """Complete OpenAI function schema"""
-
-    runtime_ctx: AgentContext
-    """Runtime context from agent"""
-
-    @property
-    def description(self) -> str | None:
-        """Get tool description from schema."""
-        return self.schema["function"].get("description")
-
-    @property
-    def parameters(self) -> ToolParameters:
-        """Get parameter definitions from schema."""
-        return self.schema["function"].get("parameters", {})  # type: ignore
-
-    def __str__(self) -> str:
-        """Format tool context for logging/display."""
-        return (
-            f"Tool: {self.name}\n"
-            f"Arguments: {self.args}\n"
-            f"Description: {self.description or 'N/A'}"
-        )
-
-
 @dataclass
-class Tool:
+class Tool[TOutputType = Any]:
     """Information about a registered tool."""
 
-    callable: Callable
+    callable: Callable[..., TOutputType]
     """The actual tool implementation"""
 
     name: str
+    """The name of the tool."""
 
     description: str = ""
+    """The description of the tool."""
 
     schema_override: schemez.OpenAIFunctionDefinition | None = None
+    """Schema override. If not set, the schema is inferred from the callable."""
 
     hints: ToolHints | None = None
+    """Hints for the tool."""
 
     import_path: str | None = None
+    """The import path for the tool."""
 
     enabled: bool = True
     """Whether the tool is currently enabled"""
@@ -98,33 +68,50 @@ class Tool:
     source: ToolSource = "dynamic"
     """Where the tool came from."""
 
-    priority: int = 100
-    """Priority for tool execution (lower = higher priority)"""
-
     requires_confirmation: bool = False
     """Whether tool execution needs explicit confirmation"""
 
-    requires_capability: str | None = None
-    """Optional capability required to use this tool"""
-
     agent_name: str | None = None
     """The agent name as an identifier for agent-as-a-tool."""
 
     metadata: dict[str, str] = field(default_factory=dict)
     """Additional tool metadata"""
 
-    cache_enabled: bool = False
-    """Whether to enable caching for this tool."""
-
     category: ToolKind | None = None
     """The category of the tool."""
 
+    __repr__ = dataclasses_no_defaults_repr
+
+    def to_pydantic_ai(self) -> PydanticAiTool:
+        """Convert tool to Pydantic AI tool."""
+        metadata = {
+            **self.metadata,
+            "agent_name": self.agent_name,
+            "category": self.category,
+        }
+        return PydanticAiTool(
+            function=self.callable,
+            name=self.name,
+            # takes_ctx=self.takes_ctx,
+            # max_retries=self.max_retries,
+            description=self.description,
+            requires_approval=self.requires_confirmation,
+            metadata=metadata,
+        )
+
+    @property
+    def schema_obj(self) -> FunctionSchema:
+        """Get the OpenAI function schema for the tool."""
+        return schemez.create_schema(
+            self.callable,
+            name_override=self.name,
+            description_override=self.description,
+        )
+
     @property
     def schema(self) -> schemez.OpenAIFunctionTool:
         """Get the OpenAI function schema for the tool."""
-        schema = schemez.create_schema(self.callable).model_dump_openai()
-        schema["function"]["name"] = self.name
-        schema["function"]["description"] = self.description
+        schema = self.schema_obj.model_dump_openai()
         if self.schema_override:
             schema["function"] = self.schema_override
         return schema
@@ -180,7 +167,7 @@ class Tool:
         code: str,
         name: str | None = None,
         description: str | None = None,
-    ) -> Self:
+    ) -> Tool[Any]:
         """Create a tool from a code string."""
         namespace: dict[str, Any] = {}
         exec(code, namespace)
@@ -189,20 +176,22 @@ class Tool:
             msg = "No callable found in provided code"
             raise ValueError(msg)
         return cls.from_callable(
-            func, name_override=name, description_override=description
+            func,  # pyright: ignore[reportArgumentType]
+            name_override=name,
+            description_override=description,
         )
 
     @classmethod
     def from_callable(
         cls,
-        fn: Callable[..., Any] | str,
+        fn: Callable[..., TOutputType | Awaitable[TOutputType]] | str,
         *,
         name_override: str | None = None,
         description_override: str | None = None,
         schema_override: schemez.OpenAIFunctionDefinition | None = None,
         hints: ToolHints | None = None,
         **kwargs: Any,
-    ) -> Self:
+    ) -> Tool[TOutputType]:
         if isinstance(fn, str):
             import_path = fn
             from llmling_agent.utils import importing
@@ -221,7 +210,7 @@ class Tool:
                 import_path = f"{module}.{fn.__class__.__qualname__}"
 
         return cls(
-            callable=callable_obj,
+            callable=callable_obj,  # pyright: ignore[reportArgumentType]
             name=name_override or name,
             description=description_override or inspect.getdoc(callable_obj) or "",
             import_path=import_path,
@@ -239,11 +228,13 @@ class Tool:
         description_override: str | None = None,
         schema_override: schemez.OpenAIFunctionDefinition | None = None,
         **kwargs: Any,
-    ) -> Self:
+    ) -> Tool[Any]:
         """Allows importing crewai tools."""
         # vaidate_import("crewai_tools", "crewai")
         try:
-            from crewai.tools import BaseTool as CrewAiBaseTool  # pyright: ignore
+            from crewai.tools import (  # type: ignore[import-not-found]
+                BaseTool as CrewAiBaseTool,
+            )
         except ImportError as e:
             msg = "crewai package not found. Please install it with 'pip install crewai'"
             raise ImportError(msg) from e
@@ -269,11 +260,11 @@ class Tool:
         description_override: str | None = None,
         schema_override: schemez.OpenAIFunctionDefinition | None = None,
         **kwargs: Any,
-    ) -> Self:
+    ) -> Tool[Any]:
         """Create a tool from a LangChain tool."""
         # vaidate_import("langchain_core", "langchain")
         try:
-            from langchain_core.tools import (  # pyright: ignore
+            from langchain_core.tools import (  # type: ignore[import-not-found]
                 BaseTool as LangChainBaseTool,
             )
         except ImportError as e:
@@ -301,12 +292,12 @@ class Tool:
         description_override: str | None = None,
         schema_override: schemez.OpenAIFunctionDefinition | None = None,
         **kwargs: Any,
-    ) -> Self:
+    ) -> Tool[Any]:
         """Create a tool from a AutoGen tool."""
         # vaidate_import("autogen_core", "autogen")
         try:
-            from autogen_core import CancellationToken  # pyright: ignore
-            from autogen_core.tools import BaseTool  # pyright: ignore
+            from autogen_core import CancellationToken  # type: ignore[import-not-found]
+            from autogen_core.tools import BaseTool  # type: ignore[import-not-found]
         except ImportError as e:
             msg = "autogent_core package not found."
             raise ImportError(msg) from e
@@ -316,14 +307,11 @@ class Tool:
             raise TypeError(msg)
         token = CancellationToken()
 
-        input_model = tool.__class__.__orig_bases__[0].__args__[0]  # type: ignore
+        input_model = tool.__class__.__orig_bases__[0].__args__[0]
 
         name = name_override or tool.name or tool.__class__.__name__.removesuffix("Tool")
         description = (
-            description_override
-            or tool.description
-            or inspect.getdoc(tool.__class__)
-            or ""
+            description_override or tool.description or inspect.getdoc(tool.__class__) or ""
         )
 
         async def wrapper(**kwargs: Any) -> Any:
@@ -332,7 +320,7 @@ class Tool:
             return await tool.run(model, cancellation_token=token)
 
         return cls.from_callable(
-            wrapper,  # type: ignore
+            wrapper,
             name_override=name,
             description_override=description,
             schema_override=schema_override,
@@ -373,3 +361,9 @@ class ToolParameter:
         type_str = f": {self.type_info}" if self.type_info else ""
         desc = f" - {self.description}" if self.description else ""
         return f"{self.name}{req}{type_str}{desc}"
+
+
+if __name__ == "__main__":
+    import webbrowser
+
+    t = Tool.from_callable(webbrowser.open)
