@@ -2,18 +2,22 @@ from __future__ import annotations
 
 import asyncio
 from collections.abc import Sequence
+from dataclasses import fields
+import functools
 from importlib.util import find_spec
 import inspect
 from types import UnionType
 from typing import (
     TYPE_CHECKING,
     Any,
+    Literal,
     TypeAliasType,
     TypeGuard,
     Union,
     get_args,
     get_origin,
     get_type_hints,
+    overload,
 )
 
 
@@ -26,6 +30,34 @@ if TYPE_CHECKING:
 PACKAGE_NAME = "llmling-agent"
 
 
+def dataclasses_no_defaults_repr(self: Any) -> str:
+    """Exclude fields with values equal to the field default."""
+    kv_pairs = (
+        f"{f.name}={getattr(self, f.name)!r}"
+        for f in fields(self)
+        if f.repr and getattr(self, f.name) != f.default
+    )
+    return f"{self.__class__.__qualname__}({', '.join(kv_pairs)})"
+
+
+@overload
+async def execute[T](
+    func: Callable[..., Awaitable[T]],
+    *args: Any,
+    use_thread: bool = False,
+    **kwargs: Any,
+) -> T: ...
+
+
+@overload
+async def execute[T](
+    func: Callable[..., T | Awaitable[T]],
+    *args: Any,
+    use_thread: bool = False,
+    **kwargs: Any,
+) -> T: ...
+
+
 async def execute[T](
     func: Callable[..., T | Awaitable[T]],
     *args: Any,
@@ -34,20 +66,25 @@ async def execute[T](
 ) -> T:
     """Execute callable, handling both sync and async cases."""
     if inspect.iscoroutinefunction(func):
-        return await func(*args, **kwargs)
+        return await func(*args, **kwargs)  # type: ignore[no-any-return]
 
     if use_thread:
-        return await asyncio.to_thread(func, *args, **kwargs)  # type: ignore
+        result = await asyncio.to_thread(func, *args, **kwargs)
+    else:
+        result = func(*args, **kwargs)
 
-    return func(*args, **kwargs)  # type: ignore
+    if inspect.iscoroutine(result) or inspect.isawaitable(result):
+        return await result
+
+    return result
 
 
-def has_argument_type(
+def get_argument_key(
     func: Callable[..., Any],
     arg_type: type | str | UnionType | Sequence[type | str | UnionType],
     include_return: bool = False,
-) -> bool:
-    """Check if function has any argument of specified type(s).
+) -> Literal[False] | str:
+    """Check if function has any argument of specified type(s) and return the key.
 
     Args:
         func: Function to check
@@ -60,14 +97,16 @@ def has_argument_type(
 
     Examples:
         >>> def func(x: int | str, y: list[int]): ...
-        >>> has_argument_type(func, int | str)  # True
-        >>> has_argument_type(func, int)        # True
-        >>> has_argument_type(func, list)       # True
-        >>> has_argument_type(func, float)      # False
-        >>> has_argument_type(func, (int, str)) # True
+        >>> get_argument_key(func, int | str)  # Returns 'x'
+        >>> get_argument_key(func, int)        # Returns 'x'
+        >>> get_argument_key(func, list)       # Returns 'y'
+        >>> get_argument_key(func, float)      # Returns False
+        >>> get_argument_key(func, (int, str)) # Returns 'x'
 
     Returns:
-        True if any argument matches any of the target types
+        Parameter name (str) if a matching argument is found, False otherwise.
+        Only checks the origin type for generics, not type arguments
+        (e.g., list[int] matches 'list', but does not match 'int').
     """
     # Convert target type(s) to set of normalized strings
     if isinstance(arg_type, Sequence) and not isinstance(arg_type, str | bytes):
@@ -81,14 +120,14 @@ def has_argument_type(
         hints.pop("return", None)
 
     # Check each parameter's type annotation
-    for param_type in hints.values():
+    for key, param_type in hints.items():
         # Handle type aliases
         if isinstance(param_type, TypeAliasType):
             param_type = param_type.__value__
 
         # Check for direct match
         if _type_to_string(param_type) in target_types:
-            return True
+            return key
 
         # Handle Union types (both | and Union[...])
         origin = get_origin(param_type)
@@ -96,24 +135,43 @@ def has_argument_type(
             union_members = get_args(param_type)
             # Check each union member
             if any(_type_to_string(t) in target_types for t in union_members):
-                return True
+                return key
             # Also check if the complete union type matches
             if _type_to_string(param_type) in target_types:
-                return True
+                return key
 
         # Handle generic types (list[str], dict[str, int], etc)
-        if origin is not None:
-            # Check if the generic type (e.g., list) matches
-            if _type_to_string(origin) in target_types:
-                return True
-            # Check type arguments (e.g., str in list[str])
-            args = get_args(param_type)
-            if any(_type_to_string(arg) in target_types for arg in args):
-                return True
+        # Only check the origin type (e.g., list), not the arguments
+        # This avoids matching nested contexts like RunContext[AgentContext]
+        if origin is not None and _type_to_string(origin) in target_types:
+            return key
+
+        # if origin is not None:
+        #     # Check if the generic type (e.g., list) matches
+        #     if _type_to_string(origin) in target_types:
+        #         return key
+        #     # Check type arguments (e.g., str in list[str])
+        #     args = get_args(param_type)
+        #     if any(_type_to_string(arg) in target_types for arg in args):
+        #         return key
 
     return False
 
 
+def is_async_callable(obj: Any) -> Any:
+    """Correctly check if a callable is async.
+
+    This function was copied from Starlette:
+    https://github.com/encode/starlette/blob/78da9b9e218ab289117df7d62aee200ed4c59617/starlette/_utils.py#L36-L40
+    """
+    while isinstance(obj, functools.partial):
+        obj = obj.func
+
+    return inspect.iscoroutinefunction(obj) or (
+        callable(obj) and inspect.iscoroutinefunction(obj.__call__)
+    )
+
+
 def _type_to_string(type_hint: Any) -> str:
     """Convert type to normalized string representation for comparison."""
     match type_hint:
@@ -200,15 +258,15 @@ def call_with_context[T](
     from llmling_agent.agent import AgentContext
 
     if inspect.ismethod(func):
-        if has_argument_type(func, AgentContext):
-            return func(context)
-        return func()
-    if has_argument_type(func, AgentContext):
+        if get_argument_key(func, AgentContext):
+            return func(context)  # type: ignore[no-any-return]
+        return func()  # type: ignore[no-any-return]
+    if get_argument_key(func, AgentContext):
         return func(context, **kwargs)
     return func(context.data)
 
 
-def validate_import(module_path: str, extras_name: str):
+def validate_import(module_path: str, extras_name: str) -> None:
     """Check existence of module, showing helpful error if not installed."""
     if not find_spec(module_path):
         msg = f"""
