@@ -4,15 +4,19 @@ from __future__ import annotations
 
 import asyncio
 from datetime import UTC, datetime
+from typing import TYPE_CHECKING
 
-from llmling.cli.constants import output_format_opt
-from llmling.cli.utils import OutputFormat, format_output
 import typer as t
 
 from llmling_agent import AgentsManifest, log
 from llmling_agent.utils.parse_time import parse_time_period
 from llmling_agent_cli import resolve_agent_config
 from llmling_agent_cli.cli_types import GroupBy
+from llmling_agent_cli.common import OutputFormat, format_output, output_format_opt
+
+
+if TYPE_CHECKING:
+    from llmling_agent_storage.base import StorageProvider
 
 
 logger = log.get_logger(__name__)
@@ -28,7 +32,7 @@ TOKEN_HELP = "Include token usage statistics"
 CONFIG_HELP = "Override agent config path"
 
 
-def get_history_provider(config_path: str):
+def get_history_provider(config_path: str) -> StorageProvider:
     """Get history provider from manifest config.
 
     Args:
@@ -59,7 +63,7 @@ def show_history(
     compact: bool = t.Option(False, "--compact", help=COMPACT_HELP),
     tokens: bool = t.Option(False, "--tokens", "-t", help=TOKEN_HELP),
     output_format: OutputFormat = output_format_opt,
-):
+) -> None:
     """Show conversation history with filtering options.
 
     Examples:
@@ -86,7 +90,7 @@ def show_history(
         config_path = resolve_agent_config(config)
         provider = get_history_provider(config_path)
 
-        async def main():
+        async def main() -> None:
             async with provider:
                 results = await provider.get_filtered_conversations(
                     agent_name=agent_name,
@@ -111,12 +115,10 @@ def show_history(
 def show_stats(
     agent_name: str | None = t.Argument(None, help=AGENT_NAME_HELP),
     config: str | None = t.Option(None, "--config", "-c", help=CONFIG_HELP),
-    period: str = t.Option(
-        "1d", "--period", "-p", help="Time period (1h, 1d, 1w, 1m, 1y)"
-    ),
+    period: str = t.Option("1d", "--period", "-p", help="Time period (1h, 1d, 1w, 1m, 1y)"),
     group_by: GroupBy = t.Option("agent", "--group-by", "-g", help="Group by"),  # noqa: B008
     output_format: OutputFormat = output_format_opt,
-):
+) -> None:
     """Show usage statistics.
 
     Examples:
@@ -139,9 +141,9 @@ def show_stats(
 
         # Create filters
         cutoff = datetime.now(UTC) - parse_time_period(period)
-        filters = StatsFilters(cutoff=cutoff, group_by=group_by, agent_name=agent_name)  # type: ignore
+        filters = StatsFilters(cutoff=cutoff, group_by=group_by, agent_name=agent_name)
 
-        async def main():
+        async def main() -> None:
             async with provider:
                 stats = await provider.get_conversation_stats(filters)
             formatted = format_stats(stats, period, group_by)
@@ -158,13 +160,9 @@ def show_stats(
 def reset_history(
     config: str | None = t.Option(None, "--config", "-c", help=CONFIG_HELP),
     confirm: bool = t.Option(False, "--confirm", "-y", help="Confirm deletion"),
-    agent_name: str | None = t.Option(
-        None, "--agent", "-a", help="Only delete for specific agent"
-    ),
-    hard: bool = t.Option(
-        False, "--hard", help="Drop and recreate tables (for schema changes)"
-    ),
-):
+    agent_name: str | None = t.Option(None, "--agent", "-a", help="Only delete for specific agent"),
+    hard: bool = t.Option(False, "--hard", help="Drop and recreate tables (for schema changes)"),
+) -> None:
     """Reset (clear) conversation history.
 
     Examples:
@@ -192,16 +190,12 @@ def reset_history(
                 print("Operation cancelled.")
                 return
 
-        async def main():
+        async def main() -> None:
             async with provider:
-                conv_count, msg_count = await provider.reset(
-                    agent_name=agent_name, hard=hard
-                )
+                conv_count, msg_count = await provider.reset(agent_name=agent_name, hard=hard)
 
                 what = f" for {agent_name}" if agent_name else ""
-                print(
-                    f"Deleted {conv_count} conversations and {msg_count} messages{what}."
-                )
+                print(f"Deleted {conv_count} conversations and {msg_count} messages{what}.")
 
         asyncio.run(main())
 
