@@ -6,12 +6,12 @@ import asyncio
 import traceback
 from typing import TYPE_CHECKING, Any
 
-from llmling.cli.constants import verbose_opt
 import typer as t
 
 from llmling_agent import AgentPool
 from llmling_agent_cli import resolve_agent_config
 from llmling_agent_cli.cli_types import DetailLevel  # noqa: TC001
+from llmling_agent_cli.common import verbose_opt
 
 
 if TYPE_CHECKING:
@@ -31,7 +31,7 @@ def run_command(
     show_metadata: bool = t.Option(False, "--metadata", help="Show message metadata"),
     show_costs: bool = t.Option(False, "--costs", help="Show token usage and costs"),
     verbose: bool = verbose_opt,
-):
+) -> None:
     """Run a node (agent/team) with prompts.
 
     Examples:
@@ -52,13 +52,13 @@ def run_command(
             error_msg = str(e)
             raise t.BadParameter(error_msg) from e
 
-        async def run():
+        async def run() -> None:
             async with AgentPool(config_path) as pool:
 
-                def on_message(chat_message: ChatMessage[Any]):
+                def on_message(chat_message: ChatMessage[Any]) -> None:
                     print(
                         chat_message.format(
-                            style=detail_level,  # type: ignore
+                            style=detail_level,
                             show_metadata=show_metadata,
                             show_costs=show_costs,
                         )
@@ -74,7 +74,7 @@ def run_command(
                     if not show_messages:
                         print(
                             response.format(
-                                style=detail_level,  # type: ignore
+                                style=detail_level,
                                 show_metadata=show_metadata,
                                 show_costs=show_costs,
                             )
