@@ -48,7 +48,7 @@ class CreateAgentCommand(SlashedCommand):
         role: str | None = None,
         description: str | None = None,
         tools: str | None = None,
-    ):
+    ) -> None:
         """Create a new agent in the current session.
 
         Args:
@@ -85,9 +85,7 @@ class CreateAgentCommand(SlashedCommand):
             msg = f"✅ **Created agent** `{agent_name}`"
             if tool_list:
                 msg += f" with tools: `{', '.join(tool_list)}`"
-            await ctx.print(
-                f"{msg}\n\n💡 Use `/connect {agent_name}` to forward messages"
-            )
+            await ctx.print(f"{msg}\n\n💡 Use `/connect {agent_name}` to forward messages")
 
         except ValueError as e:
             msg = f"Failed to create agent: {e}"
@@ -111,7 +109,7 @@ class ShowAgentCommand(SlashedCommand):
     name = "show-agent"
     category = "agents"
 
-    async def execute_command(self, ctx: CommandContext[NodeContext]):
+    async def execute_command(self, ctx: CommandContext[NodeContext]) -> None:
         """Show current agent's configuration.
 
         Args:
@@ -160,7 +158,7 @@ class ListAgentsCommand(SlashedCommand):
     name = "list-agents"
     category = "agents"
 
-    async def execute_command(self, ctx: CommandContext[AgentContext]):
+    async def execute_command(self, ctx: CommandContext[AgentContext]) -> None:
         """List all available agents.
 
         Args:
@@ -200,7 +198,7 @@ class SwitchAgentCommand(SlashedCommand):
         self,
         ctx: CommandContext[AgentContext],
         agent_name: str,
-    ):
+    ) -> None:
         """Switch to a different agent.
 
         Args:
@@ -210,6 +208,6 @@ class SwitchAgentCommand(SlashedCommand):
         msg = "Temporarily disabled"
         raise RuntimeError(msg)
 
-    def get_completer(self):
+    def get_completer(self) -> CallbackCompleter:
         """Get completer for agent names."""
         return CallbackCompleter(get_available_agents)
