@@ -2,33 +2,29 @@
 
 from __future__ import annotations
 
-from typing import TYPE_CHECKING, Any
+from typing import Any
 
 from rich.tree import Tree
 from slashed import CommandContext, CommandError, SlashedCommand  # noqa: TC002
 from slashed.completers import CallbackCompleter
 
 from llmling_agent.log import get_logger
+from llmling_agent.messaging import MessageNode
 from llmling_agent.messaging.context import NodeContext  # noqa: TC001
-from llmling_agent.messaging.messagenode import MessageNode
 from llmling_agent_commands.completers import get_available_nodes
 
 
-if TYPE_CHECKING:
-    from llmling_agent.messaging import MessageEmitter
-
-
 logger = get_logger(__name__)
 
 
-def format_node_name(node: MessageEmitter[Any, Any], current: bool = False) -> str:
+def format_node_name(node: MessageNode[Any, Any], current: bool = False) -> str:
     """Format node name for display."""
     name = node.name
     if current:
-        return f"[bold blue]{name}[/]"
+        return f"► {name} (current)"
     if node.connections.get_targets():
-        return f"[green]{name}[/]"
-    return f"[dim]{name}[/]"
+        return f"● {name}"
+    return f"○ {name}"
 
 
 class ConnectCommand(SlashedCommand):
@@ -50,7 +46,7 @@ class ConnectCommand(SlashedCommand):
         node_name: str,
         *,
         wait: bool = True,
-    ):
+    ) -> None:
         """Connect to another node.
 
         Args:
@@ -58,23 +54,20 @@ class ConnectCommand(SlashedCommand):
             node_name: Name of the node to connect to
             wait: Whether to wait for responses (default: True)
         """
-        source = ctx.context.node_name
-
         try:
             assert ctx.context.pool
             target_node = ctx.context.pool[node_name]
             assert isinstance(target_node, MessageNode)
             ctx.context.node.connect_to(target_node)
             ctx.context.node.connections.set_wait_state(node_name, wait)
-
-            wait_text = "*(waiting for responses)*" if wait else "*(async)*"
-            msg = f"🔗 **Connected:** `{source}` → `{node_name}` {wait_text}"
+            text = "*(waiting for responses)*" if wait else "*(async)*"
+            msg = f"🔗 **Connected:** `{ctx.context.node_name}` → `{node_name}` {text}"
             await ctx.print(msg)
         except Exception as e:
-            msg = f"Failed to connect {source!r} to {node_name!r}: {e}"
+            msg = f"Failed to connect {ctx.context.node_name!r} to {node_name!r}: {e}"
             raise CommandError(msg) from e
 
-    def get_completer(self):
+    def get_completer(self) -> CallbackCompleter:
         """Get completer for node names."""
         return CallbackCompleter(get_available_nodes)
 
@@ -94,7 +87,7 @@ class DisconnectCommand(SlashedCommand):
         self,
         ctx: CommandContext[NodeContext],
         node_name: str,
-    ):
+    ) -> None:
         """Disconnect from another node.
 
         Args:
@@ -112,7 +105,7 @@ class DisconnectCommand(SlashedCommand):
             msg = f"{source!r} failed to disconnect from {node_name!r}: {e}"
             raise CommandError(msg) from e
 
-    def get_completer(self):
+    def get_completer(self) -> CallbackCompleter:
         """Get completer for node names."""
         return CallbackCompleter(get_available_nodes)
 
@@ -126,14 +119,14 @@ class DisconnectAllCommand(SlashedCommand):
     name = "disconnect-all"
     category = "nodes"
 
-    async def execute_command(self, ctx: CommandContext[NodeContext]):
+    async def execute_command(self, ctx: CommandContext[NodeContext]) -> None:
         """Disconnect from all nodes.
 
         Args:
             ctx: Command context
         """
         if not ctx.context.node.connections.get_targets():
-            await ctx.print("ℹ️ **No active connections**")  #  noqa: RUF001
+            await ctx.print("ℹ️ **No active connections**")  # noqa: RUF001
             return
         source = ctx.context.node_name
         await ctx.context.node.disconnect_all()
@@ -152,14 +145,14 @@ class ListConnectionsCommand(SlashedCommand):
     name = "connections"
     category = "nodes"
 
-    async def execute_command(self, ctx: CommandContext[NodeContext]):
+    async def execute_command(self, ctx: CommandContext[NodeContext]) -> None:
         """List current connections.
 
         Args:
             ctx: Command context
         """
         if not ctx.context.node.connections.get_targets():
-            await ctx.print("ℹ️ **No active connections**")  #  noqa: RUF001
+            await ctx.print("ℹ️ **No active connections**")  # noqa: RUF001
             return
 
         # Create tree visualization
