@@ -24,7 +24,7 @@ class ShowPromptCommand(SlashedCommand):
         self,
         ctx: CommandContext[AgentContext],
         identifier: str,
-    ):
+    ) -> None:
         """Show prompt content.
 
         Args:
@@ -38,7 +38,7 @@ class ShowPromptCommand(SlashedCommand):
             msg = f"Error getting prompt: {e}"
             raise CommandError(msg) from e
 
-    def get_completer(self):
+    def get_completer(self) -> PromptCompleter:
         """Get completer for prompt names."""
         return PromptCompleter()
 
@@ -53,7 +53,7 @@ class ListPromptsCommand(SlashedCommand):
     name = "list-prompts"
     category = "prompts"
 
-    async def execute_command(self, ctx: CommandContext[AgentContext]):
+    async def execute_command(self, ctx: CommandContext[AgentContext]) -> None:
         """List available prompts from all providers.
 
         Args:
@@ -77,7 +77,5 @@ class ListPromptsCommand(SlashedCommand):
                     output_lines.append(f"- **{prompt_name}**{desc}")
             else:
                 # For other providers, just show names
-                output_lines.extend(
-                    f"- `{prompt_name}`" for prompt_name in sorted_prompts
-                )
+                output_lines.extend(f"- `{prompt_name}`" for prompt_name in sorted_prompts)
         await ctx.print("\n".join(output_lines))
