@@ -42,7 +42,7 @@ class ReadCommand(SlashedCommand):
         path: str,
         *,
         convert_to_md: bool = False,
-    ):
+    ) -> None:
         """Read file content into conversation.
 
         Args:
@@ -52,17 +52,13 @@ class ReadCommand(SlashedCommand):
         """
         try:
             agent = ctx.context.agent
-            await agent.conversation.add_context_from_path(
-                path, convert_to_md=convert_to_md
-            )
-            await ctx.print(
-                f"📄 **Added content from** {path!r} **to next message as context**"
-            )
+            await agent.conversation.add_context_from_path(path, convert_to_md=convert_to_md)
+            await ctx.print(f"📄 **Added content from** {path!r} **to next message as context**")
         except Exception as e:
             msg = f"Unexpected error reading {path}: {e}"
             logger.exception(msg)
             raise CommandError(msg) from e
 
-    def get_completer(self):
+    def get_completer(self) -> PathCompleter:
         """Get completer for file paths."""
         return PathCompleter()
