@@ -16,7 +16,7 @@ class ClearCommand(SlashedCommand):
     name = "clear"
     category = "session"
 
-    async def execute_command(self, ctx: CommandContext[AgentContext]):
+    async def execute_command(self, ctx: CommandContext[AgentContext]) -> None:
         """Clear chat history.
 
         Args:
@@ -37,13 +37,11 @@ class ResetCommand(SlashedCommand):
     name = "reset"
     category = "session"
 
-    async def execute_command(self, ctx: CommandContext[AgentContext]):
+    async def execute_command(self, ctx: CommandContext[AgentContext]) -> None:
         """Reset session state.
 
         Args:
             ctx: Command context
         """
         await ctx.context.agent.reset()
-        await ctx.print(
-            "🔄 **Session state reset** - history cleared, tools and settings restored"
-        )
+        await ctx.print("🔄 **Session state reset** - history cleared, tools and settings restored")
