@@ -33,7 +33,7 @@ class ListToolsCommand(SlashedCommand):
         self,
         ctx: CommandContext[AgentContext],
         source: str | None = None,
-    ):
+    ) -> None:
         """List all available tools.
 
         Args:
@@ -63,7 +63,6 @@ class ShowToolCommand(SlashedCommand):
     Shows:
     - Source (runtime/agent/builtin)
     - Current status (enabled/disabled)
-    - Priority and capabilities
     - Parameter descriptions
     - Additional metadata
 
@@ -77,7 +76,7 @@ class ShowToolCommand(SlashedCommand):
         self,
         ctx: CommandContext[AgentContext],
         name: str,
-    ):
+    ) -> None:
         """Show detailed information about a tool.
 
         Args:
@@ -88,20 +87,15 @@ class ShowToolCommand(SlashedCommand):
 
         try:
             tool_info = await agent.tools.get_tool(name)
-            assert tool_info, f"Tool {name} not found"
             # Start with the standard tool info format
             sections = [tool_info.format_info(indent="")]
 
             # Add extra metadata section if we have any additional info
             extra_info = []
-            if tool_info.requires_capability:
-                extra_info.append(f"Required Capability: {tool_info.requires_capability}")
             if tool_info.requires_confirmation:
                 extra_info.append("Requires Confirmation: Yes")
             if tool_info.source != "dynamic":  # Only show if not default
                 extra_info.append(f"Source: {tool_info.source}")
-            if tool_info.priority != 100:  # Only show if not default  # noqa: PLR2004
-                extra_info.append(f"Priority: {tool_info.priority}")
             if tool_info.metadata:
                 extra_info.append("\nMetadata:")
                 extra_info.extend(f"- {k}: {v}" for k, v in tool_info.metadata.items())
@@ -113,7 +107,7 @@ class ShowToolCommand(SlashedCommand):
         except KeyError:
             await ctx.print(f"❌ **Tool** `{name}` **not found**")
 
-    def get_completer(self):
+    def get_completer(self) -> CallbackCompleter:
         """Get completer for tool names."""
         return CallbackCompleter(get_tool_names)
 
@@ -133,7 +127,7 @@ class EnableToolCommand(SlashedCommand):
         self,
         ctx: CommandContext[AgentContext],
         name: str,
-    ):
+    ) -> None:
         """Enable a tool.
 
         Args:
@@ -141,13 +135,13 @@ class EnableToolCommand(SlashedCommand):
             name: Tool name to enable
         """
         try:
-            ctx.context.agent.tools.enable_tool(name)
+            await ctx.context.agent.tools.enable_tool(name)
             await ctx.print(f"✅ **Tool** `{name}` **enabled**")
         except ValueError as e:
             msg = f"Failed to enable tool: {e}"
             raise CommandError(msg) from e
 
-    def get_completer(self):
+    def get_completer(self) -> CallbackCompleter:
         """Get completer for tool names."""
         return CallbackCompleter(get_tool_names)
 
@@ -167,7 +161,7 @@ class DisableToolCommand(SlashedCommand):
         self,
         ctx: CommandContext[AgentContext],
         name: str,
-    ):
+    ) -> None:
         """Disable a tool.
 
         Args:
@@ -175,13 +169,13 @@ class DisableToolCommand(SlashedCommand):
             name: Tool name to disable
         """
         try:
-            ctx.context.agent.tools.disable_tool(name)
+            await ctx.context.agent.tools.disable_tool(name)
             await ctx.print(f"❌ **Tool** `{name}` **disabled**")
         except ValueError as e:
             msg = f"Failed to disable tool: {e}"
             raise CommandError(msg) from e
 
-    def get_completer(self):
+    def get_completer(self) -> CallbackCompleter:
         """Get completer for tool names."""
         return CallbackCompleter(get_tool_names)
 
@@ -205,7 +199,7 @@ class RegisterToolCommand(SlashedCommand):
         *,
         name: str | None = None,
         description: str | None = None,
-    ):
+    ) -> None:
         """Register a new tool from import path or function.
 
         Args:
