@@ -40,7 +40,7 @@ class AddWorkerCommand(SlashedCommand):
         *,
         reset_history: str = "true",
         share_history: str = "false",
-    ):
+    ) -> None:
         """Add another agent as a worker tool.
 
         Args:
@@ -70,7 +70,7 @@ class AddWorkerCommand(SlashedCommand):
             )
 
             await ctx.print(
-                f"✅ **Added agent** `{worker_name}` **as worker tool:** `{tool_info.name}`\n"  # noqa: E501
+                f"✅ **Added agent** `{worker_name}` **as worker tool:** `{tool_info.name}`\n"
                 f"🔧 **Tool enabled:** {tool_info.enabled}"
             )
 
@@ -81,7 +81,7 @@ class AddWorkerCommand(SlashedCommand):
             msg = f"Failed to add worker: {e}"
             raise CommandError(msg) from e
 
-    def get_completer(self):
+    def get_completer(self) -> CallbackCompleter:
         """Get completer for agent names."""
         return CallbackCompleter(get_available_agents)
 
@@ -100,7 +100,7 @@ class RemoveWorkerCommand(SlashedCommand):
         self,
         ctx: CommandContext[AgentContext],
         worker_name: str,
-    ):
+    ) -> None:
         """Remove a worker tool.
 
         Args:
@@ -110,25 +110,13 @@ class RemoveWorkerCommand(SlashedCommand):
         tool_name = f"ask_{worker_name}"  # Match the naming in to_tool
 
         try:
-            if tool_name not in ctx.context.agent.tools:
-                msg = f"No worker tool found for agent: {worker_name}"
-                raise CommandError(msg)  # noqa: TRY301
-
-            # Check if it's actually a worker tool
-            tool_info = ctx.context.agent.tools[tool_name]
-            if tool_info.source != "agent":
-                msg = f"{tool_name} is not a worker tool"
-                raise CommandError(msg)  # noqa: TRY301
-
-            # Remove the tool
-            del ctx.context.agent.tools[tool_name]
+            ctx.context.agent.tools.worker_provider.remove_tool(tool_name)
             await ctx.print(f"🗑️ **Removed worker tool:** `{tool_name}`")
-
         except Exception as e:
             msg = f"Failed to remove worker: {e}"
             raise CommandError(msg) from e
 
-    def get_completer(self):
+    def get_completer(self) -> CallbackCompleter:
         """Get completer for agent names."""
         return CallbackCompleter(get_available_agents)
 
@@ -148,32 +136,27 @@ class ListWorkersCommand(SlashedCommand):
     name = "list-workers"
     category = "tools"
 
-    async def execute_command(self, ctx: CommandContext[AgentContext]):
+    async def execute_command(self, ctx: CommandContext[AgentContext]) -> None:
         """List all worker tools.
 
         Args:
             ctx: Command context
         """
         # Filter tools by source="agent"
-        worker_tools = [
-            i for i in ctx.context.agent.tools.values() if i.source == "agent"
-        ]
-
+        worker_tools = await ctx.context.agent.tools.worker_provider.get_tools()
         if not worker_tools:
             await ctx.print("ℹ️ **No worker tools registered**")  #  noqa: RUF001
             return
 
-        rows = []
-        for tool_info in worker_tools:
-            # Extract settings from metadata
-            agent_name = tool_info.metadata.get("agent", "unknown")
-            rows.append({
+        rows = [
+            {
                 "Status": "✅" if tool_info.enabled else "❌",
-                "Agent": agent_name,
+                "Agent": tool_info.agent_name,
                 "Tool": tool_info.name,
                 "Description": tool_info.description or "",
-            })
-
+            }
+            for tool_info in worker_tools
+        ]
         headers = ["Status", "Agent", "Tool", "Description"]
         table = format_table(headers, rows)
         await ctx.print(f"## 👥 Registered Workers\n\n{table}")
