@@ -6,7 +6,6 @@ from llmling_agent_config.resources import ResourceInfo
 from llmling_agent_config.forward_targets import ForwardingTarget
 from llmling_agent_config.session import SessionQuery
 from llmling_agent_config.teams import TeamConfig
-from llmling_agent.tools import ToolCallInfo
 from llmling_agent_config.mcp_server import (
     BaseMCPServerConfig,
     StdioMCPServerConfig,
@@ -25,5 +24,4 @@ __all__ = [
     "StdioMCPServerConfig",
     "StreamableHTTPMCPServerConfig",
     "TeamConfig",
-    "ToolCallInfo",
 ]
