@@ -4,7 +4,7 @@ from __future__ import annotations
 
 from collections.abc import Awaitable, Callable
 from datetime import timedelta
-from typing import TYPE_CHECKING, Annotated, Literal
+from typing import TYPE_CHECKING, Annotated, Any, Literal, assert_never
 
 from pydantic import ConfigDict, Field, ImportString
 from schemez import Schema
@@ -17,15 +17,19 @@ if TYPE_CHECKING:
 class ConnectionCondition(Schema):
     """Base class for connection control conditions."""
 
-    type: str = Field(init=False)
+    type: str = Field(init=False, title="Condition type")
     """Discriminator for condition types."""
 
-    name: str | None = None
+    name: str | None = Field(
+        default=None,
+        examples=["exit_condition", "message_filter", "cost_check"],
+        title="Condition name",
+    )
     """Optional name for the condition for referencing."""
 
     model_config = ConfigDict(frozen=True)
 
-    async def check(self, context: EventContext) -> bool:
+    async def check(self, context: EventContext[Any]) -> bool:
         """Check if condition is met."""
         raise NotImplementedError
 
@@ -36,10 +40,17 @@ class Jinja2Condition(ConnectionCondition):
     type: Literal["jinja2"] = Field("jinja2", init=False)
     """Jinja2 template-based condition."""
 
-    template: str
+    template: str = Field(
+        examples=[
+            "{{ ctx.stats.message_count > 10 }}",
+            "{{ 'error' in ctx.message.content }}",
+            "{{ ctx.stats.total_cost > 1.0 }}",
+        ],
+        title="Jinja2 template",
+    )
     """Jinja2 template to evaluate."""
 
-    async def check(self, ctx: EventContext) -> bool:
+    async def check(self, ctx: EventContext[Any]) -> bool:
         from jinjarope import Environment
 
         from llmling_agent.utils.now import get_now
@@ -56,19 +67,26 @@ class WordMatchCondition(ConnectionCondition):
     type: Literal["word_match"] = Field("word_match", init=False)
     """Word-comparison-based condition."""
 
-    words: list[str]
+    words: list[str] = Field(
+        examples=[["error", "failed"], ["complete", "done", "finished"], ["urgent"]],
+        title="Words to match",
+    )
     """Words or phrases to match in messages."""
 
-    case_sensitive: bool = False
+    case_sensitive: bool = Field(default=False, title="Case sensitive matching")
     """Whether to match case-sensitively."""
 
-    mode: Literal["any", "all"] = "any"
+    mode: Literal["any", "all"] = Field(
+        default="any",
+        examples=["any", "all"],
+        title="Matching mode",
+    )
     """Match mode:
     - any: Trigger if any word matches
     - all: Require all words to match
     """
 
-    async def check(self, context: EventContext) -> bool:
+    async def check(self, context: EventContext[Any]) -> bool:
         """Check if message contains specified words."""
         text = str(context.message.content)
         if not self.case_sensitive:
@@ -87,16 +105,20 @@ class MessageCountCondition(ConnectionCondition):
     type: Literal["message_count"] = Field("message_count", init=False)
     """Message-count-based condition."""
 
-    max_messages: int = Field(gt=0)
+    max_messages: int = Field(gt=0, examples=[10, 50, 100], title="Maximum message count")
     """Maximum number of messages before triggering."""
 
-    count_mode: Literal["total", "per_agent"] = "total"
+    count_mode: Literal["total", "per_agent"] = Field(
+        default="total",
+        examples=["total", "per_agent"],
+        title="Message counting mode",
+    )
     """How to count messages:
     - total: All messages in conversation
     - per_agent: Messages from each agent separately
     """
 
-    async def check(self, context: EventContext) -> bool:
+    async def check(self, context: EventContext[Any]) -> bool:
         """Check if message count threshold is reached."""
         if self.count_mode == "total":
             return context.stats.message_count >= self.max_messages
@@ -112,10 +134,10 @@ class TimeCondition(ConnectionCondition):
     type: Literal["time"] = Field("time", init=False)
     """Time-based condition."""
 
-    duration: timedelta
+    duration: timedelta = Field(title="Duration threshold")
     """How long the connection should stay active."""
 
-    async def check(self, context: EventContext) -> bool:
+    async def check(self, context: EventContext[Any]) -> bool:
         """Check if time duration has elapsed."""
         from llmling_agent.utils.now import get_now
 
@@ -129,17 +151,21 @@ class TokenThresholdCondition(ConnectionCondition):
     type: Literal["token_threshold"] = Field("token_threshold", init=False)
     """Type discriminator."""
 
-    max_tokens: int = Field(gt=0)
+    max_tokens: int = Field(gt=0, examples=[1000, 4000, 8000], title="Maximum token count")
     """Maximum number of tokens allowed."""
 
-    count_type: Literal["total", "prompt", "completion"] = "total"
+    count_type: Literal["total", "prompt", "completion"] = Field(
+        default="total",
+        examples=["total", "prompt", "completion"],
+        title="Token counting type",
+    )
     """What tokens to count:
     - total: All tokens used
     - prompt: Only prompt tokens
     - completion: Only completion tokens
     """
 
-    async def check(self, context: EventContext) -> bool:
+    async def check(self, context: EventContext[Any]) -> bool:
         """Check if token threshold is reached."""
         if not context.message.cost_info:
             return False
@@ -148,16 +174,11 @@ class TokenThresholdCondition(ConnectionCondition):
             case "total":
                 return context.stats.token_count >= self.max_tokens
             case "prompt":
-                return (
-                    context.message.cost_info.token_usage.input_tokens >= self.max_tokens
-                )
+                return context.message.cost_info.token_usage.input_tokens >= self.max_tokens
             case "completion":
-                return (
-                    context.message.cost_info.token_usage.output_tokens >= self.max_tokens
-                )
-            case _:
-                msg = f"Unknown count type: {self.count_type}"
-                raise ValueError(msg)
+                return context.message.cost_info.token_usage.output_tokens >= self.max_tokens
+            case _ as unreachable:
+                assert_never(unreachable)
 
 
 class CostCondition(ConnectionCondition):
@@ -166,10 +187,10 @@ class CostCondition(ConnectionCondition):
     type: Literal["cost"] = Field("cost", init=False)
     """Cost-based condition."""
 
-    max_cost: float = Field(gt=0.0)
+    max_cost: float = Field(gt=0.0, examples=[1.0, 5.0, 10.0], title="Maximum cost threshold")
     """Maximum cost in USD."""
 
-    async def check(self, context: EventContext) -> bool:
+    async def check(self, context: EventContext[Any]) -> bool:
         """Check if cost limit is reached."""
         return context.stats.total_cost >= self.max_cost
 
@@ -180,10 +201,10 @@ class CostLimitCondition(ConnectionCondition):
     type: Literal["cost_limit"] = Field("cost_limit", init=False)
     """Cost-limit condition."""
 
-    max_cost: float = Field(gt=0.0)
+    max_cost: float = Field(gt=0.0, examples=[1.0, 5.0, 10.0], title="Cost limit")
     """Maximum cost in USD before triggering."""
 
-    async def check(self, context: EventContext) -> bool:
+    async def check(self, context: EventContext[Any]) -> bool:
         """Check if cost limit is reached."""
         if not context.message.cost_info:
             return False
@@ -196,7 +217,10 @@ class CallableCondition(ConnectionCondition):
     type: Literal["callable"] = Field("callable", init=False)
     """Condition based on an import path pointing to a predicate."""
 
-    predicate: ImportString[Callable[..., bool | Awaitable[bool]]]
+    predicate: ImportString[Callable[..., bool | Awaitable[bool]]] = Field(
+        examples=["mymodule.check_condition", "utils.predicates:is_urgent"],
+        title="Predicate function",
+    )
     """Function to evaluate condition:
     Args:
         message: Current message being processed
@@ -205,7 +229,7 @@ class CallableCondition(ConnectionCondition):
         Whether condition is met
     """
 
-    async def check(self, context: EventContext) -> bool:
+    async def check(self, context: EventContext[Any]) -> bool:
         """Execute predicate function."""
         from llmling_agent.utils.inspection import execute
 
@@ -218,10 +242,10 @@ class AndCondition(ConnectionCondition):
     type: Literal["and"] = Field("and", init=False)
     """Condition to AND-combine multiple conditions."""
 
-    conditions: list[ConnectionCondition]
+    conditions: list[ConnectionCondition] = Field(title="AND conditions")
     """List of conditions to check."""
 
-    async def check(self, context: EventContext) -> bool:
+    async def check(self, context: EventContext[Any]) -> bool:
         """Check if all conditions are met."""
         results = [await c.check(context) for c in self.conditions]
         return all(results)
@@ -233,10 +257,10 @@ class OrCondition(ConnectionCondition):
     type: Literal["or"] = Field("or", init=False)
     """Condition to OR-combine multiple conditions."""
 
-    conditions: list[ConnectionCondition]
+    conditions: list[ConnectionCondition] = Field(title="OR conditions")
     """List of conditions to check."""
 
-    async def check(self, context: EventContext) -> bool:
+    async def check(self, context: EventContext[Any]) -> bool:
         """Check if any condition is met."""
         results = [await c.check(context) for c in self.conditions]
         return any(results)
