@@ -19,10 +19,10 @@ GoogleSpeechEncoding = Literal["LINEAR16", "FLAC", "MP3"]
 class BaseConverterConfig(Schema):
     """Base configuration for document converters."""
 
-    type: str = Field(init=False)
+    type: str = Field(init=False, title="Converter type")
     """Type discriminator for converter configs."""
 
-    enabled: bool = True
+    enabled: bool = Field(default=True, title="Converter enabled")
     """Whether this converter is currently active."""
 
     model_config = ConfigDict(frozen=True)
@@ -38,7 +38,12 @@ class MarkItDownConfig(BaseConverterConfig):
     type: Literal["markitdown"] = Field("markitdown", init=False)
     """Type discriminator for MarkItDown converter."""
 
-    max_size: int | None = Field(default=None, gt=0)
+    max_size: int | None = Field(
+        default=None,
+        gt=0,
+        examples=[1048576, 10485760, 52428800],
+        title="Maximum file size",
+    )
     """Optional size limit in bytes."""
 
     def get_converter(self) -> DocumentConverter:
@@ -54,25 +59,27 @@ class YouTubeConverterConfig(BaseConverterConfig):
     type: Literal["youtube"] = Field("youtube", init=False)
     """Type discriminator for converter config."""
 
-    languages: list[str] = Field(default_factory=lambda: ["en"])
+    languages: list[str] = Field(
+        default_factory=lambda: ["en"],
+        examples=[["en"], ["en", "es", "fr"], ["de", "en"]],
+        title="Preferred languages",
+    )
     """Preferred language codes in priority order. Defaults to ['en']."""
 
-    format: FormatterType = "text"
+    format: FormatterType = Field(
+        default="text",
+        examples=["text", "json", "vtt", "srt"],
+        title="Output format",
+    )
     """Output format. One of: text, json, vtt, srt."""
 
-    preserve_formatting: bool = False
+    preserve_formatting: bool = Field(default=False, title="Preserve HTML formatting")
     """Whether to keep HTML formatting elements like <i> and <b>."""
 
-    cookies_path: str | None = None
-    """Optional path to cookies file for age-restricted videos."""
-
-    https_proxy: str | None = None
-    """Optional HTTPS proxy URL (format: https://user:pass@domain:port)."""
-
-    max_retries: int = Field(default=3, ge=0)
+    max_retries: int = Field(default=3, ge=0, examples=[1, 3, 5], title="Maximum retries")
     """Maximum number of retries for failed requests."""
 
-    timeout: int = Field(default=30, gt=0)
+    timeout: int = Field(default=30, gt=0, examples=[15, 30, 60], title="Request timeout")
     """Request timeout in seconds."""
 
     def get_converter(self) -> DocumentConverter:
@@ -88,16 +95,32 @@ class LocalWhisperConfig(BaseConverterConfig):
     type: Literal["local_whisper"] = Field("local_whisper", init=False)
     """Type discriminator for converter config."""
 
-    model: str | None = None
+    model: str | None = Field(
+        default=None,
+        examples=["whisper-1", "whisper-large"],
+        title="Whisper model",
+    )
     """Optional model name."""
 
-    model_size: Literal["tiny", "base", "small", "medium", "large"] = "base"
+    model_size: Literal["tiny", "base", "small", "medium", "large"] = Field(
+        default="base",
+        examples=["tiny", "base", "small", "medium", "large"],
+        title="Model size",
+    )
     """Size of the Whisper model to use."""
 
-    device: Literal["cpu", "cuda"] | None = None
+    device: Literal["cpu", "cuda"] | None = Field(
+        default=None,
+        examples=["cpu", "cuda"],
+        title="Compute device",
+    )
     """Device to run model on (None for auto-select)."""
 
-    compute_type: Literal["float32", "float16"] = "float16"
+    compute_type: Literal["float32", "float16"] = Field(
+        default="float16",
+        examples=["float32", "float16"],
+        title="Compute precision",
+    )
     """Compute precision to use."""
 
     def get_converter(self) -> DocumentConverter:
@@ -113,13 +136,21 @@ class WhisperAPIConfig(BaseConverterConfig):
     type: Literal["whisper_api"] = Field("whisper_api", init=False)
     """Type discriminator for converter config."""
 
-    model: str | None = None
+    model: str | None = Field(
+        default=None,
+        examples=["whisper-1", "whisper-large-v2"],
+        title="OpenAI model",
+    )
     """Optional model name."""
 
-    api_key: SecretStr | None = None
+    api_key: SecretStr | None = Field(default=None, title="OpenAI API key")
     """OpenAI API key."""
 
-    language: str | None = None
+    language: str | None = Field(
+        default=None,
+        examples=["en", "es", "fr", "de"],
+        title="Language code",
+    )
     """Optional language code."""
 
     def get_converter(self) -> DocumentConverter:
@@ -135,13 +166,25 @@ class GoogleSpeechConfig(BaseConverterConfig):
     type: Literal["google_speech"] = Field("google_speech", init=False)
     """Type discriminator for converter config."""
 
-    language: str = "en-US"
+    language: str = Field(
+        default="en-US",
+        examples=["en-US", "es-ES", "fr-FR", "de-DE"],
+        title="Language code",
+    )
     """Language code for transcription."""
 
-    model: str = "default"
+    model: str = Field(
+        default="default",
+        examples=["default", "command_and_search", "phone_call"],
+        title="Speech model",
+    )
     """Speech model to use."""
 
-    encoding: GoogleSpeechEncoding = "LINEAR16"
+    encoding: GoogleSpeechEncoding = Field(
+        default="LINEAR16",
+        examples=["LINEAR16", "FLAC", "MP3"],
+        title="Audio encoding",
+    )
     """Audio encoding format."""
 
     def get_converter(self) -> DocumentConverter:
@@ -157,7 +200,7 @@ class PlainConverterConfig(BaseConverterConfig):
     type: Literal["plain"] = Field("plain", init=False)
     """Type discriminator for plain text converter."""
 
-    force: bool = False
+    force: bool = Field(default=False, title="Force conversion")
     """Whether to attempt converting any file type."""
 
     def get_converter(self) -> DocumentConverter:
@@ -181,13 +224,21 @@ ConverterConfig = Annotated[
 class ConversionConfig(Schema):
     """Global conversion configuration."""
 
-    providers: list[ConverterConfig] | None = None
+    providers: list[ConverterConfig] | None = Field(default=None, title="Converter providers")
     """List of configured converter providers."""
 
-    default_provider: str | None = None
+    default_provider: str | None = Field(
+        default=None,
+        examples=["markitdown", "youtube", "whisper_api"],
+        title="Default provider",
+    )
     """Name of default provider for conversions."""
 
-    max_size: int | None = None
+    max_size: int | None = Field(
+        default=None,
+        examples=[1048576, 10485760, 52428800],
+        title="Global size limit",
+    )
     """Global size limit for all converters."""
 
     model_config = ConfigDict(frozen=True)
