@@ -10,13 +10,8 @@ from schemez import Schema
 
 
 if TYPE_CHECKING:
-    from mcp_interviewer import ServerScoreCard
-    from pydantic_ai.mcp import (
-        MCPServer,
-        MCPServerSSE,
-        MCPServerStdio,
-        MCPServerStreamableHTTP,
-    )
+    from mcp_interviewer import ServerScoreCard  # type: ignore[import-untyped]
+    from pydantic_ai.mcp import MCPServer, MCPServerSSE, MCPServerStdio, MCPServerStreamableHTTP
 
 
 class MCPServerAuthSettings(Schema):
@@ -25,35 +20,58 @@ class MCPServerAuthSettings(Schema):
     Minimal OAuth v2.1 support with sensible defaults.
     """
 
-    oauth: bool = False
+    oauth: bool = Field(default=False, title="Enable OAuth")
 
     # Local callback server configuration
-    redirect_port: int = 3030
-    redirect_path: str = "/callback"
+    redirect_port: int = Field(
+        default=3030, ge=1, lt=65536, examples=[3030, 8080, 9000], title="Redirect port"
+    )
+    redirect_path: str = Field(
+        default="/callback",
+        examples=["/callback", "/auth/callback", "/oauth"],
+        title="Redirect path",
+    )
 
     # Optional scope override. If set to a list, values are space-joined.
-    scope: str | list[str] | None = None
+    scope: str | list[str] | None = Field(
+        default=None,
+        examples=["read write", ["read", "write"], "admin"],
+        title="OAuth scope",
+    )
 
     # Token persistence: use OS keychain via 'keyring' by default; fallback to 'memory'.
-    persist: Literal["keyring", "memory"] = "keyring"
+    persist: Literal["keyring", "memory"] = Field(
+        default="keyring",
+        examples=["keyring", "memory"],
+        title="Token persistence",
+    )
 
 
 class BaseMCPServerConfig(Schema):
     """Base model for MCP server configuration."""
 
-    type: str
+    type: str = Field(title="Server type")
     """Type discriminator for MCP server configurations."""
 
-    name: str | None = None
+    name: str | None = Field(
+        default=None,
+        examples=["my_server", "api_connector", "file_handler"],
+        title="Server name",
+    )
     """Optional name for referencing the server."""
 
-    enabled: bool = True
+    enabled: bool = Field(default=True, title="Server enabled")
     """Whether this server is currently enabled."""
 
-    env: dict[str, str] | None = None
+    env: dict[str, str] | None = Field(default=None, title="Environment variables")
     """Environment variables to pass to the server process."""
 
-    timeout: float = Field(default=60.0, gt=0)
+    timeout: float = Field(
+        default=60.0,
+        gt=0,
+        examples=[30.0, 60.0, 120.0],
+        title="Server timeout",
+    )
     """Timeout for the server process in seconds."""
 
     def get_env_vars(self) -> dict[str, str]:
@@ -69,9 +87,6 @@ class BaseMCPServerConfig(Schema):
 
         Returns:
             A pydantic-ai MCP server instance
-
-        Raises:
-            NotImplementedError: Must be implemented by subclasses
         """
         raise NotImplementedError
 
@@ -100,10 +115,17 @@ class StdioMCPServerConfig(BaseMCPServerConfig):
     type: Literal["stdio"] = Field("stdio", init=False)
     """Stdio server coniguration."""
 
-    command: str
+    command: str = Field(
+        examples=["python", "node", "pipx", "uvx"],
+        title="Command to execute",
+    )
     """Command to execute (e.g. "pipx", "python", "node")."""
 
-    args: list[str] = Field(default_factory=list)
+    args: list[str] = Field(
+        default_factory=list,
+        examples=[["run", "mcp-server"], ["-m", "my_mcp_server"], ["--debug"]],
+        title="Command arguments",
+    )
     """Command arguments (e.g. ["run", "some-server", "--debug"])."""
 
     @classmethod
@@ -133,7 +155,9 @@ class StdioMCPServerConfig(BaseMCPServerConfig):
 
     async def check(self) -> ServerScoreCard:
         from mcp_interviewer import MCPInterviewer
-        from mcp_interviewer.models import StdioServerParameters
+        from mcp_interviewer.models import (  # type: ignore[import-untyped]
+            StdioServerParameters,
+        )
 
         params = StdioServerParameters(command=self.command, args=self.args)
         interviewer = MCPInterviewer(None, None)
@@ -149,13 +173,19 @@ class SSEMCPServerConfig(BaseMCPServerConfig):
     type: Literal["sse"] = Field("sse", init=False)
     """SSE server configuration."""
 
-    url: HttpUrl
+    url: HttpUrl = Field(
+        examples=["https://api.example.com/sse", "http://localhost:8080/events"],
+        title="SSE endpoint URL",
+    )
     """URL of the SSE server endpoint."""
 
-    headers: dict[str, str] | None = None
+    headers: dict[str, str] | None = Field(default=None, title="HTTP headers")
     """Headers to send with the SSE request."""
 
-    auth: MCPServerAuthSettings = Field(default_factory=MCPServerAuthSettings)
+    auth: MCPServerAuthSettings = Field(
+        default_factory=MCPServerAuthSettings,
+        title="Authentication settings",
+    )
     """OAuth settings for the SSE server."""
 
     @property
@@ -167,22 +197,15 @@ class SSEMCPServerConfig(BaseMCPServerConfig):
         """Convert to pydantic-ai MCPServerSSE instance."""
         from pydantic_ai.mcp import MCPServerSSE
 
-        return MCPServerSSE(
-            url=str(self.url),
-            headers=self.headers,
-            id=self.name,
-            timeout=self.timeout,
-        )
+        url = str(self.url)
+        return MCPServerSSE(url=url, headers=self.headers, id=self.name, timeout=self.timeout)
 
     async def check(self) -> ServerScoreCard:
         from mcp_interviewer import MCPInterviewer
         from mcp_interviewer.models import SseServerParameters
 
-        params = SseServerParameters(
-            url=str(self.url),
-            timeout=self.timeout,
-            headers=self.headers,
-        )
+        url = str(self.url)
+        params = SseServerParameters(url=url, timeout=self.timeout, headers=self.headers)
         interviewer = MCPInterviewer(None, None)
         return await interviewer.interview_server(params)
 
@@ -196,13 +219,19 @@ class StreamableHTTPMCPServerConfig(BaseMCPServerConfig):
     type: Literal["streamable-http"] = Field("streamable-http", init=False)
     """HTTP server configuration."""
 
-    url: HttpUrl
+    url: HttpUrl = Field(
+        examples=["https://api.example.com/mcp", "http://localhost:8080/stream"],
+        title="HTTP endpoint URL",
+    )
     """URL of the HTTP server endpoint."""
 
-    headers: dict[str, str] | None = None
+    headers: dict[str, str] | None = Field(default=None, title="HTTP headers")
     """Headers to send with the HTTP request."""
 
-    auth: MCPServerAuthSettings = Field(default_factory=MCPServerAuthSettings)
+    auth: MCPServerAuthSettings = Field(
+        default_factory=MCPServerAuthSettings,
+        title="Authentication settings",
+    )
     """OAuth settings for the HTTP server."""
 
     @property
