@@ -5,7 +5,7 @@ from __future__ import annotations
 from typing import TYPE_CHECKING, Self
 from uuid import UUID
 
-from pydantic import ConfigDict
+from pydantic import ConfigDict, Field
 from schemez import Schema
 
 from llmling_agent.common_types import MessageRole
@@ -18,19 +18,31 @@ if TYPE_CHECKING:
 class MemoryConfig(Schema):
     """Configuration for agent memory and history handling."""
 
-    enable: bool = True
+    enable: bool = Field(default=True, title="Enable memory")
     """Whether to enable history tracking."""
 
-    max_tokens: int | None = None
+    max_tokens: int | None = Field(
+        default=None,
+        examples=[1000, 4000, 8000],
+        title="Maximum context tokens",
+    )
     """Maximum number of tokens to keep in context window."""
 
-    max_messages: int | None = None
+    max_messages: int | None = Field(
+        default=None,
+        examples=[10, 50, 100],
+        title="Maximum message count",
+    )
     """Maximum number of messages to keep in context window."""
 
-    session: SessionQuery | None = None
+    session: SessionQuery | None = Field(default=None, title="Session query")
     """Query configuration for loading previous session."""
 
-    provider: str | None = None
+    provider: str | None = Field(
+        default=None,
+        examples=["sqlite", "memory", "file"],
+        title="Storage provider",
+    )
     """Override default storage provider for this agent.
     If None, uses manifest's default provider or first available."""
 
@@ -58,28 +70,40 @@ class MemoryConfig(Schema):
 class SessionQuery(Schema):
     """Query configuration for session recovery."""
 
-    name: str | None = None
+    name: str | None = Field(
+        default=None,
+        examples=["main_session", "user_123", "conversation_01"],
+        title="Session name",
+    )
     """Session identifier to match."""
 
-    agents: set[str] | None = None
+    agents: set[str] | None = Field(default=None, title="Agent filter")
     """Filter by agent names."""
 
-    since: str | None = None
+    since: str | None = Field(
+        default=None,
+        examples=["1h", "2d", "1w"],
+        title="Time period lookback",
+    )
     """Time period to look back (e.g. "1h", "2d")."""
 
-    until: str | None = None
+    until: str | None = Field(default=None, examples=["1h", "2d", "1w"], title="Time period limit")
     """Time period to look up to."""
 
-    contains: str | None = None
+    contains: str | None = Field(
+        default=None,
+        examples=["error", "important", "task completed"],
+        title="Content filter",
+    )
     """Filter by message content."""
 
-    roles: set[MessageRole] | None = None
+    roles: set[MessageRole] | None = Field(default=None, title="Role filter")
     """Only include specific message roles."""
 
-    limit: int | None = None
+    limit: int | None = Field(default=None, examples=[10, 50, 100], title="Message limit")
     """Maximum number of messages to return."""
 
-    include_forwarded: bool = True
+    include_forwarded: bool = Field(default=True, title="Include forwarded messages")
     """Whether to include messages forwarded through agents."""
 
     model_config = ConfigDict(frozen=True)
