@@ -43,19 +43,19 @@ class BaseStorageProviderConfig(Schema):
     type: str = Field(init=False)
     """Storage provider type."""
 
-    log_messages: bool = True
+    log_messages: bool = Field(default=True, title="Log messages")
     """Whether to log messages"""
 
-    agents: set[str] | None = None
+    agents: set[str] | None = Field(default=None, title="Agent filter")
     """Optional set of agent names to include. If None, logs all agents."""
 
-    log_conversations: bool = True
+    log_conversations: bool = Field(default=True, title="Log conversations")
     """Whether to log conversations"""
 
-    log_commands: bool = True
+    log_commands: bool = Field(default=True, title="Log commands")
     """Whether to log command executions"""
 
-    log_context: bool = True
+    log_context: bool = Field(default=True, title="Log context")
     """Whether to log context messages."""
 
     model_config = ConfigDict(frozen=True)
@@ -67,13 +67,22 @@ class SQLStorageConfig(BaseStorageProviderConfig):
     type: Literal["sql"] = Field("sql", init=False)
     """SQLModel storage configuration."""
 
-    url: str = Field(default_factory=get_database_path)
+    url: str = Field(
+        default_factory=get_database_path,
+        examples=["sqlite:///history.db", "postgresql://user:pass@localhost/db"],
+        title="Database URL",
+    )
     """Database URL (e.g. sqlite:///history.db)"""
 
-    pool_size: int = Field(default=5, ge=1)
+    pool_size: int = Field(
+        default=5,
+        ge=1,
+        examples=[5, 10, 20],
+        title="Connection pool size",
+    )
     """Connection pool size"""
 
-    auto_migration: bool = True
+    auto_migration: bool = Field(default=True, title="Auto migration")
     """Whether to automatically add missing columns"""
 
     def get_engine(self) -> AsyncEngine:
@@ -100,16 +109,27 @@ class TextLogConfig(BaseStorageProviderConfig):
     type: Literal["text_file"] = Field("text_file", init=False)
     """Text log storage configuration."""
 
-    path: str
+    path: str = Field(
+        examples=["/var/log/agent.log", "~/logs/conversations.txt"],
+        title="Log file path",
+    )
     """Path to log file"""
 
-    format: LogFormat = "chronological"
+    format: LogFormat = Field(
+        default="chronological",
+        examples=["chronological", "conversations"],
+        title="Log format",
+    )
     """Log format template to use"""
 
-    template: Literal["chronological", "conversations"] | str | None = "chronological"  # noqa: PYI051
+    template: Literal["chronological", "conversations"] | str | None = Field(  # noqa: PYI051
+        default="chronological",
+        examples=["chronological", "conversations", "/path/to/template.j2"],
+        title="Template",
+    )
     """Template to use: either predefined name or path to custom template"""
 
-    encoding: str = "utf-8"
+    encoding: str = Field(default="utf-8", examples=["utf-8", "ascii"], title="File encoding")
     """File encoding"""
 
 
@@ -120,14 +140,21 @@ class FileStorageConfig(BaseStorageProviderConfig):
     type: Literal["file"] = Field("file", init=False)
     """File storage configuration."""
 
-    path: str
+    path: str = Field(
+        examples=["/data/storage.json", "~/agent_data.yaml"],
+        title="Storage file path",
+    )
     """Path to storage file (extension determines format unless specified)"""
 
-    format: FormatType = "auto"
+    format: FormatType = Field(
+        default="auto",
+        examples=["auto", "json", "yaml", "toml"],
+        title="Storage format",
+    )
     """Storage format (auto=detect from extension)"""
 
-    encoding: str = "utf-8"
-    """File encoding"""
+    encoding: str = Field(default="utf-8", examples=["utf-8", "ascii"], title="File encoding")
+    """File encoding of the storage file."""
 
 
 class MemoryStorageConfig(BaseStorageProviderConfig):
@@ -144,40 +171,63 @@ StorageProviderConfig = Annotated[
 
 
 class StorageConfig(Schema):
-    """Global storage configuration."""
+    """Global storage configuration.
 
-    providers: list[StorageProviderConfig] | None = None
+    Docs: https://phil65.github.io/llmling-agent/YAML%20Configuration/storage_configuration/
+    """
+
+    providers: list[StorageProviderConfig] | None = Field(
+        default=None,
+        title="Storage providers",
+        examples=[[{"type": "file", "path": "/data/storage.json"}]],
+    )
     """List of configured storage providers"""
 
-    default_provider: str | None = None
+    default_provider: str | None = Field(
+        default=None,
+        examples=["sql", "file", "memory"],
+        title="Default provider",
+    )
     """Name of default provider for history queries.
     If None, uses first configured provider."""
 
-    agents: set[str] | None = None
+    agents: set[str] | None = Field(default=None, title="Global agent filter")
     """Global agent filter. Can be overridden by provider-specific filters."""
 
-    filter_mode: FilterMode = "and"
+    filter_mode: FilterMode = Field(
+        default="and",
+        examples=["and", "override"],
+        title="Filter mode",
+    )
     """How to combine global and provider agent filters:
     - "and": Both global and provider filters must allow the agent
     - "override": Provider filter overrides global filter if set
     """
 
-    log_messages: bool = True
+    log_messages: bool = Field(default=True, title="Log messages")
     """Whether to log messages."""
 
-    log_conversations: bool = True
+    log_conversations: bool = Field(default=True, title="Log conversations")
     """Whether to log conversations."""
 
-    log_commands: bool = True
+    log_commands: bool = Field(default=True, title="Log commands")
     """Whether to log command executions."""
 
-    log_context: bool = True
+    log_context: bool = Field(default=True, title="Log context")
     """Whether to log additions to the context."""
 
-    title_generation_model: str = "openai:gpt-5-nano"
+    title_generation_model: str = Field(
+        default="openai:gpt-5-nano",
+        examples=["openai:gpt-5-nano", "anthropic:claude-3-haiku"],
+        title="Title generation model",
+    )
     """Whether to log command executions."""
 
-    title_generation_prompt: str = DEFAULT_TITLE_PROMPT
+    title_generation_prompt: str = Field(
+        default=DEFAULT_TITLE_PROMPT,
+        examples=[DEFAULT_TITLE_PROMPT, "Summarize this conversation in 5 words"],
+        title="Title generation prompt",
+    )
     """Whether to log additions to the context."""
 
     model_config = ConfigDict(frozen=True)
