@@ -5,9 +5,10 @@ from __future__ import annotations
 import os
 from typing import TYPE_CHECKING, Annotated, Literal
 
-from pydantic import EmailStr, Field, HttpUrl, SecretStr  # noqa: TC002
-from schemez.schema import Schema
-from upath import UPath  # noqa: TC002
+from anyenv.code_execution.configs import ExecutionEnvironmentConfig
+from pydantic import EmailStr, Field, HttpUrl, SecretStr
+from schemez import Schema
+from upath import UPath
 
 from llmling_agent.utils.importing import import_class
 
@@ -19,7 +20,7 @@ if TYPE_CHECKING:
 class BaseToolsetConfig(Schema):
     """Base configuration for toolsets."""
 
-    namespace: str | None = Field(default=None)
+    namespace: str | None = Field(default=None, examples=["web", "files"], title="Tool namespace")
     """Optional namespace prefix for tool names"""
 
 
@@ -29,10 +30,17 @@ class OpenAPIToolsetConfig(BaseToolsetConfig):
     type: Literal["openapi"] = Field("openapi", init=False)
     """OpenAPI toolset."""
 
-    spec: UPath
+    spec: UPath = Field(
+        examples=["https://api.example.com/openapi.json", "/path/to/spec.yaml"],
+        title="OpenAPI specification",
+    )
     """URL or path to the OpenAPI specification document."""
 
-    base_url: HttpUrl | None = None
+    base_url: HttpUrl | None = Field(
+        default=None,
+        examples=["https://api.example.com", "http://localhost:8080"],
+        title="Base URL override",
+    )
     """Optional base URL for API requests, overrides the one in spec."""
 
     def get_provider(self) -> ResourceProvider:
@@ -49,7 +57,10 @@ class EntryPointToolsetConfig(BaseToolsetConfig):
     type: Literal["entry_points"] = Field("entry_points", init=False)
     """Entry point toolset."""
 
-    module: str
+    module: str = Field(
+        examples=["myapp.tools", "external_package.plugins"],
+        title="Module path",
+    )
     """Python module path to load tools from via entry points."""
 
     def get_provider(self) -> ResourceProvider:
@@ -65,24 +76,28 @@ class ComposioToolSetConfig(BaseToolsetConfig):
     type: Literal["composio"] = Field("composio", init=False)
     """Composio Toolsets."""
 
-    api_key: SecretStr | None = None
+    api_key: SecretStr | None = Field(default=None, title="Composio API key")
     """Composio API Key."""
 
-    user_id: EmailStr = "user@example.com"
+    user_id: EmailStr = Field(
+        default="user@example.com",
+        examples=["user@example.com", "admin@company.com"],
+        title="User ID",
+    )
     """User ID for composio tools."""
 
-    toolsets: list[str] = Field(default_factory=list)
+    toolsets: list[str] = Field(
+        default_factory=list,
+        examples=[["github", "slack"], ["gmail", "calendar"]],
+        title="Toolset list",
+    )
     """List of toolsets to load."""
 
     def get_provider(self) -> ResourceProvider:
         """Create provider from this config."""
         from llmling_agent_toolsets.composio_toolset import ComposioTools
 
-        key = (
-            self.api_key.get_secret_value()
-            if self.api_key
-            else os.getenv("COMPOSIO_API_KEY")
-        )
+        key = self.api_key.get_secret_value() if self.api_key else os.getenv("COMPOSIO_API_KEY")
         return ComposioTools(user_id=self.user_id, toolsets=self.toolsets, api_key=key)
 
 
@@ -92,13 +107,21 @@ class UpsonicToolSetConfig(BaseToolsetConfig):
     type: Literal["upsonic"] = Field("upsonic", init=False)
     """Upsonic Toolsets."""
 
-    base_url: HttpUrl | None = None
+    base_url: HttpUrl | None = Field(
+        default=None,
+        examples=["https://api.upsonic.co", "http://localhost:9000"],
+        title="Upsonic API URL",
+    )
     """Upsonic API URL."""
 
-    api_key: SecretStr | None = None
+    api_key: SecretStr | None = Field(default=None, title="Upsonic API key")
     """Upsonic API Key."""
 
-    entity_id: str = "default"
+    entity_id: str = Field(
+        default="default",
+        examples=["default", "team1", "project_alpha"],
+        title="Entity ID",
+    )
     """Toolset entity id."""
 
     def get_provider(self) -> ResourceProvider:
@@ -226,13 +249,64 @@ class CodeToolsetConfig(BaseToolsetConfig):
         return CodeTools(name="code")
 
 
+class FSSpecToolsetConfig(BaseToolsetConfig):
+    """Configuration for FSSpec filesystem toolsets."""
+
+    type: Literal["fsspec"] = Field("fsspec", init=False)
+    """FSSpec filesystem toolset."""
+
+    url: str = Field(
+        examples=["s3://my-bucket", "file:///tmp", "gcs://bucket-name"],
+        title="Filesystem URL",
+    )
+    """Filesystem URL or protocol (e.g., 'file', 's3://bucket-name', etc.)."""
+
+    storage_options: dict[str, str] = Field(
+        default_factory=dict,
+        examples=[
+            {"region": "us-east-1", "profile": "default"},
+            {"token": "ghp_123456789", "timeout": "30"},
+            {"key": "value", "ssl_verify": "true"},
+        ],
+        title="Storage options",
+    )
+    """Additional options to pass to the filesystem constructor."""
+
+    def get_provider(self) -> ResourceProvider:
+        """Create FSSpec filesystem tools provider."""
+        import fsspec  # type: ignore[import-untyped]
+
+        from llmling_agent_toolsets.fsspec_toolset import FSSpecTools
+
+        fs, _url_path = fsspec.url_to_fs(self.url, **self.storage_options)
+        # Extract protocol name for the provider name
+        protocol = self.url.split("://")[0] if "://" in self.url else self.url
+        return FSSpecTools(fs, name=f"fsspec_{protocol}")
+
+
+class VFSToolsetConfig(BaseToolsetConfig):
+    """Configuration for VFS registry filesystem toolset."""
+
+    type: Literal["vfs"] = Field("vfs", init=False)
+    """VFS registry filesystem toolset."""
+
+    def get_provider(self) -> ResourceProvider:
+        """Create VFS registry filesystem tools provider."""
+        from llmling_agent_toolsets.vfs_toolset import VFSTools
+
+        return VFSTools(name="vfs")
+
+
 class CustomToolsetConfig(BaseToolsetConfig):
     """Configuration for custom toolsets."""
 
     type: Literal["custom"] = Field("custom", init=False)
     """Custom toolset."""
 
-    import_path: str
+    import_path: str = Field(
+        examples=["myapp.toolsets.CustomTools", "external.providers:MyProvider"],
+        title="Import path",
+    )
     """Dotted import path to the custom toolset implementation class."""
 
     def get_provider(self) -> ResourceProvider:
@@ -246,7 +320,46 @@ class CustomToolsetConfig(BaseToolsetConfig):
         return provider_cls(name=provider_cls.__name__)
 
 
-# Use discriminated union for toolset types
+class CodeModeToolsetConfig(BaseToolsetConfig):
+    """Configuration for code mode tools."""
+
+    type: Literal["code_mode"] = Field("code_mode", init=False)
+    """Code mode toolset."""
+
+    toolsets: list[ToolsetConfig] = Field(title="Wrapped toolsets")
+    """List of toolsets to expose as a codemode toolset."""
+
+    def get_provider(self) -> ResourceProvider:
+        """Create Codemode toolset."""
+        from llmling_agent.resource_providers.codemode import CodeModeResourceProvider
+
+        providers = [p.get_provider() for p in self.toolsets]
+        return CodeModeResourceProvider(providers=providers)
+
+
+class RemoteCodeModeToolsetConfig(BaseToolsetConfig):
+    """Configuration for code mode tools."""
+
+    type: Literal["remote_code_mode"] = Field("remote_code_mode", init=False)
+    """Code mode toolset."""
+
+    environment: ExecutionEnvironmentConfig = Field(title="Execution environment")
+    """Execution environment configuration."""
+
+    toolsets: list[ToolsetConfig] = Field(title="Wrapped toolsets")
+    """List of toolsets to expose as a codemode toolset."""
+
+    def get_provider(self) -> ResourceProvider:
+        """Create Codemode toolset."""
+        from llmling_agent.resource_providers.codemode import RemoteCodeModeResourceProvider
+
+        providers = [p.get_provider() for p in self.toolsets]
+        return RemoteCodeModeResourceProvider(
+            providers=providers,
+            execution_config=self.environment,
+        )
+
+
 ToolsetConfig = Annotated[
     OpenAPIToolsetConfig
     | EntryPointToolsetConfig
@@ -261,11 +374,15 @@ ToolsetConfig = Annotated[
     | HistoryToolsetConfig
     | IntegrationToolsetConfig
     | CodeToolsetConfig
+    | FSSpecToolsetConfig
+    | VFSToolsetConfig
+    | CodeModeToolsetConfig
+    | RemoteCodeModeToolsetConfig
     | CustomToolsetConfig,
     Field(discriminator="type"),
 ]
 
 if __name__ == "__main__":
-    import upsonic
+    import upsonic  # type: ignore[import-untyped]
 
     tools = upsonic.Tiger().crewai
