@@ -15,7 +15,10 @@ class BaseWorkerConfig(Schema):
     This allows building hierarchies of specialized nodes.
     """
 
-    name: str
+    name: str = Field(
+        examples=["web_agent", "code_analyzer", "data_processor"],
+        title="Worker node name",
+    )
     """Name of the node to use as a worker."""
 
     model_config = ConfigDict(frozen=True)
@@ -41,13 +44,13 @@ class AgentWorkerConfig(BaseWorkerConfig):
     type: Literal["agent"] = Field("agent", init=False)
     """Agent worker configuration."""
 
-    reset_history_on_run: bool = True
+    reset_history_on_run: bool = Field(default=True, title="Reset history on run")
     """Whether to clear worker's conversation history before each run.
     True (default): Fresh conversation each time
     False: Maintain conversation context between runs
     """
 
-    pass_message_history: bool = False
+    pass_message_history: bool = Field(default=False, title="Pass message history")
     """Whether to pass parent agent's message history to worker.
     True: Worker sees parent's conversation context
     False (default): Worker only sees current request
