@@ -3,10 +3,10 @@
 from __future__ import annotations
 
 import re
-from typing import TYPE_CHECKING, Any, ClassVar, Literal
+from typing import TYPE_CHECKING, Any, ClassVar, Literal, assert_never
 
-from youtube_transcript_api import YouTubeTranscriptApi  # pyright: ignore
-from youtube_transcript_api.formatters import (  # pyright: ignore
+from youtube_transcript_api import YouTubeTranscriptApi
+from youtube_transcript_api.formatters import (
     JSONFormatter,
     SRTFormatter,
     TextFormatter,
@@ -32,7 +32,7 @@ class YouTubeTranscriptConverter(DocumentConverter):
     """Converter for YouTube video transcripts."""
 
     # YouTube URL/ID patterns
-    URL_PATTERNS: ClassVar[list[re.Pattern]] = [
+    URL_PATTERNS: ClassVar[list[re.Pattern[str]]] = [
         # Standard YouTube URLs
         re.compile(r"https?://(?:www\.)?youtube\.com/watch\?v=([a-zA-Z0-9_-]+)"),
         # Short URLs
@@ -41,7 +41,7 @@ class YouTubeTranscriptConverter(DocumentConverter):
         re.compile(r"^[a-zA-Z0-9_-]{11}$"),
     ]
 
-    def __init__(self, config: YouTubeConverterConfig | None = None):
+    def __init__(self, config: YouTubeConverterConfig | None = None) -> None:
         """Initialize converter.
 
         Args:
@@ -59,9 +59,8 @@ class YouTubeTranscriptConverter(DocumentConverter):
                 self.formatter = WebVTTFormatter()
             case "srt":
                 self.formatter = SRTFormatter()
-            case _:
-                msg = f"Invalid format: {self.config.format}"
-                raise ValueError(msg)
+            case _ as unreachable:
+                assert_never(unreachable)
 
     def extract_video_id(self, url: str) -> str | None:
         """Extract YouTube video ID from URL or ID string.
@@ -107,15 +106,11 @@ class YouTubeTranscriptConverter(DocumentConverter):
             msg = f"Invalid YouTube URL/ID: {path}"
             raise ValueError(msg)
 
-        proxies = {"https": self.config.https_proxy} if self.config.https_proxy else None
-
         try:
-            transcript = YouTubeTranscriptApi.get_transcript(
+            transcript = YouTubeTranscriptApi().fetch(
                 video_id=video_id,
                 languages=self.config.languages,
                 preserve_formatting=self.config.preserve_formatting,
-                proxies=proxies,
-                cookies=self.config.cookies_path,
             )
             return self.formatter.format_transcript(transcript)
 
