@@ -26,7 +26,7 @@ PROMPT = "Get the latest commit hash!"
 os.environ["OPENAI_API_KEY"] = os.environ.get("OPENAI_API_KEY", "your_api_key_here")
 
 
-async def run_example():
+async def run_example() -> None:
     """Run example using YAML configuration."""
     # Load config from YAML
     config_path = get_config_path(None if is_pyodide() else __file__)
