@@ -14,23 +14,16 @@ from llmling_agent_docs import (
 )
 
 
-def build(project) -> mk.MkNav:
-    build = Build()
-    project.linkprovider.add_inv_file("https://mkdocstrings.github.io/objects.inv")
-    build.on_theme(project.theme)
-    return build.on_root(project.root) or project.root
-
-
 class Build:
     """Class for building the documentation tree."""
 
     @classmethod
-    def build(cls, root, theme):
+    def build(cls, root: mk.MkNav, theme: mk.Theme) -> mk.MkNav:
         b = cls()
         b.on_theme(theme)
         return b.on_root(root)
 
-    def on_theme(self, theme: mk.Theme):
+    def on_theme(self, theme: mk.Theme) -> None:
         theme.error_page.content = mk.MkAdmonition("Page does not exist!")
         if isinstance(theme, mk.MaterialTheme):
             theme.content_area_width = 1300
@@ -38,7 +31,7 @@ class Build:
             theme.add_status_icon("js", "fa6-brands:js", "Uses JavaScript")
             theme.add_status_icon("css", "vaadin:css", "Uses CSS")
 
-    def on_root(self, nav: mk.MkNav):
+    def on_root(self, nav: mk.MkNav) -> mk.MkNav:
         nav.page_template.announcement_bar = mk.MkMetadataBadges("websites")
         nav += getting_started.nav
         nav += core_concepts.nav
