@@ -4,7 +4,7 @@ from __future__ import annotations
 
 from typing import TYPE_CHECKING, Any
 
-from promptlayer import PromptLayer
+from promptlayer import PromptLayer  # type: ignore[import-untyped]
 
 from llmling_agent.prompts.base import BasePromptProvider
 
@@ -19,7 +19,7 @@ class PromptLayerProvider(BasePromptProvider):
     name = "promptlayer"
     supports_versions = True
 
-    def __init__(self, config: PromptLayerConfig):
+    def __init__(self, config: PromptLayerConfig) -> None:
         self.client = PromptLayer(
             api_key=config.api_key.get_secret_value() if config.api_key else None
         )
@@ -35,9 +35,7 @@ class PromptLayerProvider(BasePromptProvider):
         dct = self.client.templates.get(name)
         template = dct["prompt_template"]
         return (
-            str(template.get("content"))
-            if "content" in template
-            else str(template.get("messages"))
+            str(template.get("content")) if "content" in template else str(template.get("messages"))
         )
 
     async def list_prompts(self) -> list[str]:
@@ -51,10 +49,8 @@ if __name__ == "__main__":
 
     from llmling_agent_config.prompt_hubs import PromptLayerConfig
 
-    async def main():
-        config = PromptLayerConfig(
-            api_key=SecretStr("pl_480ead79b098fc25c63cdb4c95115deb")
-        )
+    async def main() -> None:
+        config = PromptLayerConfig(api_key=SecretStr("pl_480ead79b098fc25c63cdb4c95115deb"))
         provider = PromptLayerProvider(config)
         prompt = await provider.list_prompts()
         print(prompt)
