@@ -11,7 +11,7 @@ from pathlib import Path
 from typing import TYPE_CHECKING, Any, Self, TypeVar
 import uuid
 
-from fasta2a.schema import (
+from fasta2a.schema import (  # type: ignore[import-untyped]
     AgentCapabilities,
     AgentCard,
     a2a_request_ta,
@@ -74,7 +74,7 @@ class FastA2A(Starlette):
         middleware: Sequence[Middleware] | None = None,
         exception_handlers: dict[Any, ExceptionHandler] | None = None,
         lifespan: Any = None,
-    ):
+    ) -> None:
         if lifespan is None:
             lifespan = _default_lifespan
 
@@ -134,12 +134,8 @@ class FastA2A(Starlette):
             )
             if self.provider is not None:
                 agent_card["provider"] = self.provider
-            self._agent_card_json_schema = agent_card_ta.dump_json(
-                agent_card, by_alias=True
-            )
-        return Response(
-            content=self._agent_card_json_schema, media_type="application/json"
-        )
+            self._agent_card_json_schema = agent_card_ta.dump_json(agent_card, by_alias=True)
+        return Response(content=self._agent_card_json_schema, media_type="application/json")
 
     async def _docs_endpoint(self, request: Request) -> Response:
         """Serve the documentation interface."""
@@ -279,10 +275,10 @@ async def _default_lifespan(app: FastA2A) -> AsyncIterator[None]:
 
 @asynccontextmanager
 async def worker_lifespan(
-    app: FastA2A, worker, agent: Agent[AgentDepsT, OutputDataT]
+    app: FastA2A, worker: AgentWorker, agent: Agent[AgentDepsT, OutputDataT]
 ) -> AsyncIterator[None]:
     """Custom lifespan that runs the worker during application startup."""
-    async with app.task_manager, agent, worker.run():
+    async with app.task_manager, agent, await worker.run():
         yield
 
 
@@ -328,11 +324,11 @@ class AgentWorker:
 
             # Convert A2A message to ChatMessage and add to history
             new_message = self._a2a_to_chat_message(task_data["data"])
+
+            # Run the agent with the new message as prompt and previous history as context
+            result = await self.agent.run(new_message, messages=message_history)
+
             message_history.append(new_message)
-
-            # Run the agent with full message history
-            result = await self.agent.run(message_history=message_history)
-
             message_history.append(result)
             if context_id:
                 await self.storage.update_context(context_id, message_history)
@@ -348,7 +344,7 @@ class AgentWorker:
         """Cancel a task."""
         await self.storage.update_task_status(task_id, "cancelled")
 
-    def _a2a_to_chat_message(self, task_data: A2ARequest) -> ChatMessage:
+    def _a2a_to_chat_message(self, task_data: A2ARequest) -> ChatMessage[Any]:
         """Convert A2A task data to ChatMessage."""
         # Extract message content from A2A request
         messages = task_data.get("params", {}).get("messages", [])
@@ -365,7 +361,7 @@ class AgentWorker:
             conversation_id=task_data.get("params", {}).get("context_id"),
         )
 
-    def _chat_message_to_a2a(self, message: ChatMessage) -> dict[str, Any]:
+    def _chat_message_to_a2a(self, message: ChatMessage[Any]) -> dict[str, Any]:
         """Convert ChatMessage to A2A format."""
         return {
             "messages": [
@@ -463,6 +459,7 @@ class A2AServer(BaseServer):
             host=self.host,
             port=self.port,
             log_level="info",
+            ws="websockets-sansio",
         )
         server = uvicorn.Server(config)
         await server.serve()
@@ -480,23 +477,21 @@ if __name__ == "__main__":
 
     from llmling_agent import AgentPool
 
-    async def test_client():
+    async def test_client() -> None:
         """Test the A2A server with a basic request."""
         async with httpx.AsyncClient() as client:
             # Test agent card endpoint
-            response = await client.get(
-                "http://localhost:8000/.well-known/agent-card.json"
-            )
+            response = await client.get("http://localhost:8000/.well-known/agent-card.json")
             print("Agent card:", response.json())
 
             # Test docs endpoint
             response = await client.get("http://localhost:8000/docs")
             print("Docs status:", response.status_code)
 
-    async def main():
+    async def main() -> None:
         """Run server and test client."""
         pool = AgentPool()
-        await pool.add_agent("test-agent", model="openai:gpt-4o-mini")
+        await pool.add_agent("test-agent", model="openai:gpt-5-nano")
 
         async with (
             A2AServer(
