@@ -8,7 +8,7 @@ from __future__ import annotations
 
 import asyncio
 from collections.abc import AsyncGenerator
-from dataclasses import dataclass
+from dataclasses import dataclass, field
 import re
 from typing import TYPE_CHECKING, Any
 
@@ -29,13 +29,31 @@ from pydantic_ai import (
 )
 from slashed import Command, CommandStore
 
+from acp.acp_requests import ACPRequests
 from acp.filesystem import ACPFileSystem
 from acp.notifications import ACPNotifications
-from acp.requests import ACPRequests
-from acp.schema import AvailableCommand
+from acp.schema import (
+    AvailableCommand,
+    ClientCapabilities,
+    PlanEntry as ACPPlanEntry,
+    TerminalToolCallContent,
+    ToolCallLocation,
+)
 from acp.utils import to_acp_content_blocks
 from llmling_agent.agent import SlashedAgent
-from llmling_agent.agent.events import StreamCompleteEvent, ToolCallProgressEvent
+from llmling_agent.agent.events import (
+    FileEditProgressEvent,
+    FileOperationEvent,
+    PlanUpdateEvent,
+    ProcessExitEvent,
+    ProcessKillEvent,
+    ProcessOutputEvent,
+    ProcessReleaseEvent,
+    ProcessStartEvent,
+    StreamCompleteEvent,
+    ToolCallProgressEvent,
+    ToolCallStartEvent,
+)
 from llmling_agent.log import get_logger
 from llmling_agent_commands import get_commands
 from llmling_agent_server.acp_server.acp_tools import get_acp_provider
@@ -43,6 +61,7 @@ from llmling_agent_server.acp_server.converters import (
     convert_acp_mcp_server_to_config,
     from_content_blocks,
 )
+from llmling_agent_server.acp_server.input_provider import ACPInputProvider
 
 
 if TYPE_CHECKING:
@@ -52,12 +71,12 @@ if TYPE_CHECKING:
     from slashed import CommandContext
 
     from acp import Client
-    from acp.schema import ClientCapabilities, ContentBlock, McpServer, StopReason
+    from acp.schema import ContentBlock, McpServer, StopReason
     from llmling_agent import Agent, AgentPool
     from llmling_agent.agent.events import RichAgentStreamEvent
-    from llmling_agent.mcp_server.manager import Prompt
     from llmling_agent.models.content import BaseContent
     from llmling_agent.prompts.manager import PromptManager
+    from llmling_agent.prompts.prompts import MCPClientPrompt
     from llmling_agent.resource_providers.aggregating import AggregatingResourceProvider
     from llmling_agent_server.acp_server.acp_agent import LLMlingACPAgent
     from llmling_agent_server.acp_server.session_manager import ACPSessionManager
@@ -68,9 +87,30 @@ ACP_COMMANDS = {"list-sessions", "load-session", "save-session", "delete-session
 
 
 logger = get_logger(__name__)
-# Tools that send their own rich ACP notifications (with ToolCallLocation, etc.)
+# Tools that send their own rich ACP notifications (with TerminalToolCallContent, etc.)
 # These tools are excluded from generic session-level notifications to prevent duplication
-ACP_SELF_NOTIFYING_TOOLS = {"read_text_file", "write_text_file", "run_command"}
+# TODO: This centralized string-based list is brittle. Tools/toolsets should self-report
+# whether they emit their own tool call status updates
+# via a flag like `is_self_notifying: bool`
+# on the Tool class or ResourceProvider level. This would eliminate the need for manual
+# maintenance of this list and provide better type safety.
+ACP_SELF_NOTIFYING_TOOLS = {
+    "read_text_file",
+    "write_text_file",
+    "run_command",
+    "start_process",
+    "get_process_output",
+    "wait_for_process",
+    "kill_process",
+    "release_process",
+    "list_processes",
+    "list_directory",
+    "delete_path",
+    "edit_file",
+    "agentic_edit",
+    "execute_code",
+    "execute_script",
+}
 
 
 def _is_slash_command(text: str) -> bool:
@@ -111,7 +151,7 @@ class ACPSession:
     mcp_servers: Sequence[McpServer] | None = None
     """Optional MCP server configurations"""
 
-    client_capabilities: ClientCapabilities | None = None
+    client_capabilities: ClientCapabilities = field(default_factory=ClientCapabilities)
     """Client capabilities for tool registration"""
 
     manager: ACPSessionManager | None = None
@@ -121,11 +161,13 @@ class ACPSession:
         """Initialize session state and set up providers."""
         self.mcp_servers = self.mcp_servers or []
         self.log = logger.bind(session_id=self.session_id)
-        self._active = True
         self._task_lock = asyncio.Lock()
         self._cancelled = False
-        self._current_tool_inputs: dict[str, dict] = {}
+        self._current_tool_inputs: dict[str, dict[str, Any]] = {}
         self.fs = ACPFileSystem(self.client, session_id=self.session_id)
+        from llmling_agent_server.acp_server.acp_process_manager import ACPProcessManager
+
+        self.process_manager = ACPProcessManager(self)
         self._acp_provider: AggregatingResourceProvider | None = None
         # Staged prompt parts for context building
         from llmling_agent_server.acp_server.commands.acp_commands import get_acp_commands
@@ -139,8 +181,6 @@ class ACPSession:
         cmds = [
             *get_commands(
                 enable_set_model=False,
-                enable_enable_tool=False,
-                enable_disable_tool=False,
                 enable_list_resources=False,
                 enable_add_resource=False,
                 enable_show_resource=False,
@@ -160,11 +200,11 @@ class ACPSession:
             session_id=self.session_id,
         )
         self.requests = ACPRequests(client=self.client, session_id=self.session_id)
+        self.input_provider = ACPInputProvider(self)
 
-        if self.client_capabilities:
-            self._acp_provider = get_acp_provider(self)
-            current_agent = self.agent
-            current_agent.tools.add_provider(self._acp_provider)
+        self._acp_provider = get_acp_provider(self)
+        current_agent = self.agent
+        current_agent.tools.add_provider(self._acp_provider)
 
         # Add cwd context to all agents in the pool
         for agent in self.agent_pool.agents.values():
@@ -180,9 +220,9 @@ class ACPSession:
         cfgs = [convert_acp_mcp_server_to_config(s) for s in self.mcp_servers]
         # Define accessible roots for MCP servers
         # root = Path(self.cwd).resolve().as_uri() if self.cwd else None
-        for cfg in cfgs:
+        for _cfg in cfgs:
             try:
-                await self.agent_pool.mcp.setup_server(cfg)
+                # Server will be initialized when MCP manager enters context
                 self.log.info("Added MCP servers", server_count=len(cfgs))
                 await self._register_mcp_prompts_as_commands()
             except Exception:
@@ -199,6 +239,41 @@ class ACPSession:
                 prompt = f"## Project Information\n\n{info}"
                 agent.sys_prompts.prompts.append(prompt)
 
+    async def init_client_skills(self) -> None:
+        """Discover and load skills from client-side .claude/skills directory."""
+        try:
+            from fsspec.implementations.dirfs import (  # type: ignore[import-untyped]
+                DirFileSystem,
+            )
+
+            from llmling_agent.resource_providers.skills import SkillsResourceProvider
+            from llmling_agent.skills.registry import SkillsRegistry
+
+            # Create skills registry for client-side skills
+            registry = SkillsRegistry()
+            wrapped_fs = DirFileSystem(".claude/skills", self.fs, asynchronious=True)
+            await registry.register_skills_from_path(wrapped_fs)
+            # Discover skills using ACP filesystem
+            if not registry.is_empty:
+                # Create provider
+                client_skills_provider = SkillsResourceProvider(
+                    registry=registry,
+                    name="client_skills",
+                    owner=f"acp_session_{self.session_id}",
+                )
+
+                # Add to all agents in the pool
+                for agent in self.agent_pool.agents.values():
+                    agent.tools.add_provider(client_skills_provider)
+
+                skill_count = len(registry.list_items())
+                self.log.info("Added client-side skills to agents", skill_count=skill_count)
+            else:
+                self.log.debug("No valid client-side skills found")
+
+        except Exception as e:
+            self.log.exception("Failed to discover client-side skills", error=e)
+
     @property
     def agent(self) -> Agent[ACPSession, str]:
         """Get the currently active agent."""
@@ -241,11 +316,6 @@ class ACPSession:
         #     await self.notifications.update_session_model(new_model)
         await self.send_available_commands_update()
 
-    @property
-    def active(self) -> bool:
-        """Check if session is active."""
-        return self._active
-
     def cancel(self) -> None:
         """Cancel the current prompt turn."""
         self._cancelled = True
@@ -284,10 +354,6 @@ class ACPSession:
         Returns:
             Stop reason
         """
-        if not self._active:
-            self.log.warning("Attempted to process prompt on inactive session")
-            return "refusal"
-
         self._cancelled = False
         contents = from_content_blocks(content_blocks)
         self.log.debug("Converted content", content=contents)
@@ -320,7 +386,10 @@ class ACPSession:
             self._current_tool_inputs.clear()  # Reset tool inputs for new stream
 
             try:
-                async for event in self.agent.run_stream(*non_command_content):
+                # Use the session's persistent input provider
+                async for event in self.agent.run_stream(
+                    *non_command_content, input_provider=self.input_provider
+                ):
                     if self._cancelled:
                         return "cancelled"
 
@@ -346,7 +415,7 @@ class ACPSession:
             else:
                 return "end_turn"
 
-    async def handle_event(self, event: RichAgentStreamEvent):  # noqa: PLR0915
+    async def handle_event(self, event: RichAgentStreamEvent[Any]) -> None:  # noqa: PLR0915
         match event:
             case (
                 PartStartEvent(part=TextPart(content=delta))
@@ -360,18 +429,18 @@ class ACPSession:
             ):
                 await self.notifications.send_agent_thought(delta or "\n")
 
-            case PartStartEvent(delta=delta):
-                self.log.debug("Received unhandled PartStartEvent", delta=delta)
+            case PartStartEvent(part=part):
+                self.log.debug("Received unhandled PartStartEvent", part=part)
 
             case PartDeltaEvent(delta=ToolCallPartDelta() as delta):
-                if part := delta.as_part():
-                    tool_call_id = part.tool_call_id
-                    self._current_tool_inputs[tool_call_id] = part.args_as_dict()
+                if delta_part := delta.as_part():
+                    tool_call_id = delta_part.tool_call_id
+                    self._current_tool_inputs[tool_call_id] = delta_part.args_as_dict()
                     # Skip generic notifications for self-notifying tools
-                    if part.tool_name not in ACP_SELF_NOTIFYING_TOOLS:
+                    if delta_part.tool_name not in ACP_SELF_NOTIFYING_TOOLS:
                         await self.notifications.tool_call(
-                            tool_name=part.tool_name,
-                            tool_input=part.args_as_dict(),
+                            tool_name=delta_part.tool_name,
+                            tool_input=delta_part.args_as_dict(),
                             tool_output=None,  # Not available yet
                             status="pending",
                             tool_call_id=tool_call_id,
@@ -449,6 +518,34 @@ class ACPSession:
                     )
                 self._current_tool_inputs.pop(tool_call_id, None)  # Clean up stored input
 
+            case ToolCallStartEvent(
+                tool_call_id=tool_call_id,
+                tool_name=tool_name,
+                title=title,
+                kind=kind,
+                content=content,
+                locations=locations,
+                raw_input=raw_input,
+            ):
+                self.log.debug(
+                    "Received tool call start event",
+                    tool_name=tool_name,
+                    tool_call_id=tool_call_id,
+                )
+                # Convert LocationContentItem objects to ACP format
+                acp_locations = [
+                    ToolCallLocation(path=loc.path, line=loc.line) for loc in locations
+                ]
+
+                # Send initial tool_call notification (creation)
+                await self.notifications.tool_call_start(
+                    tool_call_id=tool_call_id,
+                    title=title,
+                    kind=kind,
+                    locations=acp_locations,
+                    raw_input=raw_input,
+                )
+
             case ToolCallProgressEvent(
                 progress=progress,
                 total=total,
@@ -457,36 +554,27 @@ class ACPSession:
                 tool_call_id=tool_call_id,
                 tool_input=tool_input,
             ):
-                self.log.debug(
-                    "Received progress event for tool",
-                    tool_name=tool_name,
-                    tool_call_id=tool_call_id,
-                )
+                msg = "Received progress event for tool"
+                self.log.debug(msg, tool_name=tool_name, tool_call_id=tool_call_id)
                 output = message if message else f"Progress: {progress}"
                 if total:
                     output += f"/{total}"
-                try:
-                    # Create content from progress message
+                # Create content from progress message
 
-                    # Create ACP tool call progress notification
-                    # await self.notifications.tool_call(
-                    #     tool_name=tool_name,
-                    #     tool_input=tool_input or {},
-                    #     tool_output=output,
-                    #     status="in_progress",
-                    #     tool_call_id=tool_call_id,
-                    # )
-                    await self.notifications.tool_call_progress(
-                        title=message,
-                        raw_output=output,
-                        status="in_progress",
-                        tool_call_id=tool_call_id,
-                    )
-                except Exception as e:  # noqa: BLE001
-                    self.log.warning(
-                        "Failed to convert progress event to ACP notification",
-                        error=str(e),
-                    )
+                # Create ACP tool call progress notification
+                # await self.notifications.tool_call(
+                #     tool_name=tool_name,
+                #     tool_input=tool_input or {},
+                #     tool_output=output,
+                #     status="in_progress",
+                #     tool_call_id=tool_call_id,
+                # )
+                await self.notifications.tool_call_progress(
+                    title=message,
+                    raw_output=output,
+                    status="in_progress",
+                    tool_call_id=tool_call_id,
+                )
 
             case FinalResultEvent():
                 self.log.debug("Final result received")
@@ -494,15 +582,154 @@ class ACPSession:
             case StreamCompleteEvent(message=message):
                 pass
 
+            case PlanUpdateEvent(entries=entries, tool_call_id=tool_call_id):
+                acp_entries = [
+                    ACPPlanEntry(content=e.content, priority=e.priority, status=e.status)
+                    for e in entries
+                ]
+                await self.notifications.update_plan(acp_entries)
+
+            case FileOperationEvent(
+                operation=operation,
+                path=path,
+                success=success,
+                error=error,
+                tool_call_id=tool_call_id,
+            ):
+                if tool_call_id and success:
+                    await self.notifications.tool_call_progress(
+                        tool_call_id=tool_call_id,
+                        status="completed",
+                        locations=[ToolCallLocation(path=path)],
+                    )
+                elif tool_call_id:
+                    await self.notifications.tool_call_progress(
+                        tool_call_id=tool_call_id,
+                        status="failed",
+                        raw_output=f"File operation {operation!r} failed: {error}",
+                    )
+
+            case FileEditProgressEvent(
+                path=path,
+                old_text=old_text,
+                new_text=new_text,
+                status=status,
+                changed_lines=changed_lines,
+                tool_call_id=tool_call_id,
+            ):
+                # Handle FileEditProgressEvent
+                if tool_call_id:
+                    await self.notifications.file_edit_progress(
+                        tool_call_id=tool_call_id,
+                        path=path,
+                        old_text=old_text,
+                        new_text=new_text,
+                        status=status,
+                        changed_lines=changed_lines,
+                    )
+
+            case ProcessStartEvent(
+                process_id=process_id,
+                command=command,
+                success=success,
+                error=error,
+                tool_call_id=tool_call_id,
+            ):
+                # Handle ProcessStartEvent
+                if tool_call_id and success:
+                    await self.notifications.tool_call_start(
+                        tool_call_id=tool_call_id,
+                        title=f"Running: {command}",
+                        kind="execute",
+                        content=[TerminalToolCallContent(terminal_id=process_id)],
+                    )
+                elif tool_call_id:
+                    await self.notifications.tool_call_progress(
+                        tool_call_id=tool_call_id,
+                        status="failed",
+                        title=f"Failed to start process: {command}",
+                        raw_output=f"Process start failed: {error}",
+                    )
+
+            case ProcessOutputEvent(
+                process_id=process_id,
+                output=output,
+                # truncated=truncated,
+                tool_call_id=tool_call_id,
+            ):
+                # Handle ProcessOutputEvent
+                if tool_call_id:
+                    await self.notifications.terminal_progress(
+                        tool_call_id=tool_call_id,
+                        terminal_id=process_id,
+                        status="in_progress",
+                        title=f"Process {process_id} output",
+                    )
+
+            case ProcessExitEvent(
+                process_id=process_id,
+                exit_code=exit_code,
+                success=success,
+                final_output=final_output,
+                tool_call_id=tool_call_id,
+            ):
+                # Handle ProcessExitEvent
+                if tool_call_id:
+                    title = f"Process {process_id} exited with code {exit_code}"
+                    await self.notifications.terminal_progress(
+                        tool_call_id=tool_call_id,
+                        terminal_id=process_id,
+                        status="completed" if success else "failed",
+                        title=title,
+                    )
+
+            case ProcessKillEvent(
+                process_id=process_id,
+                success=success,
+                error=error,
+                tool_call_id=tool_call_id,
+            ):
+                if tool_call_id and success:
+                    await self.notifications.terminal_progress(
+                        tool_call_id=tool_call_id,
+                        terminal_id=process_id,
+                        status="completed",
+                        title=f"Killed process {process_id}",
+                    )
+                elif tool_call_id:
+                    await self.notifications.tool_call_progress(
+                        tool_call_id=tool_call_id,
+                        status="failed",
+                        title=f"Failed to kill process {process_id}",
+                        raw_output=f"Process kill failed: {error}",
+                    )
+
+            case ProcessReleaseEvent(
+                process_id=process_id,
+                success=success,
+                error=error,
+                tool_call_id=tool_call_id,
+            ):
+                if tool_call_id and success:
+                    await self.notifications.terminal_progress(
+                        tool_call_id=tool_call_id,
+                        terminal_id=process_id,
+                        status="completed",
+                        title=f"Released process {process_id}",
+                    )
+                elif tool_call_id:
+                    await self.notifications.tool_call_progress(
+                        tool_call_id=tool_call_id,
+                        status="failed",
+                        title=f"Failed to release process {process_id}",
+                        raw_output=f"Process release failed: {error}",
+                    )
+
             case _:
                 self.log.debug("Unhandled event", event_type=type(event).__name__)
 
     async def close(self) -> None:
         """Close the session and cleanup resources."""
-        if not self._active:
-            return
-
-        self._active = False
         self._current_tool_inputs.clear()
 
         try:
@@ -540,10 +767,8 @@ class ACPSession:
                     command = self.create_mcp_command(prompt)
                     self.command_store.register_command(command)
                 self._notify_command_update()
-                self.log.info(
-                    "Registered MCP prompts as slash commands",
-                    prompt_count=len(all_prompts),
-                )
+                msg = "Registered MCP prompts as slash commands"
+                self.log.info(msg, prompt_count=len(all_prompts))
                 # Send updated command list to client
                 await self.send_available_commands_update()
 
@@ -569,10 +794,8 @@ class ACPSession:
 
             if command_count > 0:
                 self._notify_command_update()
-                self.log.info(
-                    "Registered prompt hub prompts as slash commands",
-                    command_count=command_count,
-                )
+                msg = "Registered prompt hub prompts as slash commands"
+                self.log.info(msg, command_count=command_count)
                 # Send updated command list to client
                 await self.send_available_commands_update()
 
@@ -640,7 +863,7 @@ class ACPSession:
         """
         self._update_callbacks.append(callback)
 
-    def create_mcp_command(self, prompt: Prompt) -> Command:
+    def create_mcp_command(self, prompt: MCPClientPrompt) -> Command:
         """Convert MCP prompt to slashed Command.
 
         Args:
@@ -652,7 +875,7 @@ class ACPSession:
         """
 
         async def execute_prompt(
-            ctx: CommandContext,
+            ctx: CommandContext[Any],
             args: list[str],
             kwargs: dict[str, str],
         ) -> None:
@@ -673,18 +896,14 @@ class ACPSession:
 
                 # Send confirmation
                 staged_count = self.get_staged_parts_count()
-                await ctx.print(
-                    f"✅ Prompt '{prompt.name}' staged ({staged_count} total parts)"
-                )
+                await ctx.print(f"✅ Prompt {prompt.name!r} staged ({staged_count} total parts)")
 
             except Exception as e:
                 logger.exception("MCP prompt execution failed", prompt=prompt.name)
                 await ctx.print(f"❌ Prompt error: {e}")
 
         usage_hint = (
-            " ".join(f"<{arg['name']}>" for arg in prompt.arguments)
-            if prompt.arguments
-            else None
+            " ".join(f"<{arg['name']}>" for arg in prompt.arguments) if prompt.arguments else None
         )
         return Command(
             execute_func=execute_prompt,
@@ -709,7 +928,7 @@ class ACPSession:
         """
 
         async def execute_prompt(
-            ctx: CommandContext,
+            ctx: CommandContext[Any],
             args: list[str],
             kwargs: dict[str, str],
         ) -> None:
@@ -734,13 +953,11 @@ class ACPSession:
                 # Send confirmation
                 staged_count = self.get_staged_parts_count()
                 await ctx.print(
-                    f"✅ Prompt {name!r} from {provider} staged ({staged_count} total parts)"  # noqa: E501
+                    f"✅ Prompt {name!r} from {provider} staged ({staged_count} total parts)"
                 )
 
             except Exception as e:
-                logger.exception(
-                    "Prompt hub execution failed", prompt=name, provider=provider
-                )
+                logger.exception("Prompt hub execution failed", prompt=name, provider=provider)
                 await ctx.print(f"❌ Prompt error: {e}")
 
         # Create command name - prefix with provider if not builtin
