@@ -50,13 +50,13 @@ class StoredConversation:
     total_cost: float = 0.0
 
 
-class StorageProvider[T]:
+class StorageProvider:
     """Base class for storage providers."""
 
     can_load_history: bool = False
     """Whether this provider supports loading history."""
 
-    def __init__(self, config: BaseStorageProviderConfig):
+    def __init__(self, config: BaseStorageProviderConfig) -> None:
         super().__init__()
         self.config = config
         self.task_manager = TaskManager()
@@ -74,11 +74,11 @@ class StorageProvider[T]:
         exc_type: type[BaseException] | None,
         exc_val: BaseException | None,
         exc_tb: TracebackType | None,
-    ):
+    ) -> None:
         """Clean up provider resources."""
         self.cleanup()
 
-    def cleanup(self):
+    def cleanup(self) -> None:
         """Clean up resources."""
 
     def should_log_agent(self, agent_name: str) -> bool:
@@ -106,7 +106,7 @@ class StorageProvider[T]:
         provider_response_id: str | None = None,
         messages: str | None = None,
         finish_reason: FinishReason | None = None,
-    ):
+    ) -> None:
         """Log a message (if supported)."""
 
     async def log_conversation(
@@ -115,7 +115,7 @@ class StorageProvider[T]:
         conversation_id: str,
         node_name: str,
         start_time: datetime | None = None,
-    ):
+    ) -> None:
         """Log a conversation (if supported)."""
 
     async def log_command(
@@ -126,7 +126,7 @@ class StorageProvider[T]:
         command: str,
         context_type: type | None = None,
         metadata: dict[str, JsonValue] | None = None,
-    ):
+    ) -> None:
         """Log a command (if supported)."""
 
     async def get_commands(
@@ -151,7 +151,7 @@ class StorageProvider[T]:
         model: str | None = None,
         message_id: str | None = None,
         metadata: dict[str, Any] | None = None,
-    ):
+    ) -> None:
         """Log a context message if context logging is enabled."""
         if not self.log_context:
             return
@@ -286,20 +286,3 @@ class StorageProvider[T]:
             Tuple of (conversation count, message count)
         """
         raise NotImplementedError
-
-    async def add_checkpoint(
-        self,
-        message_id: str,
-        checkpoint_name: str,
-        description: str | None = None,
-    ):
-        """Add checkpoint to message."""
-        raise NotImplementedError
-
-    async def get_messages_until_checkpoint(
-        self,
-        checkpoint_name: str,
-        conversation_id: str,
-    ) -> list[T]:
-        """Get all messages up to and including checkpoint."""
-        raise NotImplementedError
