@@ -2,7 +2,7 @@
 
 from __future__ import annotations
 
-from typing import TYPE_CHECKING, Any, Literal, TypeGuard
+from typing import TYPE_CHECKING, Any, Literal, TypeGuard, assert_never
 
 from rich.console import Console
 from rich.markdown import Markdown
@@ -58,12 +58,11 @@ def format_output(
                 stats_data: dict[str, Any] = data  # type: ignore
                 _print_stats(console, stats_data)
             return console.export_text()
-        case _:
-            msg = f"Invalid output format: {output_format}"
-            raise ValueError(msg)
+        case _ as unreachable:
+            assert_never(unreachable)
 
 
-def _print_conversation(console: Console, conv: ConversationData):
+def _print_conversation(console: Console, conv: ConversationData) -> None:
     """Print a conversation in text format."""
     console.print(f"\n[bold blue]Conversation {conv['id']}[/]")
     console.print(f"Agent: {conv['agent']}, Started: {conv['start_time']}\n")
@@ -88,7 +87,7 @@ def _print_conversation(console: Console, conv: ConversationData):
         console.print()
 
 
-def _print_stats(console: Console, stats: dict[str, Any]):
+def _print_stats(console: Console, stats: dict[str, Any]) -> None:
     """Print statistics in text format."""
     if "period" in stats:
         console.print(f"\n[bold]Usage Statistics ({stats['period']})[/]")
