@@ -31,13 +31,13 @@ class MemoryStorageProvider(StorageProvider):
 
     can_load_history = True
 
-    def __init__(self, config: MemoryStorageConfig):
+    def __init__(self, config: MemoryStorageConfig) -> None:
         super().__init__(config)
-        self.messages: list[dict] = []
-        self.conversations: list[dict] = []
-        self.commands: list[dict] = []
+        self.messages: list[dict[str, Any]] = []
+        self.conversations: list[dict[str, Any]] = []
+        self.commands: list[dict[str, Any]] = []
 
-    def cleanup(self):
+    def cleanup(self) -> None:
         """Clear all stored data."""
         self.messages.clear()
         self.conversations.clear()
@@ -126,7 +126,7 @@ class MemoryStorageProvider(StorageProvider):
         provider_response_id: str | None = None,
         messages: str | None = None,
         finish_reason: str | None = None,
-    ):
+    ) -> None:
         """Store message in memory."""
         if next((i for i in self.messages if i["message_id"] == message_id), None):
             msg = f"Duplicate message ID: {message_id}"
@@ -155,11 +155,9 @@ class MemoryStorageProvider(StorageProvider):
         conversation_id: str,
         node_name: str,
         start_time: datetime | None = None,
-    ):
+    ) -> None:
         """Store conversation in memory."""
-        if next(
-            (i for i in self.messages if i["conversation_id"] == conversation_id), None
-        ):
+        if next((i for i in self.messages if i["conversation_id"] == conversation_id), None):
             msg = f"Duplicate conversation ID: {conversation_id}"
             raise ValueError(msg)
         self.conversations.append({
@@ -176,7 +174,7 @@ class MemoryStorageProvider(StorageProvider):
         command: str,
         context_type: type | None = None,
         metadata: dict[str, JsonValue] | None = None,
-    ):
+    ) -> None:
         """Store command in memory."""
         self.commands.append({
             "agent_name": agent_name,
@@ -265,9 +263,7 @@ class MemoryStorageProvider(StorageProvider):
                         "timestamp": msg.timestamp.isoformat(),
                         "model": msg.model_name,
                         "name": msg.name,
-                        "token_usage": msg.cost_info.token_usage
-                        if msg.cost_info
-                        else None,
+                        "token_usage": msg.cost_info.token_usage if msg.cost_info else None,
                         "cost": msg.cost_info.total_cost if msg.cost_info else None,
                         "response_time": msg.response_time,
                     },
@@ -344,16 +340,12 @@ class MemoryStorageProvider(StorageProvider):
 
         if agent_name:
             # Filter out data for specific agent
-            self.conversations = [
-                c for c in self.conversations if c["agent_name"] != agent_name
-            ]
+            self.conversations = [c for c in self.conversations if c["agent_name"] != agent_name]
             self.messages = [
                 m
                 for m in self.messages
                 if m["conversation_id"]
-                not in {
-                    c["id"] for c in self.conversations if c["agent_name"] == agent_name
-                }
+                not in {c["id"] for c in self.conversations if c["agent_name"] == agent_name}
             ]
         else:
             # Clear all
@@ -370,9 +362,7 @@ class MemoryStorageProvider(StorageProvider):
     ) -> tuple[int, int]:
         """Get conversation and message counts."""
         if agent_name:
-            conv_count = sum(
-                1 for c in self.conversations if c["agent_name"] == agent_name
-            )
+            conv_count = sum(1 for c in self.conversations if c["agent_name"] == agent_name)
             msg_count = sum(
                 1
                 for m in self.messages
