@@ -63,9 +63,7 @@ def upgrade(
 def downgrade(
     revision: Annotated[
         str,
-        typer.Argument(
-            help="Target revision (e.g., -1 for previous, or specific revision ID)"
-        ),
+        typer.Argument(help="Target revision (e.g., -1 for previous, or specific revision ID)"),
     ],
 ) -> int:
     """Downgrade database."""
@@ -133,7 +131,7 @@ def reset(
     return run_command(["alembic", "upgrade", "head"], cwd=project_root)
 
 
-def main():
+def main() -> None:
     """Main entry point."""
     # Set up environment
     project_root = get_project_root()
