@@ -3,7 +3,7 @@
 from __future__ import annotations
 
 from datetime import UTC, datetime
-from typing import Any
+from typing import TYPE_CHECKING, Any
 from uuid import uuid4
 
 from pydantic import ConfigDict
@@ -12,33 +12,42 @@ from sqlalchemy import Column, DateTime
 from sqlalchemy.ext.asyncio import AsyncAttrs
 from sqlalchemy.types import TypeDecorator
 from sqlmodel import JSON, Field, SQLModel
-from sqlmodel.main import SQLModelConfig
+from sqlmodel.main import SQLModelConfig  # type: ignore[attr-defined]
 
 from llmling_agent.common_types import JsonValue
 from llmling_agent.utils.now import get_now
 
 
-class UTCDateTime(TypeDecorator):
+if TYPE_CHECKING:
+    from sqlalchemy import Dialect
+
+
+class UTCDateTime(TypeDecorator[datetime]):
     """Stores DateTime as UTC."""
 
     impl = DateTime
     cache_ok = True
 
-    def process_bind_param(self, value: datetime | None, dialect):
+    def process_bind_param(
+        self,
+        value: datetime | None,
+        dialect: Dialect,
+    ) -> datetime | None:
         if value is not None:
-            if value.tzinfo is None:
-                value = value.replace(tzinfo=UTC)
-            else:
-                value = value.astimezone(UTC)
+            value = value.replace(tzinfo=UTC) if value.tzinfo is None else value.astimezone(UTC)
         return value
 
-    def process_result_value(self, value: datetime | None, dialect):
+    def process_result_value(
+        self,
+        value: datetime | None,
+        dialect: Dialect,
+    ) -> datetime | None:
         if value is not None:
             value = value.replace(tzinfo=UTC)
         return value
 
 
-class CommandHistory(AsyncAttrs, SQLModel, table=True):  # type: ignore[call-arg]
+class CommandHistory(AsyncAttrs, SQLModel, table=True):
     """Database model for command history."""
 
     id: int = Field(default=None, primary_key=True)
@@ -56,9 +65,7 @@ class CommandHistory(AsyncAttrs, SQLModel, table=True):  # type: ignore[call-arg
     context_type: str | None = Field(default=None, index=True)
     """Type of the command context (e.g. 'AgentContext', 'PoolSupervisor', etc.)"""
 
-    context_metadata: dict[str, JsonValue] = Field(
-        default_factory=dict, sa_column=Column(JSON)
-    )
+    context_metadata: dict[str, JsonValue] = Field(default_factory=dict, sa_column=Column(JSON))
     """Additional context information about command execution"""
 
     timestamp: datetime = Field(
@@ -111,7 +118,7 @@ class ConversationLog(Schema):
     model_config = ConfigDict(frozen=True)
 
 
-class Message(AsyncAttrs, SQLModel, table=True):  # type: ignore[call-arg]
+class Message(AsyncAttrs, SQLModel, table=True):
     """Database model for message logs."""
 
     id: str = Field(default_factory=lambda: str(uuid4()), primary_key=True)
@@ -179,7 +186,7 @@ class Message(AsyncAttrs, SQLModel, table=True):  # type: ignore[call-arg]
     model_config = SQLModelConfig(use_attribute_docstrings=True)  # pyright: ignore[reportCallIssue]
 
 
-class Conversation(AsyncAttrs, SQLModel, table=True):  # type: ignore[call-arg]
+class Conversation(AsyncAttrs, SQLModel, table=True):
     """Database model for conversations."""
 
     id: str = Field(primary_key=True)
@@ -191,9 +198,7 @@ class Conversation(AsyncAttrs, SQLModel, table=True):  # type: ignore[call-arg]
     title: str | None = Field(default=None, index=True)
     """Generated title for the conversation"""
 
-    start_time: datetime = Field(
-        sa_column=Column(UTCDateTime, index=True), default_factory=get_now
-    )
+    start_time: datetime = Field(sa_column=Column(UTCDateTime, index=True), default_factory=get_now)
     """When the conversation started"""
 
     total_tokens: int = 0
