@@ -7,13 +7,14 @@ from datetime import timedelta
 from typing import TYPE_CHECKING, Any, Literal
 from uuid import uuid4
 
-from pydantic_ai import ModelRetry, RunContext
+from pydantic_ai import ModelRetry
 
 from llmling_agent.agent.context import AgentContext  # noqa: TC001
 from llmling_agent.log import get_logger
-from llmling_agent.resource_providers.static import StaticResourceProvider
+from llmling_agent.resource_providers import StaticResourceProvider
 from llmling_agent.tools.base import Tool
 from llmling_agent.tools.exceptions import ToolError
+from llmling_agent.utils.result_utils import to_type
 
 
 if TYPE_CHECKING:
@@ -39,8 +40,6 @@ async def delegate_to(  # noqa: D417
     Returns:
         The result of the delegated task
     """
-    if isinstance(ctx, RunContext):
-        ctx = ctx.deps
     if not ctx.pool:
         msg = "Agent needs to be in a pool to delegate tasks"
         raise ToolError(msg)
@@ -72,8 +71,6 @@ async def list_available_agents(  # noqa: D417
     Returns:
         List of agent names that you can use with delegate_to
     """
-    if isinstance(ctx, RunContext):
-        ctx = ctx.deps
     if not ctx.pool:
         msg = "Agent needs to be in a pool to list agents"
         raise ToolError(msg)
@@ -111,8 +108,6 @@ async def list_available_teams(  # noqa: D417
     """
     from llmling_agent import TeamRun
 
-    if isinstance(ctx, RunContext):
-        ctx = ctx.deps
     if not ctx.pool:
         msg = "No agent pool available"
         raise ToolError(msg)
@@ -148,8 +143,6 @@ async def create_worker_agent[TDeps](
     """
     from llmling_agent import Agent
 
-    if isinstance(ctx, RunContext):
-        ctx = ctx.deps
     if not ctx.pool:
         msg = "Agent needs to be in a pool to list agents"
         raise ToolError(msg)
@@ -175,8 +168,6 @@ async def spawn_delegate[TDeps](
     """
     from llmling_agent import Agent
 
-    if isinstance(ctx, RunContext):
-        ctx = ctx.deps
     if not ctx.pool:
         msg = "No agent pool available"
         raise ToolError(msg)
@@ -218,8 +209,6 @@ async def add_agent(  # noqa: D417
     Returns:
         Confirmation message about the created agent
     """
-    if isinstance(ctx, RunContext):
-        ctx = ctx.deps
     assert ctx.pool, "No agent pool available"
     try:
         agent: Agent[Any, Any] = await ctx.pool.add_agent(
@@ -227,7 +216,7 @@ async def add_agent(  # noqa: D417
             system_prompt=system_prompt,
             model=model,
             tools=tools,
-            output_type=output_type or str,
+            output_type=to_type(output_type, responses=ctx.pool.manifest.responses),
             session=session,
         )
     except ValueError as e:  # for wrong tool imports
@@ -250,8 +239,6 @@ async def add_team(  # noqa: D417
             - parallel: Agents process simultaneously
         name: Optional name for the team
     """
-    if isinstance(ctx, RunContext):
-        ctx = ctx.deps
     if not ctx.pool:
         msg = "No agent pool available"
         raise ToolError(msg)
@@ -291,8 +278,6 @@ async def ask_agent(  # noqa: D417
     Returns:
         The agent's response
     """
-    if isinstance(ctx, RunContext):
-        ctx = ctx.deps
     assert ctx.pool, "No agent pool available"
     if agent_name not in ctx.pool.nodes:
         msg = (
@@ -324,7 +309,7 @@ async def connect_nodes(  # noqa: D417
 ) -> str:
     """Connect two nodes to enable message flow between them.
 
-    Nodes can be agents, teams, or EventNodes.
+    Nodes can be agents or teams.
 
     Args:
         source: Name of the source node
@@ -346,8 +331,6 @@ async def connect_nodes(  # noqa: D417
     Returns:
         Description of the created connection
     """
-    if isinstance(ctx, RunContext):
-        ctx = ctx.deps
     if not ctx.pool:
         msg = "No agent pool available"
         raise ToolError(msg)
@@ -407,7 +390,7 @@ def create_agent_management_tools() -> list[Tool]:
 class AgentManagementTools(StaticResourceProvider):
     """Provider for agent management tools."""
 
-    def __init__(self, name: str = "agent_management"):
+    def __init__(self, name: str = "agent_management") -> None:
         super().__init__(name=name, tools=create_agent_management_tools())
 
 
@@ -422,7 +405,7 @@ if __name__ == "__main__":
 
 ."""
 
-    async def main():
+    async def main() -> None:
         from llmling_agent_config.toolsets import IntegrationToolsetConfig
 
         async with AgentPool() as pool:
