@@ -17,8 +17,8 @@ if TYPE_CHECKING:
 class UpsonicTools(ResourceProvider):
     """Provider for upsonic tools."""
 
-    def __init__(self, api_key: SecretStr | None = None, base_url: str | None = None):
-        from upsonic import Tiger, Tiger_Admin
+    def __init__(self, api_key: SecretStr | None = None, base_url: str | None = None) -> None:
+        from upsonic import Tiger, Tiger_Admin  # type: ignore[import-untyped]
 
         super().__init__(name="tiger")
         key = api_key.get_secret_value() if api_key else os.getenv("UPSONIC_API_KEY")
@@ -42,7 +42,7 @@ class UpsonicTools(ResourceProvider):
 if __name__ == "__main__":
     import asyncio
 
-    async def main():
+    async def main() -> None:
         from llmling_agent import Agent
 
         tools = UpsonicTools()
